
!------------------------------------------------------------------------!
!  The Community Multiscale Air Quality (CMAQ) system software is in     !
!  continuous development by various groups and is based on information  !
!  from these groups: Federal Government employees, contractors working  !
!  within a United States Government contract, and non-Federal sources   !
!  including research institutions.  These groups give the Government    !
!  permission to use, prepare derivative works of, and distribute copies !
!  of their work in the CMAQ system to the public and to permit others   !
!  to do so.  The United States Environmental Protection Agency          !
!  therefore grants similar permission to use the CMAQ system software,  !
!  but users are requested to provide copies of derivative works or      !
!  products designed to operate in the CMAQ system to the United States  !
!  Government without restrictions as to use by others.  Software        !
!  that is used with the CMAQ system but distributed under the GNU       !
!  General Public License or the GNU Lesser General Public License is    !
!  subject to their copyright restrictions.                              !
!------------------------------------------------------------------------!
 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! The ODE Function of Chemical Model File
! 
! Generated by KPP-2.2.3 symbolic chemistry Kinetics PreProcessor
!       (http://www.cs.vt.edu/~asandu/Software/KPP)
! KPP is distributed under GPL, the general public licence
!       (http://www.gnu.org/copyleft/gpl.html)
! (C) 1995-1997, V. Damian & A. Sandu, CGRER, Univ. Iowa
! (C) 1997-2005, A. Sandu, Michigan Tech, Virginia Tech
!     With important contributions from:
!        M. Damian, Villanova University, USA
!        R. Sander, Max-Planck Institute for Chemistry, Mainz, Germany
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



MODULE aqchem_Function

  USE aqchem_Parameters
  IMPLICIT NONE

! A - Rate for each equation
  REAL(kind=dp) :: A(NREACT)

CONTAINS


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! Fun - time derivatives of variables - Agregate form
!   Arguments :
!      V         - Concentrations of variable species (local)
!      F         - Concentrations of fixed species (local)
!      RCT       - Rate constants (local)
!      Vdot      - Time derivative of variable species concentrations
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE Fun ( V, F, RCT, Vdot )

! V - Concentrations of variable species (local)
  REAL(kind=dp) :: V(NVAR)
! F - Concentrations of fixed species (local)
  REAL(kind=dp) :: F(NFIX)
! RCT - Rate constants (local)
  REAL(kind=dp) :: RCT(NREACT)
! Vdot - Time derivative of variable species concentrations
  REAL(kind=dp) :: Vdot(NVAR)


! Computation of equation rates
  A(1) = RCT(1)*V(100)
  A(2) = RCT(2)*V(86)
  A(3) = RCT(3)*V(87)
  A(4) = RCT(4)*V(88)
  A(5) = RCT(5)*V(85)
  A(6) = RCT(6)*V(89)
  A(7) = RCT(7)*V(90)
  A(8) = RCT(8)*V(91)
  A(9) = RCT(9)*V(92)
  A(10) = RCT(10)*V(93)
  A(11) = RCT(11)*V(94)
  A(12) = RCT(12)*V(95)
  A(13) = RCT(13)*V(82)
  A(14) = RCT(14)*V(96)
  A(15) = RCT(15)*V(74)
  A(16) = RCT(16)*V(97)
  A(17) = RCT(17)*V(145)
  A(18) = RCT(18)*V(107)
  A(19) = RCT(19)*V(125)
  A(20) = RCT(20)*V(108)
  A(21) = RCT(21)*V(146)
  A(22) = RCT(22)*V(158)
  A(23) = RCT(23)*V(142)
  A(24) = RCT(24)*V(121)
  A(25) = RCT(25)*V(122)
  A(26) = RCT(26)*V(111)
  A(27) = RCT(27)*V(106)
  A(28) = RCT(28)*V(113)
  A(29) = RCT(29)*V(155)
  A(30) = RCT(30)*V(159)
  A(31) = RCT(31)*V(126)
  A(32) = RCT(32)*V(150)
  A(33) = RCT(33)*V(1)
  A(34) = RCT(34)*V(2)
  A(35) = RCT(35)*V(3)
  A(36) = RCT(36)*V(4)
  A(37) = RCT(37)*V(5)
  A(38) = RCT(38)*V(6)
  A(39) = RCT(39)*V(7)
  A(40) = RCT(40)*V(8)
  A(41) = RCT(41)*V(145)
  A(42) = RCT(42)*V(157)
  A(43) = RCT(43)*V(107)
  A(44) = RCT(44)*V(125)
  A(45) = RCT(45)*V(115)
  A(46) = RCT(46)*V(108)
  A(47) = RCT(47)*V(142)
  A(48) = RCT(48)*V(111)
  A(49) = RCT(49)*F(1)
  A(50) = RCT(50)*V(110)
  A(51) = RCT(51)*V(124)
  A(52) = RCT(52)*V(155)
  A(53) = RCT(53)*V(126)
  A(54) = RCT(54)*V(150)
  A(55) = RCT(55)*V(156)*V(157)
  A(56) = RCT(56)*V(156)*V(160)
  A(57) = RCT(57)*V(147)*V(156)
  A(58) = RCT(58)*V(115)*V(156)
  A(59) = RCT(59)*V(114)*V(156)
  A(60) = RCT(60)*V(109)*V(153)
  A(61) = RCT(61)*V(138)*V(156)
  A(62) = RCT(62)*V(112)*V(156)
  A(63) = RCT(63)*V(153)*V(156)
  A(64) = RCT(64)*V(124)*V(156)
  A(65) = RCT(65)*V(154)*V(156)
  A(66) = RCT(66)*V(151)*V(156)
  A(67) = RCT(67)*V(152)*V(156)
  A(68) = RCT(68)*V(130)*V(156)
  A(69) = RCT(69)*V(146)*V(156)*V(157)
  A(70) = RCT(70)*V(145)*V(158)
  A(71) = RCT(71)*V(157)*V(158)
  A(72) = RCT(72)*V(158)*V(160)
  A(73) = RCT(73)*V(14)*V(145)
  A(74) = RCT(74)*V(14)*V(157)
  A(75) = RCT(75)*V(14)*V(160)
  A(76) = RCT(76)*V(13)*V(145)
  A(77) = RCT(77)*V(13)*V(157)
  A(78) = RCT(78)*V(13)*V(160)
  A(79) = RCT(79)*V(13)*V(14)*V(145)
  A(80) = RCT(80)*V(13)*V(14)*V(157)
  A(81) = RCT(81)*V(13)*V(14)*V(160)
  A(82) = RCT(82)*V(121)*V(156)*V(157)
  A(83) = RCT(83)*V(122)*V(156)*V(157)
  A(84) = RCT(84)*V(122)*V(157)
  A(85) = RCT(85)*V(155)*V(155)
  A(86) = RCT(86)*V(151)*V(155)
  A(87) = RCT(87)*V(151)*V(158)
  A(88) = RCT(88)*V(145)*V(159)
  A(89) = RCT(89)*V(157)*V(159)
  A(90) = RCT(90)*V(159)*V(160)
  A(91) = RCT(91)*V(150)*V(157)
  A(92) = RCT(92)*V(130)
  A(93) = RCT(93)*V(152)*V(158)
  A(94) = RCT(94)*V(152)*V(161)
  A(95) = RCT(95)*V(126)*V(161)
  A(96) = RCT(96)*V(145)
  A(97) = RCT(97)*V(107)
  A(98) = RCT(98)*V(125)
  A(99) = RCT(99)*V(108)
  A(100) = RCT(100)*V(146)
  A(101) = RCT(101)*V(158)
  A(102) = RCT(102)*V(142)
  A(103) = RCT(103)*V(121)
  A(104) = RCT(104)*V(122)
  A(105) = RCT(105)*V(110)
  A(106) = RCT(106)*V(111)
  A(107) = RCT(107)*V(106)
  A(108) = RCT(108)*V(113)
  A(109) = RCT(109)*V(154)
  A(110) = RCT(110)*V(147)
  A(111) = RCT(111)*V(109)
  A(112) = RCT(112)*V(112)
  A(113) = RCT(113)*V(9)
  A(114) = RCT(114)*V(10)
  A(115) = RCT(115)*V(11)
  A(116) = RCT(116)*V(12)
  A(117) = RCT(117)*V(15)
  A(118) = RCT(118)*V(16)
  A(119) = RCT(119)*V(17)
  A(120) = RCT(120)*V(18)
  A(121) = RCT(121)*V(13)
  A(122) = RCT(122)*V(14)
  A(123) = RCT(123)*V(156)
  A(124) = RCT(124)*V(153)
  A(125) = RCT(125)*V(157)
  A(126) = RCT(126)*V(160)
  A(127) = RCT(127)*V(115)
  A(128) = RCT(128)*V(114)
  A(129) = RCT(129)*V(138)
  A(130) = RCT(130)*V(124)
  A(131) = RCT(131)*V(151)
  A(132) = RCT(132)*V(155)
  A(133) = RCT(133)*V(159)
  A(134) = RCT(134)*V(126)
  A(135) = RCT(135)*V(152)
  A(136) = RCT(136)*V(130)
  A(137) = RCT(137)*V(150)
  A(138) = RCT(138)*F(2)
  A(139) = RCT(139)*V(161)
  A(140) = RCT(140)*V(161)
  A(141) = RCT(141)*V(101)
  A(142) = RCT(142)*V(75)
  A(143) = RCT(143)*V(77)
  A(144) = RCT(144)*V(116)
  A(145) = RCT(145)*V(76)
  A(146) = RCT(146)*V(78)
  A(147) = RCT(147)*V(116)*F(1)
  A(148) = RCT(148)*V(116)*V(154)
  A(149) = RCT(149)*V(102)*V(116)
  A(150) = RCT(150)*V(103)*V(116)
  A(151) = RCT(151)*V(116)*F(1)
  A(152) = RCT(152)*V(116)*V(154)
  A(153) = RCT(153)*V(116)*V(147)
  A(154) = RCT(154)*V(76)*F(1)
  A(155) = RCT(155)*V(76)*V(154)
  A(156) = RCT(156)*V(78)*F(1)
  A(157) = RCT(157)*V(78)*V(154)
  A(158) = RCT(158)*V(116)
  A(159) = RCT(159)*V(102)
  A(160) = RCT(160)*V(103)
  A(161) = RCT(161)*V(56)
  A(162) = RCT(162)*V(76)
  A(163) = RCT(163)*V(78)
  A(164) = RCT(164)*V(60)
  A(165) = RCT(165)*V(62)
  A(166) = RCT(166)*V(53)
  A(167) = RCT(167)*V(79)
  A(168) = RCT(168)*V(80)
  A(169) = RCT(169)*V(81)
  A(170) = RCT(170)*V(84)
  A(171) = RCT(171)*V(83)
  A(172) = RCT(172)*V(105)
  A(173) = RCT(173)*V(135)
  A(174) = RCT(174)*V(144)
  A(175) = RCT(175)*V(119)
  A(176) = RCT(176)*V(134)
  A(177) = RCT(177)*V(137)
  A(178) = RCT(178)*V(129)
  A(179) = RCT(179)*V(132)
  A(180) = RCT(180)*V(134)
  A(181) = RCT(181)*V(139)
  A(182) = RCT(182)*V(135)
  A(183) = RCT(183)*V(141)*V(156)
  A(184) = RCT(184)*V(132)*V(156)
  A(185) = RCT(185)*V(131)*V(156)
  A(186) = RCT(186)*V(133)*V(156)
  A(187) = RCT(187)*V(140)*V(156)
  A(188) = RCT(188)*V(136)*V(156)
  A(189) = RCT(189)*V(144)*F(1)
  A(190) = RCT(190)*V(149)
  A(191) = RCT(191)*V(119)*F(1)
  A(192) = RCT(192)*V(117)
  A(193) = RCT(193)*V(146)
  A(194) = RCT(194)*V(105)*V(161)
  A(195) = RCT(195)*V(105)*V(161)
  A(196) = RCT(196)*V(139)*V(161)
  A(197) = RCT(197)*V(140)*V(161)
  A(198) = RCT(198)*V(106)*V(161)
  A(199) = RCT(199)*V(137)*V(161)
  A(200) = RCT(200)*V(141)*V(161)
  A(201) = RCT(201)*V(129)*V(161)
  A(202) = RCT(202)*V(132)*V(161)
  A(203) = RCT(203)*V(131)*V(161)
  A(204) = RCT(204)*V(113)*V(161)
  A(205) = RCT(205)*V(134)*V(161)
  A(206) = RCT(206)*V(133)*V(161)
  A(207) = RCT(207)*V(135)*V(161)
  A(208) = RCT(208)*V(136)*V(161)
  A(209) = RCT(209)*V(149)*V(161)
  A(210) = RCT(210)*V(142)*V(161)
  A(211) = RCT(211)*V(117)*V(161)
  A(212) = RCT(212)*V(137)
  A(213) = RCT(213)*V(141)
  A(214) = RCT(214)*V(129)
  A(215) = RCT(215)*V(132)
  A(216) = RCT(216)*V(131)
  A(217) = RCT(217)*V(134)
  A(218) = RCT(218)*V(133)
  A(219) = RCT(219)*V(135)
  A(220) = RCT(220)*V(136)
  A(221) = RCT(221)*V(149)
  A(222) = RCT(222)*V(105)
  A(223) = RCT(223)*V(139)
  A(224) = RCT(224)*V(140)
  A(225) = RCT(225)*V(144)
  A(226) = RCT(226)*V(119)
  A(227) = RCT(227)*V(117)
  A(228) = RCT(228)*V(98)
  A(229) = RCT(229)*V(99)
  A(230) = RCT(230)*V(127)
  A(231) = RCT(231)*V(120)
  A(232) = RCT(232)*V(147)
  A(233) = RCT(233)*V(161)*V(161)
  A(234) = RCT(234)*V(155)*V(161)
  A(235) = RCT(235)*V(151)*V(161)
  A(236) = RCT(236)*V(146)*V(161)
  A(237) = RCT(237)*V(157)*V(161)
  A(238) = RCT(238)*V(155)*V(159)
  A(239) = RCT(239)*V(151)*V(159)
  A(240) = RCT(240)*V(150)
  A(241) = RCT(241)*V(127)*V(154)
  A(242) = RCT(242)*V(127)*V(157)
  A(243) = RCT(243)*V(104)*F(3)
  A(244) = RCT(244)*V(143)*V(155)
  A(245) = RCT(245)*V(143)*V(143)
  A(246) = RCT(246)*V(128)*V(156)*V(157)
  A(247) = RCT(247)*V(123)*F(1)
  A(248) = RCT(248)*V(120)*V(120)
  A(249) = RCT(249)*V(120)*V(157)
  A(250) = RCT(250)*V(138)*V(161)
  A(251) = RCT(251)*V(144)*V(157)
  A(252) = RCT(252)*V(144)*V(160)
  A(253) = RCT(253)*V(148)
  A(254) = RCT(254)*V(148)*V(153)
  A(255) = RCT(255)*V(148)*V(161)
  A(256) = RCT(256)*V(119)*V(157)
  A(257) = RCT(257)*V(119)*V(160)
  A(258) = RCT(258)*V(118)
  A(259) = RCT(259)*V(118)*V(153)
  A(260) = RCT(260)*V(118)*V(161)
  A(261) = RCT(261)*V(127)
  A(262) = RCT(262)*V(120)
  A(263) = RCT(263)*V(123)
  A(264) = RCT(264)*V(104)
  A(265) = RCT(265)*V(148)
  A(266) = RCT(266)*V(143)
  A(267) = RCT(267)*V(128)
  A(268) = RCT(268)*V(22)
  A(269) = RCT(269)*V(118)

! Aggregate function
  Vdot(1) = -A(33)
  Vdot(2) = -A(34)
  Vdot(3) = -A(35)
  Vdot(4) = -A(36)
  Vdot(5) = -A(37)
  Vdot(6) = -A(38)
  Vdot(7) = -A(39)
  Vdot(8) = -A(40)
  Vdot(9) = A(40)-A(113)
  Vdot(10) = A(38)-A(114)
  Vdot(11) = -A(115)
  Vdot(12) = A(39)-A(116)
  Vdot(13) = -A(121)
  Vdot(14) = -A(122)
  Vdot(15) = -A(117)
  Vdot(16) = -A(118)
  Vdot(17) = -A(119)
  Vdot(18) = A(36)-A(120)
  Vdot(19) = A(96)+A(125)+A(126)+A(263)+A(264)+A(265)+A(266)+A(267)
  Vdot(20) = A(97)
  Vdot(21) = A(98)+A(127)+A(128)+A(268)
  Vdot(22) = A(202)+A(203)-A(268)
  Vdot(23) = A(99)
  Vdot(24) = A(100)
  Vdot(25) = A(101)
  Vdot(26) = A(102)+A(129)
  Vdot(27) = A(103)
  Vdot(28) = A(104)
  Vdot(29) = A(105)+A(109)+A(130)
  Vdot(30) = A(106)
  Vdot(31) = A(107)
  Vdot(32) = A(108)
  Vdot(33) = A(140)
  Vdot(34) = A(110)
  Vdot(35) = A(111)
  Vdot(36) = A(112)
  Vdot(37) = A(113)
  Vdot(38) = A(121)
  Vdot(39) = A(122)
  Vdot(40) = A(114)
  Vdot(41) = A(115)
  Vdot(42) = A(116)
  Vdot(43) = A(123)
  Vdot(44) = A(117)
  Vdot(45) = A(118)
  Vdot(46) = A(119)
  Vdot(47) = A(120)
  Vdot(48) = A(133)
  Vdot(49) = A(134)+A(135)
  Vdot(50) = A(136)+A(137)
  Vdot(51) = A(158)
  Vdot(52) = A(159)+A(166)
  Vdot(53) = A(151)+A(152)+A(153)-A(166)
  Vdot(54) = A(160)
  Vdot(55) = A(161)
  Vdot(56) = A(149)+A(150)-A(161)
  Vdot(57) = A(162)
  Vdot(58) = A(163)
  Vdot(59) = A(164)
  Vdot(60) = A(154)+A(156)-A(164)
  Vdot(61) = A(165)
  Vdot(62) = A(155)+A(157)-A(165)
  Vdot(63) = A(212)+A(213)
  Vdot(64) = A(214)+A(215)+A(216)
  Vdot(65) = A(217)+A(218)
  Vdot(66) = A(219)+A(220)
  Vdot(67) = A(221)+A(225)+A(265)
  Vdot(68) = A(131)+A(132)
  Vdot(69) = A(222)
  Vdot(70) = A(223)+A(224)
  Vdot(71) = A(226)+A(227)+A(269)
  Vdot(72) = A(261)
  Vdot(73) = A(262)
  Vdot(74) = -A(15)+A(31)
  Vdot(75) = -A(142)+A(145)
  Vdot(76) = A(142)-A(145)-A(154)-A(155)-A(162)
  Vdot(77) = -A(143)+A(146)
  Vdot(78) = A(143)-A(146)-A(156)-A(157)-A(163)
  Vdot(79) = -A(167)+A(172)
  Vdot(80) = -A(168)+A(173)
  Vdot(81) = -A(169)+A(174)
  Vdot(82) = -A(13)+A(29)
  Vdot(83) = -A(171)+A(176)
  Vdot(84) = -A(170)+A(175)
  Vdot(85) = -A(5)+A(21)
  Vdot(86) = -A(2)+A(18)
  Vdot(87) = -A(3)+A(19)
  Vdot(88) = -A(4)+A(20)
  Vdot(89) = -A(6)+A(22)
  Vdot(90) = -A(7)+A(23)
  Vdot(91) = -A(8)+A(24)
  Vdot(92) = -A(9)+A(25)
  Vdot(93) = -A(10)+A(26)
  Vdot(94) = -A(11)+A(27)
  Vdot(95) = -A(12)+A(28)
  Vdot(96) = -A(14)+A(30)
  Vdot(97) = -A(16)+A(32)
  Vdot(98) = -A(228)+A(230)
  Vdot(99) = -A(229)+A(231)
  Vdot(100) = -A(1)+A(17)
  Vdot(101) = -A(141)+A(144)
  Vdot(102) = A(147)-A(149)-A(159)
  Vdot(103) = A(148)-A(150)-A(160)
  Vdot(104) = A(237)+A(242)-A(243)+A(249)-A(264)
  Vdot(105) = A(167)-A(172)-A(194)-A(195)-A(222)
  Vdot(106) = A(11)-A(27)-A(107)+A(195)-A(198)
  Vdot(107) = A(2)-A(18)-A(43)+A(57)-A(97)
  Vdot(108) = A(4)-A(20)-A(46)+A(60)-A(99)
  Vdot(109) = A(34)+A(46)-A(60)-A(111)
  Vdot(110) = -A(50)+A(64)-A(105)
  Vdot(111) = A(10)-A(26)-A(48)+A(62)-A(106)
  Vdot(112) = A(35)+A(48)-A(62)-A(112)
  Vdot(113) = A(12)-A(28)-A(108)-A(204)
  Vdot(114) = A(45)-A(59)-A(128)
  Vdot(115) = A(44)-A(45)-A(58)+A(59)-A(127)
  Vdot(116) = A(141)-A(144)-A(147)-A(148)-A(149)-A(150)-A(151)-A(152)-A(153)-A(158)
  Vdot(117) = A(191)-A(192)-A(211)-A(227)+A(259)
  Vdot(118) = A(256)+A(257)-A(258)-A(259)-A(260)-A(269)
  Vdot(119) = A(170)-A(175)-A(191)+A(192)-A(226)-A(256)-A(257)+A(258)
  Vdot(120) = A(229)-A(231)-2*A(248)-A(249)-A(262)
  Vdot(121) = A(8)-A(24)-A(82)-A(103)+A(249)
  Vdot(122) = A(9)-A(25)-A(83)-A(84)-A(104)
  Vdot(123) = A(241)+2*A(245)-A(247)-A(263)
  Vdot(124) = A(50)-A(51)-A(64)+A(65)-A(130)+A(247)
  Vdot(125) = A(3)-A(19)-A(44)+A(58)-A(98)+2*A(201)+A(202)+A(203)+A(205)+A(206)+A(210)+A(250)
  Vdot(126) = A(15)-A(31)-A(53)+A(67)-A(95)-A(134)
  Vdot(127) = A(228)-A(230)-A(241)-A(242)-A(261)
  Vdot(128) = A(244)-A(246)-A(267)
  Vdot(129) = -A(178)+A(184)+A(199)-A(201)-A(214)
  Vdot(130) = A(54)-A(68)-A(92)-A(136)+A(239)
  Vdot(131) = A(179)-A(185)-A(203)-A(216)
  Vdot(132) = A(178)-A(179)-A(184)+A(185)+A(200)-A(202)-A(215)
  Vdot(133) = A(180)-A(186)+0.92*A(204)-A(206)-A(218)
  Vdot(134) = A(171)-A(176)-A(180)+A(186)-A(205)-A(217)
  Vdot(135) = A(168)-A(173)-A(182)+A(188)+A(205)-A(207)-A(219)
  Vdot(136) = A(182)-A(188)+A(206)-A(208)-A(220)
  Vdot(137) = -A(177)+A(183)+A(198)-A(199)+0.85*A(207)-A(212)
  Vdot(138) = A(47)-A(61)-A(129)-A(250)
  Vdot(139) = -A(181)+A(187)+A(194)-A(196)-A(223)
  Vdot(140) = A(181)-A(187)-A(197)-A(224)
  Vdot(141) = A(177)-A(183)+A(196)+A(197)-A(200)+0.08*A(204)+0.85*A(208)-A(213)
  Vdot(142) = A(7)-A(23)-A(47)+A(61)-A(102)+A(209)-A(210)+A(255)
  Vdot(143) = A(243)-A(244)-2*A(245)-A(266)
  Vdot(144) = A(169)-A(174)-A(189)+A(190)-A(225)+2*A(248)-A(251)-A(252)+A(253)
  Vdot(145) = A(1)-A(17)-A(41)+A(55)-A(70)-A(73)-A(76)-A(79)-A(88)-A(96)
  Vdot(146) = A(5)-A(21)-A(69)+A(85)+A(86)-A(100)-A(193)+A(233)-A(236)
  Vdot(147) = A(33)+A(43)-A(57)+A(91)+A(93)-A(110)-A(153)-A(232)+A(241)+A(242)
  Vdot(148) = A(251)+A(252)-A(253)-A(254)-A(255)-A(265)
  Vdot(149) = A(189)-A(190)+0.15*A(207)+0.15*A(208)-A(209)-A(221)+A(254)
  Vdot(150) = A(16)-A(32)-A(54)+A(68)-A(91)-A(137)+A(238)-A(240)
  Vdot(151) = A(52)-A(66)-A(86)-A(87)-A(131)-A(235)-A(239)
  Vdot(152) = A(53)-A(67)+2*A(88)+2*A(89)+2*A(90)+A(92)-A(93)-A(94)-A(135)
  Vdot(153) = A(46)+A(49)-A(60)-A(63)+A(86)+A(87)+A(94)-A(124)+A(203)+A(232)+A(235)+A(250)+A(252)-A(254)
  Vdot(154) = A(37)+A(51)-A(65)+A(69)+A(70)+A(71)+A(72)+A(73)+A(74)+A(75)+A(76)+A(77)+A(78)+A(79)+A(80)+A(81)+A(82)&
                &+A(83)+A(84)+A(88)+A(89)+A(90)+A(91)-A(109)-A(148)-A(152)-A(155)-A(157)-A(241)+2*A(246)
  Vdot(155) = A(13)-A(29)-A(52)+A(66)-2*A(85)-A(86)-A(132)+A(194)+A(195)+A(196)+A(197)+A(198)+A(199)+A(200)+A(204)&
                &+A(205)+A(206)+A(209)+A(210)-A(234)+A(236)-A(238)+A(240)-A(244)+2*A(248)+A(250)+A(255)
  Vdot(156) = A(41)+A(42)+A(43)+A(44)+A(45)+A(47)+A(48)+A(49)+A(50)+A(51)+A(52)+A(53)+A(54)-A(55)-A(56)-A(57)-A(58)&
                &-A(59)-A(61)-A(62)-A(63)-A(64)-A(65)-A(66)-A(67)-A(68)+A(69)+2*A(70)+A(71)+2*A(73)+A(74)+2*A(76)+A(77)+2&
                &*A(79)+A(80)+A(82)+A(83)+A(84)+4*A(88)+3*A(89)+2*A(90)+2*A(91)-A(123)+A(177)+A(178)+A(179)+A(180)+A(181)&
                &+A(182)-A(183)-A(184)-A(185)-A(186)-A(187)-A(188)+A(196)+A(242)+2*A(246)
  Vdot(157) = A(41)-A(42)-A(55)+A(56)-A(69)-A(71)-A(74)-A(77)-A(80)-A(82)-A(83)-A(84)-A(89)-A(91)-A(125)-A(237)-A(242)&
                &-A(246)-A(249)-A(251)+A(253)+A(255)
  Vdot(158) = A(6)-A(22)-A(70)-A(71)-A(72)-A(87)-A(93)-A(101)
  Vdot(159) = A(14)-A(30)-2*A(88)-2*A(89)-2*A(90)+A(94)+A(95)-A(133)+A(232)-A(238)-A(239)+A(240)
  Vdot(160) = A(42)-A(56)-A(72)-A(75)-A(78)-A(81)-A(90)-A(126)-A(252)+A(254)
  Vdot(161) = A(87)-A(94)-A(95)+A(138)-A(139)-A(140)+2*A(193)-A(194)-A(195)-A(196)-A(197)-A(198)-A(199)-A(200)-2*A(201)&
                &-A(202)-A(203)-A(204)-A(205)-A(206)-A(207)-A(208)-A(209)-A(210)+A(232)-2*A(233)-A(234)-A(235)-A(236)-A(237)&
                &+A(247)-A(250)-A(255)
      
END SUBROUTINE Fun

! End of Fun function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



END MODULE aqchem_Function

