
!------------------------------------------------------------------------!
!  The Community Multiscale Air Quality (CMAQ) system software is in     !
!  continuous development by various groups and is based on information  !
!  from these groups: Federal Government employees, contractors working  !
!  within a United States Government contract, and non-Federal sources   !
!  including research institutions.  These groups give the Government    !
!  permission to use, prepare derivative works of, and distribute copies !
!  of their work in the CMAQ system to the public and to permit others   !
!  to do so.  The United States Environmental Protection Agency          !
!  therefore grants similar permission to use the CMAQ system software,  !
!  but users are requested to provide copies of derivative works or      !
!  products designed to operate in the CMAQ system to the United States  !
!  Government without restrictions as to use by others.  Software        !
!  that is used with the CMAQ system but distributed under the GNU       !
!  General Public License or the GNU Lesser General Public License is    !
!  subject to their copyright restrictions.                              !
!------------------------------------------------------------------------!

      SUBROUTINE HRPRODLOSS

C***********************************************************************
C
C  FUNCTION: To compute the production and loss rates for EBI species
C
C  PRECONDITIONS: For the RACM2_AE6_AQ mechanism
C
C  RETURN VALUES: None
C
C  KEY SUBROUTINES/FUNCTIONS CALLED: None
C
C  REVISION HISTORY: Created by EBI solver program, Jun  8, 2022
C
C   18 Jul 14 B.Hutzell: revised to use real(8) variables

C***********************************************************************
      USE HRDATA

      IMPLICIT NONE


C.....INCLUDES: NONE


C.....ARGUMENTS: NONE


C.....PARAMETERS: NONE


C.....EXTERNAL FUNCTIONS: NONE


C.....SAVED VARIABLES: NONE
!     CHARACTER( 16 ), SAVE  ::  PNAME = 'HRPRODLOSS'   ! Program name


C.....LOCAL VARIABLES:


C***********************************************************************


      PROD(  H2O2     ) =                 RXRAT(    45 )      ! HO2+HO2=H2O2
     &                  +                 RXRAT(    46 )      ! HO2+HO2=H2O2
     &                  +    6.8000D-02 * RXRAT(   127 )      ! OLT+O3=0.6800D-01*H2O2+...
     &                  +    2.6000D-02 * RXRAT(   128 )      ! OLI+O3=0.2600D-01*H2O2+...
     &                  +    1.0000D-03 * RXRAT(   129 )      ! DIEN+O3=0.1000D-02*H2O2+...
     &                  +    9.0000D-02 * RXRAT(   130 )      ! ISO+O3=0.9000D-01*H2O2+...
     &                  +    2.0000D-02 * RXRAT(   131 )      ! API+O3=0.2000D-01*H2O2+...
     &                  +    2.0000D-02 * RXRAT(   132 )      ! LIM+O3=0.2000D-01*H2O2+...
      LOSS(  H2O2     ) =                 RXRAT(     3 )      ! H2O2=0.2000D+01*HO
     &                  +                 RXRAT(    47 )      ! H2O2+HO=HO2

      PROD(  HNO3     ) =                 RXRAT(    51 )      ! NO+HO2=HNO3
     &                  +                 RXRAT(    56 )      ! NO2+HO=HNO3
     &                  +    3.0000D-01 * RXRAT(    59 )      ! NO3+HO2=0.3000D+00*HNO3+...
     &                  +    2.0000D+00 * RXRAT(    65 )      ! N2O5=0.2000D+01*HNO3
     &                  +                 RXRAT(   148 )      ! HCHO+NO3=HNO3+CO+HO2
     &                  +                 RXRAT(   149 )      ! ACD+NO3=HNO3+ACO3
     &                  +                 RXRAT(   150 )      ! ALD+NO3=HNO3+RCO3
     &                  +    3.2000D-01 * RXRAT(   151 )      ! MACR+NO3=0.3200D+00*HNO3+...
     &                  +                 RXRAT(   153 )      ! GLY+NO3=HNO3+0.2000D+01*CO+HO2
     &                  +                 RXRAT(   154 )      ! MGLY+NO3=HNO3+CO+ACO3
     &                  +    5.0000D-01 * RXRAT(   155 )      ! PHEN+NO3=0.5000D+00*HNO3+...
     &                  +    5.0000D-01 * RXRAT(   156 )      ! CSL+NO3=0.5000D+00*HNO3+...
     &                  +    5.0000D-01 * RXRAT(   157 )      ! EPX+NO3=0.5000D+00*HNO3+...
     &                  +                 RXRAT(   158 )      ! MCT+NO3=HNO3+MCTO
     &                  +    2.0000D+00 * RXRAT(   378 )      ! N2O5=0.2000D+01*HNO3
     &                  +    5.0000D-01 * RXRAT(   379 )      ! NO2=0.5000D+00*HNO3+...
      LOSS(  HNO3     ) =                 RXRAT(     8 )      ! HNO3=HO+NO2
     &                  +                 RXRAT(    57 )      ! HNO3+HO=NO3

      PROD(  HCHO     ) =    3.5000D-01 * RXRAT(    15 )      ! UALD=0.3500D+00*HCHO+...
     &                  +                 RXRAT(    18 )      ! HKET=HCHO+ACO3+HO2
     &                  +    6.7000D-01 * RXRAT(    19 )      ! MACR=0.6700D+00*HCHO+...
     &                  +                 RXRAT(    22 )      ! GLY=HCHO+CO
     &                  +                 RXRAT(    28 )      ! OP1=HCHO+HO2+HO
     &                  +                 RXRAT(   109 )      ! MOH+HO=HCHO+HO2
     &                  +    3.5000D-01 * RXRAT(   113 )      ! OP1+HO=0.3500D+00*HCHO+...
     &                  +    3.5000D-01 * RXRAT(   119 )      ! PAA+HO=0.3500D+00*HCHO+...
     &                  +                 RXRAT(   120 )      ! PAN+HO=HCHO+NO3+XO2
     &                  +                 RXRAT(   121 )      ! PPN+HO=HCHO+NO3+XO2
     &                  +    7.0000D-02 * RXRAT(   125 )      ! ISON+HO=0.7000D-01*HCHO+...
     &                  +                 RXRAT(   126 )      ! ETE+O3=HCHO+0.1500D+00*HO2+...
     &                  +    5.6000D-01 * RXRAT(   127 )      ! OLT+O3=0.5600D+00*HCHO+...
     &                  +    9.0000D-02 * RXRAT(   128 )      ! OLI+O3=0.9000D-01*HCHO+...
     &                  +    9.0000D-01 * RXRAT(   129 )      ! DIEN+O3=0.9000D+00*HCHO+...
     &                  +    5.8000D-01 * RXRAT(   130 )      ! ISO+O3=0.5800D+00*HCHO+...
     &                  +    4.0000D-02 * RXRAT(   132 )      ! LIM+O3=0.4000D-01*HCHO+...
     &                  +    1.0000D-01 * RXRAT(   134 )      ! MVK+O3=0.1000D+00*HCHO+...
     &                  +    8.0000D-02 * RXRAT(   135 )      ! UALD+O3=0.8000D-01*HCHO+...
     &                  +    5.0000D-02 * RXRAT(   136 )      ! DCB1+O3=0.5000D-01*HCHO+...
     &                  +    5.0000D-02 * RXRAT(   137 )      ! DCB2+O3=0.5000D-01*HCHO+...
     &                  +    6.8000D-01 * RXRAT(   151 )      ! MACR+NO3=0.6800D+00*HCHO+...
     &                  +    3.3200D-01 * RXRAT(   152 )      ! UALD+NO3=0.3320D+00*HCHO+...
     &                  +                 RXRAT(   172 )      ! MO2+NO=HCHO+NO2+HO2
     &                  +    1.8000D-02 * RXRAT(   175 )      ! HC5P+NO=0.1800D-01*HCHO+...
     &                  +    1.6000D+00 * RXRAT(   177 )      ! ETEP+NO=0.1600D+01*HCHO+...
     &                  +    7.8000D-01 * RXRAT(   178 )      ! OLTP+NO=0.7800D+00*HCHO+...
     &                  +    2.0000D-01 * RXRAT(   188 )      ! ISOP+NO=0.2000D+00*HCHO+...
     &                  +    2.3000D-01 * RXRAT(   189 )      ! APIP+NO=0.2300D+00*HCHO+...
     &                  +    4.3000D-01 * RXRAT(   190 )      ! LIMP+NO=0.4300D+00*HCHO+...
     &                  +                 RXRAT(   193 )      ! ACTP+NO=HCHO+NO2+ACO3
     &                  +    3.3000D-01 * RXRAT(   194 )      ! MEKP+NO=0.3300D+00*HCHO+...
     &                  +    6.5000D-01 * RXRAT(   196 )      ! MACP+NO=0.6500D+00*HCHO+...
     &                  +    5.0000D-01 * RXRAT(   197 )      ! MCP+NO=0.5000D+00*HCHO+...
     &                  +    3.0000D-01 * RXRAT(   198 )      ! MVKP+NO=0.3000D+00*HCHO+...
     &                  +    3.0000D-02 * RXRAT(   199 )      ! UALP+NO=0.3000D-01*HCHO+...
     &                  +    2.8700D-01 * RXRAT(   206 )      ! OLND+NO=0.2870D+00*HCHO+...
     &                  +    1.5000D-01 * RXRAT(   233 )      ! ACTP+HO2=0.1500D+00*HCHO+...
     &                  +    1.3700D+00 * RXRAT(   248 )      ! MO2+MO2=0.1370D+01*HCHO+...
     &                  +    7.5000D-01 * RXRAT(   249 )      ! ETHP+MO2=0.7500D+00*HCHO+...
     &                  +    8.2700D-01 * RXRAT(   250 )      ! HC3P+MO2=0.8270D+00*HCHO+...
     &                  +    7.7700D-01 * RXRAT(   251 )      ! HC5P+MO2=0.7770D+00*HCHO+...
     &                  +    7.5000D-01 * RXRAT(   252 )      ! HC8P+MO2=0.7500D+00*HCHO+...
     &                  +    1.9500D+00 * RXRAT(   253 )      ! ETEP+MO2=0.1950D+01*HCHO+...
     &                  +    1.5000D+00 * RXRAT(   254 )      ! OLTP+MO2=0.1500D+01*HCHO+...
     &                  +    7.5000D-01 * RXRAT(   255 )      ! OLIP+MO2=0.7500D+00*HCHO+...
     &                  +                 RXRAT(   256 )      ! BENP+MO2=HCHO+0.4590D+...
     &                  +                 RXRAT(   257 )      ! TLP1+MO2=HCHO+HO2+BALD
     &                  +                 RXRAT(   258 )      ! TOLP+MO2=HCHO+0.2000D+...
     &                  +                 RXRAT(   259 )      ! PER1+MO2=HCHO+0.2000D+...
     &                  +                 RXRAT(   260 )      ! XYL1+MO2=HCHO+HO2+BALD
     &                  +                 RXRAT(   261 )      ! XYLP+MO2=HCHO+0.2000D+...
     &                  +                 RXRAT(   262 )      ! PER2+MO2=HCHO+0.2000D+...
     &                  +                 RXRAT(   263 )      ! XYOP+MO2=HCHO+0.2000D+...
     &                  +    1.3100D+00 * RXRAT(   264 )      ! ISOP+MO2=0.1310D+01*HCHO+...
     &                  +    7.5000D-01 * RXRAT(   265 )      ! APIP+MO2=0.7500D+00*HCHO+...
     &                  +    1.0400D+00 * RXRAT(   266 )      ! LIMP+MO2=0.1040D+01*HCHO+...
     &                  +                 RXRAT(   267 )      ! ACO3+MO2=HCHO+0.9000D+...
     &                  +                 RXRAT(   268 )      ! RCO3+MO2=HCHO+0.9000D+...
     &                  +    1.5000D+00 * RXRAT(   269 )      ! ACTP+MO2=0.1500D+01*HCHO+...
     &                  +                 RXRAT(   270 )      ! MEKP+MO2=HCHO+0.8340D+...
     &                  +    7.5000D-01 * RXRAT(   271 )      ! KETP+MO2=0.7500D+00*HCHO+...
     &                  +    1.6600D+00 * RXRAT(   272 )      ! MACP+MO2=0.1660D+01*HCHO+...
     &                  +    1.5000D+00 * RXRAT(   273 )      ! MCP+MO2=0.1500D+01*HCHO+...
     &                  +    1.5000D+00 * RXRAT(   274 )      ! MVKP+MO2=0.1500D+01*HCHO+...
     &                  +    7.7300D-01 * RXRAT(   275 )      ! UALP+MO2=0.7730D+00*HCHO+...
     &                  +                 RXRAT(   276 )      ! BALP+MO2=HCHO+BAL1+HO2
     &                  +                 RXRAT(   277 )      ! BAL1+MO2=HCHO+BAL2+HO2
     &                  +                 RXRAT(   278 )      ! ADDC+MO2=HCHO+0.2000D+...
     &                  +                 RXRAT(   279 )      ! MCTP+MO2=HCHO+MCTO+HO2
     &                  +                 RXRAT(   280 )      ! ORAP+MO2=HCHO+HO2+GLY
     &                  +                 RXRAT(   281 )      ! OLNN+MO2=HCHO+0.2000D+...
     &                  +    9.6500D-01 * RXRAT(   282 )      ! OLND+MO2=0.9650D+00*HCHO+...
     &                  +                 RXRAT(   283 )      ! ADCN+MO2=HCHO+0.7000D+...
     &                  +                 RXRAT(   284 )      ! XO2+MO2=HCHO+HO2
     &                  +    1.3000D-01 * RXRAT(   286 )      ! HC3P+ACO3=0.1300D+00*HCHO+...
     &                  +    4.2000D-02 * RXRAT(   287 )      ! HC5P+ACO3=0.4200D-01*HCHO+...
     &                  +    1.6000D+00 * RXRAT(   289 )      ! ETEP+ACO3=0.1600D+01*HCHO+...
     &                  +                 RXRAT(   290 )      ! OLTP+ACO3=HCHO+0.5000D+...
     &                  +    1.0480D+00 * RXRAT(   300 )      ! ISOP+ACO3=0.1048D+01*HCHO+...
     &                  +    3.8500D-01 * RXRAT(   302 )      ! LIMP+ACO3=0.3850D+00*HCHO+...
     &                  +                 RXRAT(   305 )      ! ACTP+ACO3=HCHO+0.5000D+...
     &                  +    3.3000D-01 * RXRAT(   306 )      ! MEKP+ACO3=0.3300D+00*HCHO+...
     &                  +                 RXRAT(   308 )      ! MACP+ACO3=HCHO+0.5000D+...
     &                  +                 RXRAT(   309 )      ! MCP+ACO3=HCHO+0.5000D+...
     &                  +                 RXRAT(   310 )      ! MVKP+ACO3=HCHO+0.5000D+...
     &                  +    3.0000D-02 * RXRAT(   311 )      ! UALP+ACO3=0.3000D-01*HCHO+...
     &                  +    2.8700D-01 * RXRAT(   318 )      ! OLND+ACO3=0.2870D+00*HCHO+...
     &                  +                 RXRAT(   322 )      ! MO2+NO3=HCHO+HO2+NO2
     &                  +    2.4000D-02 * RXRAT(   325 )      ! HC5P+NO3=0.2400D-01*HCHO+...
     &                  +    1.6000D+00 * RXRAT(   327 )      ! ETEP+NO3=0.1600D+01*HCHO+...
     &                  +    7.9000D-01 * RXRAT(   328 )      ! OLTP+NO3=0.7900D+00*HCHO+...
     &                  +    7.5000D-01 * RXRAT(   338 )      ! ISOP+NO3=0.7500D+00*HCHO+...
     &                  +    3.8500D-01 * RXRAT(   340 )      ! LIMP+NO3=0.3850D+00*HCHO+...
     &                  +                 RXRAT(   343 )      ! ACTP+NO3=HCHO+NO2+ACO3
     &                  +    3.3000D-01 * RXRAT(   344 )      ! MEKP+NO3=0.3300D+00*HCHO+...
     &                  +                 RXRAT(   346 )      ! MACP+NO3=HCHO+0.5380D+...
     &                  +                 RXRAT(   347 )      ! MCP+NO3=HCHO+HO2+NO2+HKET
     &                  +    3.0000D-01 * RXRAT(   348 )      ! MVKP+NO3=0.3000D+00*HCHO+...
     &                  +    3.0000D-02 * RXRAT(   349 )      ! UALP+NO3=0.3000D-01*HCHO+...
     &                  +    2.8700D-01 * RXRAT(   356 )      ! OLND+NO3=0.2870D+00*HCHO+...
     &                  +    2.0200D-01 * RXRAT(   359 )      ! OLNN+OLND=0.2020D+00*HCHO+...
     &                  +    5.0400D-01 * RXRAT(   360 )      ! OLND+OLND=0.5040D+00*HCHO+...
      LOSS(  HCHO     ) =                 RXRAT(    10 )      ! HCHO=CO
     &                  +                 RXRAT(    11 )      ! HCHO=0.2000D+01*HO2+CO
     &                  +                 RXRAT(    89 )      ! HCHO+HO=HO2+CO
     &                  +                 RXRAT(   148 )      ! HCHO+NO3=HO2+CO+HNO3

      PROD(  CO       ) =                 RXRAT(    10 )      ! HCHO=CO
     &                  +                 RXRAT(    11 )      ! HCHO=CO+0.2000D+01*HO2
     &                  +                 RXRAT(    12 )      ! ACD=CO+MO2+HO2
     &                  +                 RXRAT(    13 )      ! ALD=CO+ETHP+HO2
     &                  +    1.2200D+00 * RXRAT(    15 )      ! UALD=0.1220D+01*CO+0.7840D+...
     &                  +    6.7000D-01 * RXRAT(    19 )      ! MACR=0.6700D+00*CO+0.6600D+...
     &                  +    7.0000D-01 * RXRAT(    20 )      ! MVK=0.7000D+00*CO+0.3000D+...
     &                  +    2.0000D+00 * RXRAT(    21 )      ! GLY=0.2000D+01*CO
     &                  +                 RXRAT(    22 )      ! GLY=CO+HCHO
     &                  +    2.0000D+00 * RXRAT(    23 )      ! GLY=0.2000D+01*CO+0.2000D+...
     &                  +                 RXRAT(    24 )      ! MGLY=CO+ACO3+HO2
     &                  +                 RXRAT(    25 )      ! DCB1=CO+0.2500D+00*ACO3+...
     &                  +                 RXRAT(    26 )      ! DCB2=CO+0.2500D+00*ACO3+...
     &                  +                 RXRAT(    27 )      ! BALD=CO+HO2+CHO
     &                  +    3.5000D-01 * RXRAT(    80 )      ! ACE+HO=0.3500D+00*CO+...
     &                  +                 RXRAT(    89 )      ! HCHO+HO=CO+HO2
     &                  +    2.0000D+00 * RXRAT(    99 )      ! GLY+HO=0.2000D+01*CO+HO2
     &                  +                 RXRAT(   100 )      ! MGLY+HO=CO+ACO3
     &                  +    3.3000D-01 * RXRAT(   101 )      ! DCB1+HO=0.3300D+00*CO+...
     &                  +    3.3000D-01 * RXRAT(   102 )      ! DCB2+HO=0.3300D+00*CO+...
     &                  +    1.1000D-01 * RXRAT(   103 )      ! DCB3+HO=0.1100D+00*CO+...
     &                  +                 RXRAT(   107 )      ! EPX+HO=CO+XO2+HO2+ALD
     &                  +    4.3000D-01 * RXRAT(   126 )      ! ETE+O3=0.4300D+00*CO+...
     &                  +    4.3000D-01 * RXRAT(   127 )      ! OLT+O3=0.4300D+00*CO+...
     &                  +    3.7000D-01 * RXRAT(   128 )      ! OLI+O3=0.3700D+00*CO+...
     &                  +    3.6000D-01 * RXRAT(   129 )      ! DIEN+O3=0.3600D+00*CO+...
     &                  +    1.4000D-01 * RXRAT(   130 )      ! ISO+O3=0.1400D+00*CO+...
     &                  +    1.4000D-01 * RXRAT(   131 )      ! API+O3=0.1400D+00*CO+...
     &                  +    1.4000D-01 * RXRAT(   132 )      ! LIM+O3=0.1400D+00*CO+...
     &                  +    2.2000D-01 * RXRAT(   133 )      ! MACR+O3=0.2200D+00*CO+...
     &                  +    5.6000D-01 * RXRAT(   134 )      ! MVK+O3=0.5600D+00*CO+...
     &                  +    2.4300D-01 * RXRAT(   135 )      ! UALD+O3=0.2430D+00*CO+...
     &                  +    1.5000D+00 * RXRAT(   136 )      ! DCB1+O3=0.1500D+01*CO+HO2+...
     &                  +    1.5000D+00 * RXRAT(   137 )      ! DCB2+O3=0.1500D+01*CO+HO2+...
     &                  +    1.5000D+00 * RXRAT(   138 )      ! DCB3+O3=0.1500D+01*CO+HO2+...
     &                  +    1.5000D+00 * RXRAT(   139 )      ! EPX+O3=0.1500D+01*CO+...
     &                  +                 RXRAT(   148 )      ! HCHO+NO3=CO+HO2+HNO3
     &                  +    6.6800D-01 * RXRAT(   152 )      ! UALD+NO3=0.6680D+00*CO+XO2+...
     &                  +    2.0000D+00 * RXRAT(   153 )      ! GLY+NO3=0.2000D+01*CO+HO2+HNO3
     &                  +                 RXRAT(   154 )      ! MGLY+NO3=CO+ACO3+HNO3
     &                  +    1.5000D+00 * RXRAT(   157 )      ! EPX+NO3=0.1500D+01*CO+...
     &                  +    6.5000D-01 * RXRAT(   196 )      ! MACP+NO=0.6500D+00*CO+...
     &                  +    6.1000D-01 * RXRAT(   199 )      ! UALP+NO=0.6100D+00*CO+NO2+...
     &                  +    5.0000D-01 * RXRAT(   272 )      ! MACP+MO2=0.5000D+00*CO+...
     &                  +    3.0500D-01 * RXRAT(   275 )      ! UALP+MO2=0.3050D+00*CO+HO2+...
     &                  +    5.0000D-01 * RXRAT(   308 )      ! MACP+ACO3=0.5000D+00*CO+...
     &                  +    5.0000D-01 * RXRAT(   311 )      ! UALP+ACO3=0.5000D+00*CO+...
     &                  +                 RXRAT(   346 )      ! MACP+NO3=CO+0.5380D+...
     &                  +    6.1000D-01 * RXRAT(   349 )      ! UALP+NO3=0.6100D+00*CO+NO2+...
      LOSS(  CO       ) =                 RXRAT(    70 )      ! CO+HO=HO2

      PROD(  ACD      ) =                 RXRAT(   110 )      ! EOH+HO=ACD+HO2
     &                  +    1.8400D-01 * RXRAT(   111 )      ! ROH+HO=0.1840D+00*ACD+...
     &                  +    1.0000D-02 * RXRAT(   127 )      ! OLT+O3=0.1000D-01*ACD+...
     &                  +    4.5700D-01 * RXRAT(   128 )      ! OLI+O3=0.4570D+00*ACD+...
     &                  +    4.2000D-01 * RXRAT(   135 )      ! UALD+O3=0.4200D+00*ACD+...
     &                  +                 RXRAT(   173 )      ! ETHP+NO=ACD+NO2+HO2
     &                  +    5.0400D-01 * RXRAT(   174 )      ! HC3P+NO=0.5040D+00*ACD+...
     &                  +    4.5000D-02 * RXRAT(   175 )      ! HC5P+NO=0.4500D-01*ACD+...
     &                  +    1.2000D-02 * RXRAT(   178 )      ! OLTP+NO=0.1200D-01*ACD+...
     &                  +    8.1000D-01 * RXRAT(   179 )      ! OLIP+NO=0.8100D+00*ACD+...
     &                  +    7.5000D-01 * RXRAT(   249 )      ! ETHP+MO2=0.7500D+00*ACD+...
     &                  +                 RXRAT(   285 )      ! ETHP+ACO3=ACD+0.5000D+...
     &                  +                 RXRAT(   323 )      ! ETHP+NO3=ACD+NO2+HO2
     &                  +    5.1900D-01 * RXRAT(   324 )      ! HC3P+NO3=0.5190D+00*ACD+...
     &                  +    4.8000D-02 * RXRAT(   325 )      ! HC5P+NO3=0.4800D-01*ACD+...
     &                  +    2.0000D-02 * RXRAT(   328 )      ! OLTP+NO3=0.2000D-01*ACD+...
     &                  +    8.5000D-01 * RXRAT(   329 )      ! OLIP+NO3=0.8500D+00*ACD+...
      LOSS(  ACD      ) =                 RXRAT(    12 )      ! ACD=HO2+MO2+CO
     &                  +                 RXRAT(    90 )      ! ACD+HO=ACO3
     &                  +                 RXRAT(   149 )      ! ACD+NO3=ACO3+HNO3

      PROD(  MO2      ) =                 RXRAT(    12 )      ! ACD=MO2+HO2+CO
     &                  +                 RXRAT(    14 )      ! ACT=MO2+ACO3
     &                  +    5.0000D-01 * RXRAT(    16 )      ! MEK=0.5000D+00*MO2+0.5000D+...
     &                  +    3.0000D-01 * RXRAT(    20 )      ! MVK=0.3000D+00*MO2+0.3000D+...
     &                  +                 RXRAT(    30 )      ! PAA=MO2+HO
     &                  +                 RXRAT(    33 )      ! PAN=MO2+NO3
     &                  +                 RXRAT(    71 )      ! HO=MO2
     &                  +    6.5000D-01 * RXRAT(   113 )      ! OP1+HO=0.6500D+00*MO2+...
     &                  +    6.4000D-01 * RXRAT(   118 )      ! ORA2+HO=0.6400D+00*MO2+...
     &                  +    8.0000D-02 * RXRAT(   127 )      ! OLT+O3=0.8000D-01*MO2+...
     &                  +    3.2000D-01 * RXRAT(   128 )      ! OLI+O3=0.3200D+00*MO2+...
     &                  +    3.0000D-02 * RXRAT(   129 )      ! DIEN+O3=0.3000D-01*MO2+...
     &                  +    8.0000D-02 * RXRAT(   130 )      ! ISO+O3=0.8000D-01*MO2+...
     &                  +    8.0000D-03 * RXRAT(   135 )      ! UALD+O3=0.8000D-02*MO2+...
     &                  +    1.3100D-01 * RXRAT(   174 )      ! HC3P+NO=0.1310D+00*MO2+...
     &                  +    5.1000D-02 * RXRAT(   175 )      ! HC5P+NO=0.5100D-01*MO2+...
     &                  +                 RXRAT(   191 )      ! ACO3+NO=MO2+NO2
     &                  +    6.5000D-01 * RXRAT(   196 )      ! MACP+NO=0.6500D+00*MO2+...
     &                  +    4.4000D-01 * RXRAT(   231 )      ! ACO3+HO2=0.4400D+00*MO2+...
     &                  +    5.0000D-01 * RXRAT(   285 )      ! ETHP+ACO3=0.5000D+00*MO2+...
     &                  +    5.8000D-01 * RXRAT(   286 )      ! HC3P+ACO3=0.5800D+00*MO2+...
     &                  +    5.1800D-01 * RXRAT(   287 )      ! HC5P+ACO3=0.5180D+00*MO2+...
     &                  +    5.0000D-01 * RXRAT(   288 )      ! HC8P+ACO3=0.5000D+00*MO2+...
     &                  +    5.0000D-01 * RXRAT(   289 )      ! ETEP+ACO3=0.5000D+00*MO2+...
     &                  +    5.0000D-01 * RXRAT(   290 )      ! OLTP+ACO3=0.5000D+00*MO2+...
     &                  +    5.0000D-01 * RXRAT(   291 )      ! OLIP+ACO3=0.5000D+00*MO2+...
     &                  +                 RXRAT(   292 )      ! BENP+ACO3=MO2+0.6000D+...
     &                  +                 RXRAT(   293 )      ! TLP1+ACO3=MO2+BALD
     &                  +                 RXRAT(   294 )      ! TOLP+ACO3=MO2+HO2+DCB2
     &                  +                 RXRAT(   295 )      ! PER1+ACO3=MO2+HO2+MGLY+DCB1
     &                  +                 RXRAT(   296 )      ! XYL1+ACO3=MO2+BALD
     &                  +                 RXRAT(   297 )      ! XYLP+ACO3=MO2+HO2+DCB2
     &                  +                 RXRAT(   298 )      ! PER2+ACO3=MO2+HO2+MGLY+...
     &                  +                 RXRAT(   299 )      ! XYOP+ACO3=MO2+HO2+0.3680D+...
     &                  +    5.0000D-01 * RXRAT(   300 )      ! ISOP+ACO3=0.5000D+00*MO2+...
     &                  +    5.0000D-01 * RXRAT(   301 )      ! APIP+ACO3=0.5000D+00*MO2+...
     &                  +    5.0000D-01 * RXRAT(   302 )      ! LIMP+ACO3=0.5000D+00*MO2+...
     &                  +    2.0000D+00 * RXRAT(   303 )      ! ACO3+ACO3=0.2000D+01*MO2
     &                  +                 RXRAT(   304 )      ! RCO3+ACO3=MO2+ETHP
     &                  +    5.0000D-01 * RXRAT(   305 )      ! ACTP+ACO3=0.5000D+00*MO2+...
     &                  +    5.0000D-01 * RXRAT(   306 )      ! MEKP+ACO3=0.5000D+00*MO2+...
     &                  +    5.0000D-01 * RXRAT(   307 )      ! KETP+ACO3=0.5000D+00*MO2+...
     &                  +    5.0000D-01 * RXRAT(   308 )      ! MACP+ACO3=0.5000D+00*MO2+...
     &                  +    5.0000D-01 * RXRAT(   309 )      ! MCP+ACO3=0.5000D+00*MO2+...
     &                  +    5.0000D-01 * RXRAT(   310 )      ! MVKP+ACO3=0.5000D+00*MO2+...
     &                  +    5.0000D-01 * RXRAT(   311 )      ! UALP+ACO3=0.5000D+00*MO2+...
     &                  +                 RXRAT(   312 )      ! BALP+ACO3=MO2+BAL1
     &                  +                 RXRAT(   313 )      ! BAL1+ACO3=MO2+BAL2
     &                  +                 RXRAT(   314 )      ! ADDC+ACO3=MO2+0.2000D+...
     &                  +                 RXRAT(   315 )      ! MCTP+ACO3=MO2+HO2+MCTO
     &                  +                 RXRAT(   316 )      ! ORAP+ACO3=MO2+GLY
     &                  +                 RXRAT(   317 )      ! OLNN+ACO3=MO2+HO2+ONIT
     &                  +    5.0000D-01 * RXRAT(   318 )      ! OLND+ACO3=0.5000D+00*MO2+...
     &                  +                 RXRAT(   319 )      ! ADCN+ACO3=MO2+HO2+0.7000D+...
     &                  +                 RXRAT(   320 )      ! XO2+ACO3=MO2
     &                  +    1.4000D-01 * RXRAT(   324 )      ! HC3P+NO3=0.1400D+00*MO2+...
     &                  +    5.5000D-02 * RXRAT(   325 )      ! HC5P+NO3=0.5500D-01*MO2+...
     &                  +                 RXRAT(   341 )      ! ACO3+NO3=MO2+NO2
      LOSS(  MO2      ) =                 RXRAT(   172 )      ! MO2+NO=HO2+NO2+HCHO
     &                  +                 RXRAT(   212 )      ! MO2+HO2=OP1
     &                  +    2.0000D+00 * RXRAT(   248 )      ! MO2+MO2=0.7400D+00*HO2+...
     &                  +                 RXRAT(   249 )      ! MO2+ETHP=HO2+0.7500D+...
     &                  +    9.2000D-01 * RXRAT(   250 )      ! MO2+HC3P=0.8000D-01*MO2+...
     &                  +    9.8200D-01 * RXRAT(   251 )      ! MO2+HC5P=0.1800D-01*MO2+...
     &                  +                 RXRAT(   252 )      ! MO2+HC8P=0.9100D+00*HO2+...
     &                  +                 RXRAT(   253 )      ! MO2+ETEP=HO2+0.1950D+...
     &                  +                 RXRAT(   254 )      ! MO2+OLTP=HO2+0.1500D+...
     &                  +                 RXRAT(   255 )      ! MO2+OLIP=HO2+0.7500D+...
     &                  +                 RXRAT(   256 )      ! MO2+BENP=0.1600D+01*HO2+...
     &                  +                 RXRAT(   257 )      ! MO2+TLP1=HO2+HCHO+BALD
     &                  +                 RXRAT(   258 )      ! MO2+TOLP=0.2000D+01*HO2+...
     &                  +                 RXRAT(   259 )      ! MO2+PER1=0.2000D+01*HO2+...
     &                  +                 RXRAT(   260 )      ! MO2+XYL1=HO2+HCHO+BALD
     &                  +                 RXRAT(   261 )      ! MO2+XYLP=0.2000D+01*HO2+...
     &                  +                 RXRAT(   262 )      ! MO2+PER2=0.2000D+01*HO2+...
     &                  +                 RXRAT(   263 )      ! MO2+XYOP=0.2000D+01*HO2+...
     &                  +                 RXRAT(   264 )      ! MO2+ISOP=HO2+0.1310D+...
     &                  +                 RXRAT(   265 )      ! MO2+APIP=HO2+0.7500D+...
     &                  +                 RXRAT(   266 )      ! MO2+LIMP=HO2+0.1040D+...
     &                  +    1.0000D-01 * RXRAT(   267 )      ! MO2+ACO3=0.9000D+00*MO2+...
     &                  +    1.0000D-01 * RXRAT(   268 )      ! MO2+RCO3=0.9000D+00*MO2+...
     &                  +                 RXRAT(   269 )      ! MO2+ACTP=0.5000D+00*HO2+...
     &                  +                 RXRAT(   270 )      ! MO2+MEKP=0.8340D+00*HO2+...
     &                  +                 RXRAT(   271 )      ! MO2+KETP=HO2+0.7500D+...
     &                  +    7.5000D-01 * RXRAT(   272 )      ! MO2+MACP=0.2500D+00*MO2+...
     &                  +                 RXRAT(   273 )      ! MO2+MCP=NO2+HO2+0.1500D+...
     &                  +                 RXRAT(   274 )      ! MO2+MVKP=HO2+0.1160D+...
     &                  +                 RXRAT(   275 )      ! MO2+UALP=HO2+0.3050D+00*CO+...
     &                  +                 RXRAT(   276 )      ! MO2+BALP=HO2+BAL1+HCHO
     &                  +                 RXRAT(   277 )      ! MO2+BAL1=HO2+BAL2+HCHO
     &                  +                 RXRAT(   278 )      ! MO2+ADDC=0.2000D+01*HO2+...
     &                  +                 RXRAT(   279 )      ! MO2+MCTP=HO2+MCTO+HCHO
     &                  +                 RXRAT(   280 )      ! MO2+ORAP=HCHO+HO2+GLY
     &                  +                 RXRAT(   281 )      ! MO2+OLNN=0.2000D+01*HO2+...
     &                  +                 RXRAT(   282 )      ! MO2+OLND=0.5000D+00*HO2+...
     &                  +                 RXRAT(   283 )      ! MO2+ADCN=HO2+0.7000D+...
     &                  +                 RXRAT(   284 )      ! MO2+XO2=HO2+HCHO
     &                  +                 RXRAT(   322 )      ! MO2+NO3=HO2+HCHO+NO2

      PROD(  ALD      ) =    4.3400D-01 * RXRAT(    15 )      ! UALD=0.4340D+00*ALD+...
     &                  +                 RXRAT(    29 )      ! OP2=ALD+HO2+HO
     &                  +    2.0000D-01 * RXRAT(    31 )      ! ONIT=0.2000D+00*ALD+NO2+...
     &                  +    2.5000D-02 * RXRAT(    75 )      ! HC8+HO=0.2500D-01*ALD+...
     &                  +    4.0000D-01 * RXRAT(   101 )      ! DCB1+HO=0.4000D+00*ALD+...
     &                  +                 RXRAT(   107 )      ! EPX+HO=ALD+XO2+CO+HO2
     &                  +    7.1900D-01 * RXRAT(   111 )      ! ROH+HO=0.7190D+00*ALD+HO2+...
     &                  +                 RXRAT(   112 )      ! ETEG+HO=ALD+HO2
     &                  +    8.0000D-02 * RXRAT(   114 )      ! OP2+HO=0.8000D-01*ALD+...
     &                  +    4.4000D-01 * RXRAT(   127 )      ! OLT+O3=0.4400D+00*ALD+...
     &                  +    7.3000D-01 * RXRAT(   128 )      ! OLI+O3=0.7300D+00*ALD+...
     &                  +    6.5000D-01 * RXRAT(   131 )      ! API+O3=0.6500D+00*ALD+...
     &                  +    1.0000D-01 * RXRAT(   134 )      ! MVK+O3=0.1000D+00*ALD+...
     &                  +    3.3200D-01 * RXRAT(   152 )      ! UALD+NO3=0.3320D+00*ALD+...
     &                  +    1.3200D-01 * RXRAT(   174 )      ! HC3P+NO=0.1320D+00*ALD+...
     &                  +    2.0300D-01 * RXRAT(   175 )      ! HC5P+NO=0.2030D+00*ALD+...
     &                  +    1.5000D-01 * RXRAT(   176 )      ! HC8P+NO=0.1500D+00*ALD+...
     &                  +    2.0000D-01 * RXRAT(   177 )      ! ETEP+NO=0.2000D+00*ALD+NO2+...
     &                  +    4.4000D-01 * RXRAT(   178 )      ! OLTP+NO=0.4400D+00*ALD+...
     &                  +    6.8000D-01 * RXRAT(   179 )      ! OLIP+NO=0.6800D+00*ALD+...
     &                  +    2.7000D-02 * RXRAT(   188 )      ! ISOP+NO=0.2700D-01*ALD+...
     &                  +    4.3000D-01 * RXRAT(   189 )      ! APIP+NO=0.4300D+00*ALD+...
     &                  +    4.6000D-01 * RXRAT(   195 )      ! KETP+NO=0.4600D+00*ALD+...
     &                  +    7.0000D-01 * RXRAT(   198 )      ! MVKP+NO=0.7000D+00*ALD+...
     &                  +    2.7000D-01 * RXRAT(   199 )      ! UALP+NO=0.2700D+00*ALD+NO2+...
     &                  +    1.2400D+00 * RXRAT(   206 )      ! OLND+NO=0.1240D+01*ALD+...
     &                  +    1.9800D-01 * RXRAT(   250 )      ! HC3P+MO2=0.1980D+00*ALD+...
     &                  +    2.5100D-01 * RXRAT(   251 )      ! HC5P+MO2=0.2510D+00*ALD+...
     &                  +    1.9700D-01 * RXRAT(   252 )      ! HC8P+MO2=0.1970D+00*ALD+...
     &                  +    1.5000D-01 * RXRAT(   253 )      ! ETEP+MO2=0.1500D+00*ALD+...
     &                  +    7.0500D-01 * RXRAT(   254 )      ! OLTP+MO2=0.7050D+00*ALD+...
     &                  +    1.2800D+00 * RXRAT(   255 )      ! OLIP+MO2=0.1280D+01*ALD+...
     &                  +    2.3000D-02 * RXRAT(   264 )      ! ISOP+MO2=0.2300D-01*ALD+...
     &                  +    7.5000D-01 * RXRAT(   265 )      ! APIP+MO2=0.7500D+00*ALD+...
     &                  +    1.7500D+00 * RXRAT(   274 )      ! MVKP+MO2=0.1750D+01*ALD+...
     &                  +    2.0300D-01 * RXRAT(   275 )      ! UALP+MO2=0.2030D+00*ALD+...
     &                  +    9.3000D-01 * RXRAT(   282 )      ! OLND+MO2=0.9300D+00*ALD+...
     &                  +    2.7300D-01 * RXRAT(   286 )      ! HC3P+ACO3=0.2730D+00*ALD+...
     &                  +    3.8100D-01 * RXRAT(   287 )      ! HC5P+ACO3=0.3810D+00*ALD+...
     &                  +    2.1700D-01 * RXRAT(   288 )      ! HC8P+ACO3=0.2170D+00*ALD+...
     &                  +    2.0000D-01 * RXRAT(   289 )      ! ETEP+ACO3=0.2000D+00*ALD+...
     &                  +    9.4000D-01 * RXRAT(   290 )      ! OLTP+ACO3=0.9400D+00*ALD+...
     &                  +    1.7100D+00 * RXRAT(   291 )      ! OLIP+ACO3=0.1710D+01*ALD+...
     &                  +                 RXRAT(   301 )      ! APIP+ACO3=ALD+0.5000D+...
     &                  +    2.3000D+00 * RXRAT(   310 )      ! MVKP+ACO3=0.2300D+01*ALD+...
     &                  +    2.7000D-01 * RXRAT(   311 )      ! UALP+ACO3=0.2700D+00*ALD+...
     &                  +    1.2400D+00 * RXRAT(   318 )      ! OLND+ACO3=0.1240D+01*ALD+...
     &                  +    1.4700D-01 * RXRAT(   324 )      ! HC3P+NO3=0.1470D+00*ALD+...
     &                  +    2.4100D-01 * RXRAT(   325 )      ! HC5P+NO3=0.2410D+00*ALD+...
     &                  +    2.0300D-01 * RXRAT(   326 )      ! HC8P+NO3=0.2030D+00*ALD+...
     &                  +    2.0000D-01 * RXRAT(   327 )      ! ETEP+NO3=0.2000D+00*ALD+...
     &                  +    4.7000D-01 * RXRAT(   328 )      ! OLTP+NO3=0.4700D+00*ALD+...
     &                  +    7.2000D-01 * RXRAT(   329 )      ! OLIP+NO3=0.7200D+00*ALD+...
     &                  +    3.1000D-02 * RXRAT(   338 )      ! ISOP+NO3=0.3100D-01*ALD+...
     &                  +                 RXRAT(   339 )      ! APIP+NO3=ALD+NO2+HO2+KET
     &                  +    7.0000D-01 * RXRAT(   348 )      ! MVKP+NO3=0.7000D+00*ALD+...
     &                  +    2.7000D-01 * RXRAT(   349 )      ! UALP+NO3=0.2700D+00*ALD+...
     &                  +    1.2400D+00 * RXRAT(   356 )      ! OLND+NO3=0.1240D+01*ALD+...
     &                  +    6.4000D-01 * RXRAT(   359 )      ! OLNN+OLND=0.6400D+00*ALD+...
     &                  +    1.2100D+00 * RXRAT(   360 )      ! OLND+OLND=0.1210D+01*ALD+...
      LOSS(  ALD      ) =                 RXRAT(    13 )      ! ALD=HO2+ETHP+CO
     &                  +                 RXRAT(    91 )      ! ALD+HO=RCO3
     &                  +                 RXRAT(   150 )      ! ALD+NO3=RCO3+HNO3

      PROD(  ETHP     ) =                 RXRAT(    13 )      ! ALD=ETHP+HO2+CO
     &                  +    5.0000D-01 * RXRAT(    16 )      ! MEK=0.5000D+00*ETHP+...
     &                  +                 RXRAT(    17 )      ! KET=ETHP+ACO3
     &                  +                 RXRAT(    72 )      ! ETH+HO=ETHP
     &                  +    6.0000D-02 * RXRAT(   127 )      ! OLT+O3=0.6000D-01*ETHP+...
     &                  +    7.0000D-02 * RXRAT(   128 )      ! OLI+O3=0.7000D-01*ETHP+...
     &                  +    2.0000D-01 * RXRAT(   131 )      ! API+O3=0.2000D+00*ETHP+...
     &                  +    1.6000D-01 * RXRAT(   132 )      ! LIM+O3=0.1600D+00*ETHP+...
     &                  +    4.8000D-02 * RXRAT(   174 )      ! HC3P+NO=0.4800D-01*ETHP+...
     &                  +    2.3100D-01 * RXRAT(   175 )      ! HC5P+NO=0.2310D+00*ETHP+...
     &                  +    1.3300D-01 * RXRAT(   176 )      ! HC8P+NO=0.1330D+00*ETHP+...
     &                  +                 RXRAT(   192 )      ! RCO3+NO=ETHP+NO2
     &                  +    4.4000D-01 * RXRAT(   232 )      ! RCO3+HO2=0.4400D+00*ETHP+...
     &                  +    2.6000D-02 * RXRAT(   250 )      ! HC3P+MO2=0.2600D-01*ETHP+...
     &                  +    1.4000D-01 * RXRAT(   251 )      ! HC5P+MO2=0.1400D+00*ETHP+...
     &                  +    9.0000D-02 * RXRAT(   252 )      ! HC8P+MO2=0.9000D-01*ETHP+...
     &                  +    2.6000D-02 * RXRAT(   286 )      ! HC3P+ACO3=0.2600D-01*ETHP+...
     &                  +    1.4000D-01 * RXRAT(   287 )      ! HC5P+ACO3=0.1400D+00*ETHP+...
     &                  +    6.7000D-02 * RXRAT(   288 )      ! HC8P+ACO3=0.6700D-01*ETHP+...
     &                  +                 RXRAT(   304 )      ! RCO3+ACO3=ETHP+MO2
     &                  +    2.0000D+00 * RXRAT(   321 )      ! RCO3+RCO3=0.2000D+01*ETHP
     &                  +    5.0300D-01 * RXRAT(   324 )      ! HC3P+NO3=0.5030D+00*ETHP+...
     &                  +    2.8000D-01 * RXRAT(   325 )      ! HC5P+NO3=0.2800D+00*ETHP+...
     &                  +    1.8000D-01 * RXRAT(   326 )      ! HC8P+NO3=0.1800D+00*ETHP+...
     &                  +                 RXRAT(   342 )      ! RCO3+NO3=ETHP+NO2
     &                  +                 RXRAT(   362 )      ! XO2+RCO3=ETHP
      LOSS(  ETHP     ) =                 RXRAT(   173 )      ! ETHP+NO=HO2+NO2+ACD
     &                  +                 RXRAT(   213 )      ! ETHP+HO2=OP2
     &                  +                 RXRAT(   249 )      ! ETHP+MO2=HO2+0.7500D+...
     &                  +                 RXRAT(   285 )      ! ETHP+ACO3=0.5000D+00*HO2+...
     &                  +                 RXRAT(   323 )      ! ETHP+NO3=HO2+NO2+ACD

      PROD(  ACT      ) =    3.0000D-02 * RXRAT(   127 )      ! OLT+O3=0.3000D-01*ACT+...
     &                  +    1.1000D-01 * RXRAT(   128 )      ! OLI+O3=0.1100D+00*ACT+...
     &                  +    1.6500D-01 * RXRAT(   174 )      ! HC3P+NO=0.1650D+00*ACT+...
     &                  +    2.1700D-01 * RXRAT(   175 )      ! HC5P+NO=0.2170D+00*ACT+...
     &                  +    6.0000D-02 * RXRAT(   178 )      ! OLTP+NO=0.6000D-01*ACT+...
     &                  +    2.0000D-01 * RXRAT(   179 )      ! OLIP+NO=0.2000D+00*ACT+...
     &                  +    1.1000D-01 * RXRAT(   189 )      ! APIP+NO=0.1100D+00*ACT+...
     &                  +    9.5000D-02 * RXRAT(   324 )      ! HC3P+NO3=0.9500D-01*ACT+...
     &                  +    2.4700D-01 * RXRAT(   325 )      ! HC5P+NO3=0.2470D+00*ACT+...
     &                  +    9.0000D-02 * RXRAT(   328 )      ! OLTP+NO3=0.9000D-01*ACT+...
     &                  +    2.0000D-01 * RXRAT(   329 )      ! OLIP+NO3=0.2000D+00*ACT+...
      LOSS(  ACT      ) =                 RXRAT(    14 )      ! ACT=MO2+ACO3
     &                  +                 RXRAT(    92 )      ! ACT+HO=ACTP

      PROD(  UALD     ) =    7.0000D-01 * RXRAT(    20 )      ! MVK=0.7000D+00*UALD+...
     &                  +    6.8000D-01 * RXRAT(   190 )      ! LIMP+NO=0.6800D+00*UALD+...
      LOSS(  UALD     ) =                 RXRAT(    15 )      ! UALD=0.1220D+01*HO2+...
     &                  +                 RXRAT(    98 )      ! UALD+HO=0.3130D+00*ACO3+...
     &                  +                 RXRAT(   135 )      ! UALD+O3=0.1000D+00*HO+...
     &                  +                 RXRAT(   152 )      ! UALD+NO3=HO2+XO2+0.6680D+...

      PROD(  KET      ) =    2.1600D-01 * RXRAT(    15 )      ! UALD=0.2160D+00*KET+...
     &                  +    8.0000D-01 * RXRAT(    31 )      ! ONIT=0.8000D+00*KET+NO2+...
     &                  +    7.8000D-01 * RXRAT(   101 )      ! DCB1+HO=0.7800D+00*KET+...
     &                  +    4.1000D-01 * RXRAT(   114 )      ! OP2+HO=0.4100D+00*KET+...
     &                  +    1.7000D-02 * RXRAT(   128 )      ! OLI+O3=0.1700D-01*KET+...
     &                  +    5.3000D-01 * RXRAT(   131 )      ! API+O3=0.5300D+00*KET+...
     &                  +    2.8000D-02 * RXRAT(   135 )      ! UALD+O3=0.2800D-01*KET+...
     &                  +    3.3000D-02 * RXRAT(   175 )      ! HC5P+NO=0.3300D-01*KET+...
     &                  +    6.4200D-01 * RXRAT(   176 )      ! HC8P+NO=0.6420D+00*KET+...
     &                  +    9.0000D-02 * RXRAT(   179 )      ! OLIP+NO=0.9000D-01*KET+...
     &                  +    4.4000D-01 * RXRAT(   189 )      ! APIP+NO=0.4400D+00*KET+...
     &                  +    7.0000D-01 * RXRAT(   199 )      ! UALP+NO=0.7000D+00*KET+NO2+...
     &                  +    4.6400D-01 * RXRAT(   206 )      ! OLND+NO=0.4640D+00*KET+...
     &                  +    4.9700D-01 * RXRAT(   250 )      ! HC3P+MO2=0.4970D+00*KET+...
     &                  +    6.1800D-01 * RXRAT(   251 )      ! HC5P+MO2=0.6180D+00*KET+...
     &                  +    6.5200D-01 * RXRAT(   252 )      ! HC8P+MO2=0.6520D+00*KET+...
     &                  +    4.5000D-02 * RXRAT(   254 )      ! OLTP+MO2=0.4500D-01*KET+...
     &                  +    2.1800D-01 * RXRAT(   255 )      ! OLIP+MO2=0.2180D+00*KET+...
     &                  +    7.5000D-01 * RXRAT(   265 )      ! APIP+MO2=0.7500D+00*KET+...
     &                  +    5.2500D-01 * RXRAT(   275 )      ! UALP+MO2=0.5250D+00*KET+...
     &                  +    3.4800D-01 * RXRAT(   282 )      ! OLND+MO2=0.3480D+00*KET+...
     &                  +    6.6200D-01 * RXRAT(   286 )      ! HC3P+ACO3=0.6620D+00*KET+...
     &                  +    8.2400D-01 * RXRAT(   287 )      ! HC5P+ACO3=0.8240D+00*KET+...
     &                  +    6.4200D-01 * RXRAT(   288 )      ! HC8P+ACO3=0.6420D+00*KET+...
     &                  +    6.0000D-02 * RXRAT(   290 )      ! OLTP+ACO3=0.6000D-01*KET+...
     &                  +    2.9000D-01 * RXRAT(   291 )      ! OLIP+ACO3=0.2900D+00*KET+...
     &                  +                 RXRAT(   301 )      ! APIP+ACO3=KET+0.5000D+...
     &                  +    7.0000D-01 * RXRAT(   311 )      ! UALP+ACO3=0.7000D+00*KET+...
     &                  +    4.6400D-01 * RXRAT(   318 )      ! OLND+ACO3=0.4640D+00*KET+...
     &                  +    6.0000D-02 * RXRAT(   325 )      ! HC5P+NO3=0.6000D-01*KET+...
     &                  +    8.6900D-01 * RXRAT(   326 )      ! HC8P+NO3=0.8690D+00*KET+...
     &                  +    1.1000D-01 * RXRAT(   329 )      ! OLIP+NO3=0.1100D+00*KET+...
     &                  +                 RXRAT(   339 )      ! APIP+NO3=KET+NO2+ALD+HO2
     &                  +    7.0000D-01 * RXRAT(   349 )      ! UALP+NO3=0.7000D+00*KET+...
     &                  +    4.6400D-01 * RXRAT(   356 )      ! OLND+NO3=0.4640D+00*KET+...
     &                  +    1.4900D-01 * RXRAT(   359 )      ! OLNN+OLND=0.1490D+00*KET+...
     &                  +    2.8500D-01 * RXRAT(   360 )      ! OLND+OLND=0.2850D+00*KET+...
      LOSS(  KET      ) =                 RXRAT(    17 )      ! KET=ETHP+ACO3
     &                  +                 RXRAT(    94 )      ! KET+HO=KETP

      PROD(  MEK      ) =    1.3000D-01 * RXRAT(   102 )      ! DCB2+HO=0.1300D+00*MEK+...
     &                  +    6.0000D-02 * RXRAT(   127 )      ! OLT+O3=0.6000D-01*MEK+...
     &                  +    4.2000D-02 * RXRAT(   174 )      ! HC3P+NO=0.4200D-01*MEK+...
     &                  +    3.3000D-02 * RXRAT(   175 )      ! HC5P+NO=0.3300D-01*MEK+...
     &                  +    1.3000D-01 * RXRAT(   178 )      ! OLTP+NO=0.1300D+00*MEK+...
     &                  +    7.5000D-02 * RXRAT(   324 )      ! HC3P+NO3=0.7500D-01*MEK+...
     &                  +    6.3000D-02 * RXRAT(   325 )      ! HC5P+NO3=0.6300D-01*MEK+...
     &                  +    1.8000D-01 * RXRAT(   328 )      ! OLTP+NO3=0.1800D+00*MEK+...
      LOSS(  MEK      ) =                 RXRAT(    16 )      ! MEK=0.5000D+00*MO2+0.5000D+...
     &                  +                 RXRAT(    93 )      ! MEK+HO=MEKP

      PROD(  HKET     ) =    2.4000D-02 * RXRAT(    75 )      ! HC8+HO=0.2400D-01*HKET+...
     &                  +                 RXRAT(   122 )      ! MPAN+HO=HKET+NO2
     &                  +                 RXRAT(   124 )      ! NALD+HO=HKET+XO2+NO2
     &                  +    7.0000D-02 * RXRAT(   125 )      ! ISON+HO=0.7000D-01*HKET+...
     &                  +    1.0000D-02 * RXRAT(   127 )      ! OLT+O3=0.1000D-01*HKET+...
     &                  +    4.4000D-02 * RXRAT(   128 )      ! OLI+O3=0.4400D-01*HKET+...
     &                  +    2.7200D-01 * RXRAT(   175 )      ! HC5P+NO=0.2720D+00*HKET+...
     &                  +    2.0000D-02 * RXRAT(   179 )      ! OLIP+NO=0.2000D-01*HKET+...
     &                  +    2.9000D-02 * RXRAT(   188 )      ! ISOP+NO=0.2900D-01*HKET+...
     &                  +                 RXRAT(   197 )      ! MCP+NO=HKET+0.5000D+00*HO2+...
     &                  +    3.2000D-01 * RXRAT(   202 )      ! ADDC+NO=0.3200D+00*HKET+...
     &                  +    1.6000D-02 * RXRAT(   264 )      ! ISOP+MO2=0.1600D-01*HKET+...
     &                  +    5.0000D-01 * RXRAT(   273 )      ! MCP+MO2=0.5000D+00*HKET+...
     &                  +    3.2000D-01 * RXRAT(   278 )      ! ADDC+MO2=0.3200D+00*HKET+...
     &                  +    5.0000D-01 * RXRAT(   309 )      ! MCP+ACO3=0.5000D+00*HKET+...
     &                  +    3.2000D-01 * RXRAT(   314 )      ! ADDC+ACO3=0.3200D+00*HKET+...
     &                  +    2.7500D-01 * RXRAT(   325 )      ! HC5P+NO3=0.2750D+00*HKET+...
     &                  +    4.0000D-02 * RXRAT(   329 )      ! OLIP+NO3=0.4000D-01*HKET+...
     &                  +    3.3000D-02 * RXRAT(   338 )      ! ISOP+NO3=0.3300D-01*HKET+...
     &                  +                 RXRAT(   347 )      ! MCP+NO3=HKET+HO2+HCHO+NO2
     &                  +    3.2000D-01 * RXRAT(   352 )      ! ADDC+NO3=0.3200D+00*HKET+...
      LOSS(  HKET     ) =                 RXRAT(    18 )      ! HKET=HO2+ACO3+HCHO
     &                  +                 RXRAT(    95 )      ! HKET+HO=HO2+MGLY

      PROD(  MACR     ) =                 RXRAT(   115 )      ! ISHP+HO=MACR+HO+0.9040D+...
     &                  +    3.9000D-01 * RXRAT(   129 )      ! DIEN+O3=0.3900D+00*MACR+...
     &                  +    4.6100D-01 * RXRAT(   130 )      ! ISO+O3=0.4610D+00*MACR+...
     &                  +    7.9000D-01 * RXRAT(   132 )      ! LIM+O3=0.7900D+00*MACR+...
     &                  +    9.0000D-01 * RXRAT(   144 )      ! DIEN+NO3=0.9000D+00*MACR+...
     &                  +    2.8000D-01 * RXRAT(   188 )      ! ISOP+NO=0.2800D+00*MACR+...
     &                  +    1.5900D-01 * RXRAT(   264 )      ! ISOP+MO2=0.1590D+00*MACR+...
     &                  +    3.0800D-01 * RXRAT(   266 )      ! LIMP+MO2=0.3080D+00*MACR+...
     &                  +    2.1900D-01 * RXRAT(   300 )      ! ISOP+ACO3=0.2190D+00*MACR+...
     &                  +    3.0800D-01 * RXRAT(   302 )      ! LIMP+ACO3=0.3080D+00*MACR+...
     &                  +    3.1800D-01 * RXRAT(   338 )      ! ISOP+NO3=0.3180D+00*MACR+...
     &                  +    6.1500D-01 * RXRAT(   340 )      ! LIMP+NO3=0.6150D+00*MACR+...
      LOSS(  MACR     ) =                 RXRAT(    19 )      ! MACR=0.3400D+00*HO+0.6600D+...
     &                  +                 RXRAT(    96 )      ! MACR+HO=0.5700D+00*MACP+...
     &                  +                 RXRAT(   133 )      ! MACR+O3=0.1900D+00*HO+...
     &                  +                 RXRAT(   151 )      ! MACR+NO3=0.6800D+00*HCHO+...

      PROD(  MACP     ) =    3.3000D-01 * RXRAT(    19 )      ! MACR=0.3300D+00*MACP+...
     &                  +    3.0000D-01 * RXRAT(    20 )      ! MVK=0.3000D+00*MACP+...
     &                  +    5.7000D-01 * RXRAT(    96 )      ! MACR+HO=0.5700D+00*MACP+...
     &                  +    2.1000D-01 * RXRAT(   103 )      ! DCB3+HO=0.2100D+00*MACP+...
     &                  +                 RXRAT(   116 )      ! MAHP+HO=MACP
     &                  +    1.0000D-01 * RXRAT(   130 )      ! ISO+O3=0.1000D+00*MACP+...
     &                  +    3.2000D-01 * RXRAT(   151 )      ! MACR+NO3=0.3200D+00*MACP+...
     &                  +                 RXRAT(   159 )      ! MPAN+NO3=MACP+NO2
     &                  +                 RXRAT(   171 )      ! MPAN=MACP+NO2
      LOSS(  MACP     ) =                 RXRAT(   170 )      ! MACP+NO2=MPAN
     &                  +                 RXRAT(   196 )      ! MACP+NO=0.6500D+00*MO2+...
     &                  +                 RXRAT(   236 )      ! MACP+HO2=MAHP
     &                  +                 RXRAT(   272 )      ! MACP+MO2=0.5000D+00*HO2+...
     &                  +                 RXRAT(   308 )      ! MACP+ACO3=0.6350D+00*ORA2+...
     &                  +                 RXRAT(   346 )      ! MACP+NO3=HCHO+0.5380D+...

      PROD(  XO2      ) =    3.4000D-01 * RXRAT(    19 )      ! MACR=0.3400D+00*XO2+...
     &                  +    2.0000D-01 * RXRAT(    25 )      ! DCB1=0.2000D+00*XO2+...
     &                  +    2.0000D-01 * RXRAT(    26 )      ! DCB2=0.2000D+00*XO2+...
     &                  +                 RXRAT(   107 )      ! EPX+HO=XO2+HO2+CO+ALD
     &                  +    7.0000D-02 * RXRAT(   114 )      ! OP2+HO=0.7000D-01*XO2+...
     &                  +    3.5000D-01 * RXRAT(   119 )      ! PAA+HO=0.3500D+00*XO2+...
     &                  +                 RXRAT(   120 )      ! PAN+HO=XO2+NO3+HCHO
     &                  +                 RXRAT(   121 )      ! PPN+HO=XO2+NO3+HCHO
     &                  +                 RXRAT(   124 )      ! NALD+HO=XO2+NO2+HKET
     &                  +    1.3000D-01 * RXRAT(   129 )      ! DIEN+O3=0.1300D+00*XO2+...
     &                  +    1.0000D-02 * RXRAT(   134 )      ! MVK+O3=0.1000D-01*XO2+...
     &                  +    1.0000D-01 * RXRAT(   135 )      ! UALD+O3=0.1000D+00*XO2+...
     &                  +    6.0000D-01 * RXRAT(   136 )      ! DCB1+O3=0.6000D+00*XO2+HO2+...
     &                  +    6.0000D-01 * RXRAT(   137 )      ! DCB2+O3=0.6000D+00*XO2+HO2+...
     &                  +    6.8000D-01 * RXRAT(   151 )      ! MACR+NO3=0.6800D+00*XO2+...
     &                  +                 RXRAT(   152 )      ! UALD+NO3=XO2+HO2+0.6680D+...
     &                  +    8.9000D-02 * RXRAT(   174 )      ! HC3P+NO=0.8900D-01*XO2+...
     &                  +    2.3500D-01 * RXRAT(   175 )      ! HC5P+NO=0.2350D+00*XO2+...
     &                  +    4.1600D-01 * RXRAT(   176 )      ! HC8P+NO=0.4160D+00*XO2+...
     &                  +    1.6000D-01 * RXRAT(   195 )      ! KETP+NO=0.1600D+00*XO2+...
     &                  +    7.0000D-01 * RXRAT(   198 )      ! MVKP+NO=0.7000D+00*XO2+...
     &                  +    2.6000D-02 * RXRAT(   250 )      ! HC3P+MO2=0.2600D-01*XO2+...
     &                  +    1.9100D-01 * RXRAT(   251 )      ! HC5P+MO2=0.1910D+00*XO2+...
     &                  +    2.8100D-01 * RXRAT(   252 )      ! HC8P+MO2=0.2810D+00*XO2+...
     &                  +    1.1600D+00 * RXRAT(   274 )      ! MVKP+MO2=0.1160D+01*XO2+...
     &                  +    2.6000D-02 * RXRAT(   286 )      ! HC3P+ACO3=0.2600D-01*XO2+...
     &                  +    1.9100D-01 * RXRAT(   287 )      ! HC5P+ACO3=0.1910D+00*XO2+...
     &                  +    2.0800D-01 * RXRAT(   288 )      ! HC8P+ACO3=0.2080D+00*XO2+...
     &                  +    1.1600D+00 * RXRAT(   310 )      ! MVKP+ACO3=0.1160D+01*XO2+...
     &                  +    9.2000D-02 * RXRAT(   324 )      ! HC3P+NO3=0.9200D-01*XO2+...
     &                  +    4.8500D-01 * RXRAT(   325 )      ! HC5P+NO3=0.4850D+00*XO2+...
     &                  +    5.6300D-01 * RXRAT(   326 )      ! HC8P+NO3=0.5630D+00*XO2+...
     &                  +    7.0000D-01 * RXRAT(   348 )      ! MVKP+NO3=0.7000D+00*XO2+...
      LOSS(  XO2      ) =                 RXRAT(   208 )      ! XO2+NO=NO2
     &                  +                 RXRAT(   247 )      ! XO2+HO2=OP2
     &                  +                 RXRAT(   284 )      ! XO2+MO2=HO2+HCHO
     &                  +                 RXRAT(   320 )      ! XO2+ACO3=MO2
     &                  +                 RXRAT(   361 )      ! XO2+NO3=NO2
     &                  +                 RXRAT(   362 )      ! XO2+RCO3=ETHP
     &                  +    2.0000D+00 * RXRAT(   363 )      ! XO2+XO2=

      PROD(  MVK      ) =    1.8900D-01 * RXRAT(   130 )      ! ISO+O3=0.1890D+00*MVK+...
     &                  +    4.4000D-01 * RXRAT(   188 )      ! ISOP+NO=0.4400D+00*MVK+...
     &                  +    2.5000D-01 * RXRAT(   264 )      ! ISOP+MO2=0.2500D+00*MVK+...
     &                  +    3.0500D-01 * RXRAT(   300 )      ! ISOP+ACO3=0.3050D+00*MVK+...
     &                  +    5.0000D-01 * RXRAT(   338 )      ! ISOP+NO3=0.5000D+00*MVK+...
      LOSS(  MVK      ) =                 RXRAT(    20 )      ! MVK=0.3000D+00*MO2+0.3000D+...
     &                  +                 RXRAT(    97 )      ! MVK+HO=MVKP
     &                  +                 RXRAT(   134 )      ! MVK+O3=0.1600D+00*HO+...

      PROD(  GLY      ) =    5.0000D-01 * RXRAT(    25 )      ! DCB1=0.5000D+00*GLY+...
     &                  +    5.0000D-01 * RXRAT(    26 )      ! DCB2=0.5000D+00*GLY+...
     &                  +    6.5000D-01 * RXRAT(    80 )      ! ACE+HO=0.6500D+00*GLY+...
     &                  +    1.0000D-01 * RXRAT(   101 )      ! DCB1+HO=0.1000D+00*GLY+...
     &                  +    1.0000D-01 * RXRAT(   102 )      ! DCB2+HO=0.1000D+00*GLY+...
     &                  +    2.7000D-01 * RXRAT(   103 )      ! DCB3+HO=0.2700D+00*GLY+...
     &                  +    4.9100D-01 * RXRAT(   135 )      ! UALD+O3=0.4910D+00*GLY+...
     &                  +    5.0000D-02 * RXRAT(   136 )      ! DCB1+O3=0.5000D-01*GLY+HO2+...
     &                  +    5.0000D-02 * RXRAT(   137 )      ! DCB2+O3=0.5000D-01*GLY+HO2+...
     &                  +    4.8000D-01 * RXRAT(   138 )      ! DCB3+O3=0.4800D+00*GLY+HO2+...
     &                  +                 RXRAT(   139 )      ! EPX+O3=GLY+0.1500D+01*HO2+...
     &                  +                 RXRAT(   157 )      ! EPX+NO3=GLY+0.1500D+01*HO2+...
     &                  +    9.1800D-01 * RXRAT(   180 )      ! BENP+NO=0.9180D+00*GLY+...
     &                  +    3.5000D-01 * RXRAT(   187 )      ! XYOP+NO=0.3500D+00*GLY+...
     &                  +    2.1000D-02 * RXRAT(   188 )      ! ISOP+NO=0.2100D-01*GLY+...
     &                  +    1.8000D-01 * RXRAT(   199 )      ! UALP+NO=0.1800D+00*GLY+NO2+...
     &                  +    6.8000D-01 * RXRAT(   202 )      ! ADDC+NO=0.6800D+00*GLY+NO2+...
     &                  +                 RXRAT(   204 )      ! ORAP+NO=GLY+NO2+HO2
     &                  +                 RXRAT(   207 )      ! ADCN+NO=GLY+0.2000D+01*NO2+OP2
     &                  +    5.0000D-02 * RXRAT(   250 )      ! HC3P+MO2=0.5000D-01*GLY+...
     &                  +    6.0000D-01 * RXRAT(   256 )      ! BENP+MO2=0.6000D+00*GLY+...
     &                  +    2.7100D-01 * RXRAT(   258 )      ! TOLP+MO2=0.2710D+00*GLY+...
     &                  +    3.6800D-01 * RXRAT(   263 )      ! XYOP+MO2=0.3680D+00*GLY+...
     &                  +    1.8000D-02 * RXRAT(   264 )      ! ISOP+MO2=0.1800D-01*GLY+...
     &                  +    1.3500D-01 * RXRAT(   275 )      ! UALP+MO2=0.1350D+00*GLY+...
     &                  +    6.8000D-01 * RXRAT(   278 )      ! ADDC+MO2=0.6800D+00*GLY+...
     &                  +                 RXRAT(   280 )      ! ORAP+MO2=GLY+HO2+HCHO
     &                  +    7.0000D-01 * RXRAT(   283 )      ! ADCN+MO2=0.7000D+00*GLY+...
     &                  +    6.7000D-02 * RXRAT(   286 )      ! HC3P+ACO3=0.6700D-01*GLY+...
     &                  +    6.0000D-01 * RXRAT(   292 )      ! BENP+ACO3=0.6000D+00*GLY+...
     &                  +    3.6800D-01 * RXRAT(   299 )      ! XYOP+ACO3=0.3680D+00*GLY+...
     &                  +    1.8000D-01 * RXRAT(   311 )      ! UALP+ACO3=0.1800D+00*GLY+...
     &                  +    6.8000D-01 * RXRAT(   314 )      ! ADDC+ACO3=0.6800D+00*GLY+...
     &                  +                 RXRAT(   316 )      ! ORAP+ACO3=GLY+MO2
     &                  +    7.0000D-01 * RXRAT(   319 )      ! ADCN+ACO3=0.7000D+00*GLY+...
     &                  +                 RXRAT(   330 )      ! BENP+NO3=GLY+NO2+0.5000D+...
     &                  +    3.6800D-01 * RXRAT(   337 )      ! XYOP+NO3=0.3680D+00*GLY+...
     &                  +    2.4000D-02 * RXRAT(   338 )      ! ISOP+NO3=0.2400D-01*GLY+...
     &                  +    1.8000D-01 * RXRAT(   349 )      ! UALP+NO3=0.1800D+00*GLY+...
     &                  +    6.8000D-01 * RXRAT(   352 )      ! ADDC+NO3=0.6800D+00*GLY+...
     &                  +                 RXRAT(   354 )      ! ORAP+NO3=GLY+NO2+HO2
     &                  +                 RXRAT(   357 )      ! ADCN+NO3=GLY+0.2000D+...
      LOSS(  GLY      ) =                 RXRAT(    21 )      ! GLY=0.2000D+01*CO
     &                  +                 RXRAT(    22 )      ! GLY=HCHO+CO
     &                  +                 RXRAT(    23 )      ! GLY=0.2000D+01*HO2+0.2000D+...
     &                  +                 RXRAT(    99 )      ! GLY+HO=HO2+0.2000D+01*CO
     &                  +                 RXRAT(   153 )      ! GLY+NO3=HO2+0.2000D+01*CO+HNO3

      PROD(  MGLY     ) =    5.0000D-01 * RXRAT(    25 )      ! DCB1=0.5000D+00*MGLY+...
     &                  +    5.0000D-01 * RXRAT(    26 )      ! DCB2=0.5000D+00*MGLY+...
     &                  +                 RXRAT(    95 )      ! HKET+HO=MGLY+HO2
     &                  +    1.0000D-02 * RXRAT(   101 )      ! DCB1+HO=0.1000D-01*MGLY+...
     &                  +    1.0000D-02 * RXRAT(   102 )      ! DCB2+HO=0.1000D-01*MGLY+...
     &                  +    1.0000D-02 * RXRAT(   103 )      ! DCB3+HO=0.1000D-01*MGLY+...
     &                  +    5.0000D-01 * RXRAT(   133 )      ! MACR+O3=0.5000D+00*MGLY+...
     &                  +    5.4000D-01 * RXRAT(   134 )      ! MVK+O3=0.5400D+00*MGLY+...
     &                  +    3.0000D-03 * RXRAT(   135 )      ! UALD+O3=0.3000D-02*MGLY+...
     &                  +    8.0000D-02 * RXRAT(   136 )      ! DCB1+O3=0.8000D-01*MGLY+...
     &                  +    8.0000D-02 * RXRAT(   137 )      ! DCB2+O3=0.8000D-01*MGLY+...
     &                  +    6.8000D-01 * RXRAT(   151 )      ! MACR+NO3=0.6800D+00*MGLY+...
     &                  +    5.0000D-01 * RXRAT(   183 )      ! PER1+NO=0.5000D+00*MGLY+...
     &                  +    9.5000D-01 * RXRAT(   186 )      ! PER2+NO=0.9500D+00*MGLY+...
     &                  +    6.0000D-01 * RXRAT(   187 )      ! XYOP+NO=0.6000D+00*MGLY+...
     &                  +    5.4000D-01 * RXRAT(   195 )      ! KETP+NO=0.5400D+00*MGLY+...
     &                  +    3.0000D-01 * RXRAT(   198 )      ! MVKP+NO=0.3000D+00*MGLY+...
     &                  +    2.1000D-01 * RXRAT(   199 )      ! UALP+NO=0.2100D+00*MGLY+...
     &                  +                 RXRAT(   259 )      ! PER1+MO2=MGLY+HCHO+0.2000D+...
     &                  +                 RXRAT(   262 )      ! PER2+MO2=MGLY+HCHO+0.2000D+...
     &                  +    6.3200D-01 * RXRAT(   263 )      ! XYOP+MO2=0.6320D+00*MGLY+...
     &                  +    5.0000D-01 * RXRAT(   274 )      ! MVKP+MO2=0.5000D+00*MGLY+...
     &                  +    1.0500D-01 * RXRAT(   275 )      ! UALP+MO2=0.1050D+00*MGLY+...
     &                  +                 RXRAT(   295 )      ! PER1+ACO3=MGLY+MO2+HO2+DCB1
     &                  +                 RXRAT(   298 )      ! PER2+ACO3=MGLY+MO2+HO2+...
     &                  +    6.3200D-01 * RXRAT(   299 )      ! XYOP+ACO3=0.6320D+00*MGLY+...
     &                  +    5.0000D-01 * RXRAT(   310 )      ! MVKP+ACO3=0.5000D+00*MGLY+...
     &                  +    1.0500D-01 * RXRAT(   311 )      ! UALP+ACO3=0.1050D+00*MGLY+...
     &                  +    5.0000D-01 * RXRAT(   333 )      ! PER1+NO3=0.5000D+00*MGLY+...
     &                  +                 RXRAT(   336 )      ! PER2+NO3=MGLY+NO2+HO2+DCB1+...
     &                  +    6.3200D-01 * RXRAT(   337 )      ! XYOP+NO3=0.6320D+00*MGLY+...
     &                  +    3.0000D-01 * RXRAT(   348 )      ! MVKP+NO3=0.3000D+00*MGLY+...
     &                  +    2.1000D-01 * RXRAT(   349 )      ! UALP+NO3=0.2100D+00*MGLY+...
      LOSS(  MGLY     ) =                 RXRAT(    24 )      ! MGLY=HO2+ACO3+CO
     &                  +                 RXRAT(   100 )      ! MGLY+HO=ACO3+CO
     &                  +                 RXRAT(   154 )      ! MGLY+NO3=ACO3+CO+HNO3

      PROD(  DCB1     ) =    7.0000D-01 * RXRAT(   137 )      ! DCB2+O3=0.7000D+00*DCB1+...
     &                  +    7.0000D-01 * RXRAT(   138 )      ! DCB3+O3=0.7000D+00*DCB1+...
     &                  +    5.0000D-01 * RXRAT(   183 )      ! PER1+NO=0.5000D+00*DCB1+...
     &                  +    9.5000D-01 * RXRAT(   186 )      ! PER2+NO=0.9500D+00*DCB1+...
     &                  +    7.0000D-01 * RXRAT(   187 )      ! XYOP+NO=0.7000D+00*DCB1+...
     &                  +    6.7000D-01 * RXRAT(   194 )      ! MEKP+NO=0.6700D+00*DCB1+...
     &                  +                 RXRAT(   259 )      ! PER1+MO2=DCB1+HCHO+MGLY+...
     &                  +                 RXRAT(   262 )      ! PER2+MO2=DCB1+HCHO+MGLY+...
     &                  +    7.3700D-01 * RXRAT(   263 )      ! XYOP+MO2=0.7370D+00*DCB1+...
     &                  +    3.3400D-01 * RXRAT(   270 )      ! MEKP+MO2=0.3340D+00*DCB1+...
     &                  +    5.0000D-01 * RXRAT(   271 )      ! KETP+MO2=0.5000D+00*DCB1+...
     &                  +                 RXRAT(   295 )      ! PER1+ACO3=DCB1+MO2+MGLY+HO2
     &                  +                 RXRAT(   298 )      ! PER2+ACO3=DCB1+MO2+MGLY+...
     &                  +    7.3700D-01 * RXRAT(   299 )      ! XYOP+ACO3=0.7370D+00*DCB1+...
     &                  +    3.3400D-01 * RXRAT(   306 )      ! MEKP+ACO3=0.3340D+00*DCB1+...
     &                  +    5.0000D-01 * RXRAT(   307 )      ! KETP+ACO3=0.5000D+00*DCB1+...
     &                  +    5.0000D-01 * RXRAT(   333 )      ! PER1+NO3=0.5000D+00*DCB1+...
     &                  +                 RXRAT(   336 )      ! PER2+NO3=DCB1+NO2+MGLY+HO2+...
     &                  +    7.3700D-01 * RXRAT(   337 )      ! XYOP+NO3=0.7370D+00*DCB1+...
     &                  +    6.7000D-01 * RXRAT(   344 )      ! MEKP+NO3=0.6700D+00*DCB1+...
     &                  +                 RXRAT(   345 )      ! KETP+NO3=DCB1+NO2+HO2
      LOSS(  DCB1     ) =                 RXRAT(    25 )      ! DCB1=0.1500D+01*HO2+...
     &                  +                 RXRAT(   101 )      ! DCB1+HO=0.5200D+00*HO2+...
     &                  +                 RXRAT(   136 )      ! DCB1+O3=0.5000D-01*HO+HO2+...

      PROD(  DCB2     ) =    2.8000D-01 * RXRAT(   160 )      ! TR2=0.2800D+00*DCB2+...
     &                  +    4.9000D-01 * RXRAT(   161 )      ! TOLP=0.4900D+00*DCB2+...
     &                  +    2.2400D-01 * RXRAT(   162 )      ! XY2=0.2240D+00*DCB2+...
     &                  +    4.9000D-01 * RXRAT(   163 )      ! XYLP=0.4900D+00*DCB2+...
     &                  +    2.2400D-01 * RXRAT(   164 )      ! XYO2=0.2240D+00*DCB2+...
     &                  +    4.9000D-01 * RXRAT(   165 )      ! XYOP=0.4900D+00*DCB2+...
     &                  +    4.5900D-01 * RXRAT(   180 )      ! BENP+NO=0.4590D+00*DCB2+...
     &                  +    9.5000D-01 * RXRAT(   182 )      ! TOLP+NO=0.9500D+00*DCB2+...
     &                  +    7.3000D-02 * RXRAT(   187 )      ! XYOP+NO=0.7300D-01*DCB2+...
     &                  +    4.5900D-01 * RXRAT(   256 )      ! BENP+MO2=0.4590D+00*DCB2+...
     &                  +                 RXRAT(   258 )      ! TOLP+MO2=DCB2+HCHO+0.2710D+...
     &                  +                 RXRAT(   261 )      ! XYLP+MO2=DCB2+HCHO+0.2000D+...
     &                  +    7.7000D-02 * RXRAT(   263 )      ! XYOP+MO2=0.7700D-01*DCB2+...
     &                  +    4.5900D-01 * RXRAT(   292 )      ! BENP+ACO3=0.4590D+00*DCB2+...
     &                  +                 RXRAT(   294 )      ! TOLP+ACO3=DCB2+MO2+HO2
     &                  +                 RXRAT(   297 )      ! XYLP+ACO3=DCB2+MO2+HO2
     &                  +    7.7000D-02 * RXRAT(   299 )      ! XYOP+ACO3=0.7700D-01*DCB2+...
     &                  +    5.0000D-01 * RXRAT(   330 )      ! BENP+NO3=0.5000D+00*DCB2+...
     &                  +                 RXRAT(   332 )      ! TOLP+NO3=DCB2+NO2+HO2
     &                  +    7.7000D-02 * RXRAT(   337 )      ! XYOP+NO3=0.7700D-01*DCB2+...
      LOSS(  DCB2     ) =                 RXRAT(    26 )      ! DCB2=0.1500D+01*HO2+...
     &                  +                 RXRAT(   102 )      ! DCB2+HO=0.5200D+00*HO2+...
     &                  +                 RXRAT(   137 )      ! DCB2+O3=0.5000D-01*HO+HO2+...

      PROD(  BALD     ) =    2.0000D-02 * RXRAT(   127 )      ! OLT+O3=0.2000D-01*BALD+...
     &                  +    8.5000D-01 * RXRAT(   139 )      ! EPX+O3=0.8500D+00*BALD+...
     &                  +                 RXRAT(   181 )      ! TLP1+NO=BALD+NO2
     &                  +    5.0000D-01 * RXRAT(   183 )      ! PER1+NO=0.5000D+00*BALD+...
     &                  +                 RXRAT(   184 )      ! XYL1+NO=BALD+NO2
     &                  +                 RXRAT(   257 )      ! TLP1+MO2=BALD+HCHO+HO2
     &                  +                 RXRAT(   260 )      ! XYL1+MO2=BALD+HCHO+HO2
     &                  +                 RXRAT(   293 )      ! TLP1+ACO3=BALD+MO2
     &                  +                 RXRAT(   296 )      ! XYL1+ACO3=BALD+MO2
     &                  +                 RXRAT(   331 )      ! TLP1+NO3=BALD+NO2
     &                  +    5.0000D-01 * RXRAT(   333 )      ! PER1+NO3=0.5000D+00*BALD+...
     &                  +                 RXRAT(   334 )      ! XYL1+NO3=BALD+NO2
      LOSS(  BALD     ) =                 RXRAT(    27 )      ! BALD=CHO+HO2+CO
     &                  +                 RXRAT(   104 )      ! BALD+HO=BALP

      PROD(  CHO      ) =                 RXRAT(    27 )      ! BALD=CHO+HO2+CO
     &                  +    7.0000D-02 * RXRAT(   105 )      ! PHEN+HO=0.7000D-01*CHO+...
     &                  +    7.0000D-02 * RXRAT(   106 )      ! CSL+HO=0.7000D-01*CHO+...
     &                  +    4.0000D-01 * RXRAT(   155 )      ! PHEN+NO3=0.4000D+00*CHO+...
     &                  +    4.0000D-01 * RXRAT(   156 )      ! CSL+NO3=0.4000D+00*CHO+...
      LOSS(  CHO      ) =                 RXRAT(   210 )      ! CHO+NO2=ONIT
     &                  +                 RXRAT(   241 )      ! CHO+HO2=CSL

      PROD(  OP1      ) =                 RXRAT(   212 )      ! MO2+HO2=OP1
      LOSS(  OP1      ) =                 RXRAT(    28 )      ! OP1=HO+HO2+HCHO
     &                  +                 RXRAT(   113 )      ! OP1+HO=0.3500D+00*HO+...

      PROD(  OP2      ) =    7.8000D-01 * RXRAT(   102 )      ! DCB2+HO=0.7800D+00*OP2+...
     &                  +    7.9000D-01 * RXRAT(   103 )      ! DCB3+HO=0.7900D+00*OP2+...
     &                  +    6.5000D-01 * RXRAT(   136 )      ! DCB1+O3=0.6500D+00*OP2+HO2+...
     &                  +    6.5000D-01 * RXRAT(   137 )      ! DCB2+O3=0.6500D+00*OP2+HO2+...
     &                  +    6.8000D-01 * RXRAT(   202 )      ! ADDC+NO=0.6800D+00*OP2+NO2+...
     &                  +                 RXRAT(   207 )      ! ADCN+NO=OP2+GLY+0.2000D+01*NO2
     &                  +                 RXRAT(   213 )      ! ETHP+HO2=OP2
     &                  +                 RXRAT(   214 )      ! HC3P+HO2=OP2
     &                  +                 RXRAT(   215 )      ! HC5P+HO2=OP2
     &                  +                 RXRAT(   216 )      ! HC8P+HO2=OP2
     &                  +                 RXRAT(   217 )      ! ETEP+HO2=OP2
     &                  +                 RXRAT(   218 )      ! OLTP+HO2=OP2
     &                  +                 RXRAT(   219 )      ! OLIP+HO2=OP2
     &                  +                 RXRAT(   220 )      ! BENP+HO2=OP2
     &                  +                 RXRAT(   221 )      ! TLP1+HO2=OP2
     &                  +                 RXRAT(   222 )      ! TOLP+HO2=OP2
     &                  +                 RXRAT(   223 )      ! PER1+HO2=OP2
     &                  +                 RXRAT(   224 )      ! XYL1+HO2=OP2
     &                  +                 RXRAT(   225 )      ! XYLP+HO2=OP2
     &                  +                 RXRAT(   226 )      ! PER2+HO2=OP2
     &                  +                 RXRAT(   227 )      ! XYOP+HO2=OP2
     &                  +                 RXRAT(   229 )      ! APIP+HO2=OP2
     &                  +                 RXRAT(   230 )      ! LIMP+HO2=OP2
     &                  +    8.5000D-01 * RXRAT(   233 )      ! ACTP+HO2=0.8500D+00*OP2+...
     &                  +                 RXRAT(   234 )      ! MEKP+HO2=OP2
     &                  +                 RXRAT(   235 )      ! KETP+HO2=OP2
     &                  +                 RXRAT(   238 )      ! MVKP+HO2=OP2
     &                  +                 RXRAT(   239 )      ! UALP+HO2=OP2
     &                  +                 RXRAT(   240 )      ! ADDC+HO2=OP2
     &                  +                 RXRAT(   242 )      ! MCTP+HO2=OP2
     &                  +                 RXRAT(   243 )      ! ORAP+HO2=OP2
     &                  +                 RXRAT(   246 )      ! ADCN+HO2=OP2
     &                  +                 RXRAT(   247 )      ! XO2+HO2=OP2
     &                  +    6.8000D-01 * RXRAT(   278 )      ! ADDC+MO2=0.6800D+00*OP2+...
     &                  +    7.0000D-01 * RXRAT(   283 )      ! ADCN+MO2=0.7000D+00*OP2+...
     &                  +    6.8000D-01 * RXRAT(   314 )      ! ADDC+ACO3=0.6800D+00*OP2+...
     &                  +    7.0000D-01 * RXRAT(   319 )      ! ADCN+ACO3=0.7000D+00*OP2+...
     &                  +    6.8000D-01 * RXRAT(   352 )      ! ADDC+NO3=0.6800D+00*OP2+...
     &                  +                 RXRAT(   357 )      ! ADCN+NO3=OP2+GLY+0.2000D+...
      LOSS(  OP2      ) =                 RXRAT(    29 )      ! OP2=HO+HO2+ALD
     &                  +                 RXRAT(   114 )      ! OP2+HO=0.1000D-01*HO+...

      PROD(  PAA      ) =    1.1000D-01 * RXRAT(   138 )      ! DCB3+O3=0.1100D+00*PAA+HO2+...
     &                  +    4.1000D-01 * RXRAT(   231 )      ! ACO3+HO2=0.4100D+00*PAA+...
     &                  +    4.1000D-01 * RXRAT(   232 )      ! RCO3+HO2=0.4100D+00*PAA+...
      LOSS(  PAA      ) =                 RXRAT(    30 )      ! PAA=HO+MO2
     &                  +                 RXRAT(   119 )      ! PAA+HO=0.3500D+00*HO+...

      PROD(  ONIT     ) =                 RXRAT(   152 )      ! UALD+NO3=ONIT+XO2+0.6680D+...
     &                  +    6.5000D-02 * RXRAT(   174 )      ! HC3P+NO=0.6500D-01*ONIT+...
     &                  +    1.3600D-01 * RXRAT(   175 )      ! HC5P+NO=0.1360D+00*ONIT+...
     &                  +    2.6100D-01 * RXRAT(   176 )      ! HC8P+NO=0.2610D+00*ONIT+...
     &                  +    3.0000D-02 * RXRAT(   178 )      ! OLTP+NO=0.3000D-01*ONIT+...
     &                  +    5.0000D-02 * RXRAT(   179 )      ! OLIP+NO=0.5000D-01*ONIT+...
     &                  +    8.2000D-02 * RXRAT(   180 )      ! BENP+NO=0.8200D-01*ONIT+...
     &                  +    5.0000D-02 * RXRAT(   182 )      ! TOLP+NO=0.5000D-01*ONIT+...
     &                  +    5.0000D-02 * RXRAT(   183 )      ! PER1+NO=0.5000D-01*ONIT+...
     &                  +    5.0000D-02 * RXRAT(   185 )      ! XYLP+NO=0.5000D-01*ONIT+...
     &                  +    5.0000D-02 * RXRAT(   186 )      ! PER2+NO=0.5000D-01*ONIT+...
     &                  +    5.0000D-02 * RXRAT(   187 )      ! XYOP+NO=0.5000D-01*ONIT+...
     &                  +    1.8000D-01 * RXRAT(   189 )      ! APIP+NO=0.1800D+00*ONIT+...
     &                  +                 RXRAT(   205 )      ! OLNN+NO=ONIT+HO2+NO2
     &                  +                 RXRAT(   209 )      ! BAL2+NO2=ONIT
     &                  +                 RXRAT(   210 )      ! CHO+NO2=ONIT
     &                  +                 RXRAT(   211 )      ! MCTO+NO2=ONIT
     &                  +                 RXRAT(   244 )      ! OLNN+HO2=ONIT
     &                  +                 RXRAT(   245 )      ! OLND+HO2=ONIT
     &                  +                 RXRAT(   281 )      ! OLNN+MO2=ONIT+HCHO+0.2000D+...
     &                  +    5.0000D-01 * RXRAT(   282 )      ! OLND+MO2=0.5000D+00*ONIT+...
     &                  +    3.0000D-01 * RXRAT(   283 )      ! ADCN+MO2=0.3000D+00*ONIT+...
     &                  +                 RXRAT(   317 )      ! OLNN+ACO3=ONIT+MO2+HO2
     &                  +    3.0000D-01 * RXRAT(   319 )      ! ADCN+ACO3=0.3000D+00*ONIT+...
     &                  +                 RXRAT(   355 )      ! OLNN+NO3=ONIT+NO2+HO2
     &                  +    2.0000D+00 * RXRAT(   358 )      ! OLNN+OLNN=0.2000D+01*ONIT+HO2
     &                  +    1.5000D+00 * RXRAT(   359 )      ! OLNN+OLND=0.1500D+01*ONIT+...
     &                  +                 RXRAT(   360 )      ! OLND+OLND=ONIT+0.5040D+...
      LOSS(  ONIT     ) =                 RXRAT(    31 )      ! ONIT=HO2+NO2+0.2000D+...
     &                  +                 RXRAT(   123 )      ! ONIT+HO=HC3P+NO2

      PROD(  SO2      ) =   0.0D0
      LOSS(  SO2      ) =                 RXRAT(    69 )      ! SO2+HO=HO2+SULF+SULRXN

      PROD(  SULF     ) =                 RXRAT(    69 )      ! SO2+HO=SULF+HO2+SULRXN
      LOSS(  SULF     ) =   0.0D0

      PROD(  SULRXN   ) =                 RXRAT(    69 )      ! SO2+HO=SULRXN+SULF+HO2
      LOSS(  SULRXN   ) =   0.0D0

      PROD(  ETH      ) =    2.0000D-02 * RXRAT(   127 )      ! OLT+O3=0.2000D-01*ETH+...
     &                  +    1.0000D-02 * RXRAT(   128 )      ! OLI+O3=0.1000D-01*ETH+...
      LOSS(  ETH      ) =                 RXRAT(    72 )      ! ETH+HO=ETHP

      PROD(  HC3      ) =    1.5000D-02 * RXRAT(   127 )      ! OLT+O3=0.1500D-01*HC3+...
     &                  +    1.0000D-02 * RXRAT(   128 )      ! OLI+O3=0.1000D-01*HC3+...
      LOSS(  HC3      ) =                 RXRAT(    73 )      ! HC3+HO=HC3P

      PROD(  HC3P     ) =                 RXRAT(    73 )      ! HC3+HO=HC3P
     &                  +    4.4000D-01 * RXRAT(   114 )      ! OP2+HO=0.4400D+00*HC3P+...
     &                  +                 RXRAT(   123 )      ! ONIT+HO=HC3P+NO2
     &                  +    4.0000D-02 * RXRAT(   127 )      ! OLT+O3=0.4000D-01*HC3P+...
     &                  +    4.0000D-02 * RXRAT(   128 )      ! OLI+O3=0.4000D-01*HC3P+...
      LOSS(  HC3P     ) =                 RXRAT(   174 )      ! HC3P+NO=0.6600D+00*HO2+...
     &                  +                 RXRAT(   214 )      ! HC3P+HO2=OP2
     &                  +                 RXRAT(   250 )      ! HC3P+MO2=0.8940D+00*HO2+...
     &                  +                 RXRAT(   286 )      ! HC3P+ACO3=0.3940D+00*HO2+...
     &                  +                 RXRAT(   324 )      ! HC3P+NO3=0.2540D+00*HO2+...

      PROD(  HC5      ) =    6.0000D-03 * RXRAT(   127 )      ! OLT+O3=0.6000D-02*HC5+...
      LOSS(  HC5      ) =                 RXRAT(    74 )      ! HC5+HO=HC5P

      PROD(  HC5P     ) =                 RXRAT(    74 )      ! HC5+HO=HC5P
     &                  +    2.0000D-02 * RXRAT(   127 )      ! OLT+O3=0.2000D-01*HC5P+...
      LOSS(  HC5P     ) =                 RXRAT(   175 )      ! HC5P+NO=0.2000D+00*HO2+...
     &                  +                 RXRAT(   215 )      ! HC5P+HO2=OP2
     &                  +                 RXRAT(   251 )      ! HC5P+MO2=0.8420D+00*HO2+...
     &                  +                 RXRAT(   287 )      ! HC5P+ACO3=0.3420D+00*HO2+...
     &                  +                 RXRAT(   325 )      ! HC5P+NO3=0.4880D+00*HO2+...

      PROD(  HC8      ) =   0.0D0
      LOSS(  HC8      ) =                 RXRAT(    75 )      ! HC8+HO=0.4900D-01*HO2+...

      PROD(  HC8P     ) =    9.5100D-01 * RXRAT(    75 )      ! HC8+HO=0.9510D+00*HC8P+...
      LOSS(  HC8P     ) =                 RXRAT(   176 )      ! HC8P+NO=0.6060D+00*HO2+...
     &                  +                 RXRAT(   216 )      ! HC8P+HO2=OP2
     &                  +                 RXRAT(   252 )      ! HC8P+MO2=0.9100D+00*HO2+...
     &                  +                 RXRAT(   288 )      ! HC8P+ACO3=0.3030D+00*HO2+...
     &                  +                 RXRAT(   326 )      ! HC8P+NO3=0.8200D+00*HO2+...

      PROD(  ETE      ) =   0.0D0
      LOSS(  ETE      ) =                 RXRAT(    76 )      ! ETE+HO=ETEP
     &                  +                 RXRAT(   126 )      ! ETE+O3=0.8000D-01*HO+...
     &                  +                 RXRAT(   141 )      ! ETE+NO3=0.8000D+00*OLNN+...

      PROD(  ETEP     ) =                 RXRAT(    76 )      ! ETE+HO=ETEP
      LOSS(  ETEP     ) =                 RXRAT(   177 )      ! ETEP+NO=HO2+NO2+0.1600D+...
     &                  +                 RXRAT(   217 )      ! ETEP+HO2=OP2
     &                  +                 RXRAT(   253 )      ! ETEP+MO2=HO2+0.1950D+...
     &                  +                 RXRAT(   289 )      ! ETEP+ACO3=0.5000D+00*HO2+...
     &                  +                 RXRAT(   327 )      ! ETEP+NO3=HO2+NO2+0.1600D+...

      PROD(  OLT      ) =    3.5000D-01 * RXRAT(   129 )      ! DIEN+O3=0.3500D+00*OLT+...
     &                  +    1.5300D-01 * RXRAT(   130 )      ! ISO+O3=0.1530D+00*OLT+...
     &                  +    4.6000D-01 * RXRAT(   132 )      ! LIM+O3=0.4600D+00*OLT+...
      LOSS(  OLT      ) =                 RXRAT(    77 )      ! OLT+HO=OLTP
     &                  +                 RXRAT(   127 )      ! OLT+O3=0.2200D+00*HO+...
     &                  +                 RXRAT(   142 )      ! OLT+NO3=0.4300D+00*OLNN+...

      PROD(  OLTP     ) =                 RXRAT(    77 )      ! OLT+HO=OLTP
      LOSS(  OLTP     ) =                 RXRAT(   178 )      ! OLTP+NO=0.7800D+00*HO2+...
     &                  +                 RXRAT(   218 )      ! OLTP+HO2=OP2
     &                  +                 RXRAT(   254 )      ! OLTP+MO2=HO2+0.1500D+...
     &                  +                 RXRAT(   290 )      ! OLTP+ACO3=0.5000D+00*HO2+...
     &                  +                 RXRAT(   328 )      ! OLTP+NO3=0.4700D+00*ALD+...

      PROD(  OLI      ) =    5.0000D-02 * RXRAT(   190 )      ! LIMP+NO=0.5000D-01*OLI+...
     &                  +    1.9200D-01 * RXRAT(   266 )      ! LIMP+MO2=0.1920D+00*OLI+...
     &                  +    1.9200D-01 * RXRAT(   302 )      ! LIMP+ACO3=0.1920D+00*OLI+...
     &                  +    3.8500D-01 * RXRAT(   340 )      ! LIMP+NO3=0.3850D+00*OLI+...
      LOSS(  OLI      ) =                 RXRAT(    78 )      ! OLI+HO=OLIP
     &                  +                 RXRAT(   128 )      ! OLI+O3=0.4600D+00*HO+...
     &                  +                 RXRAT(   143 )      ! OLI+NO3=0.1100D+00*OLNN+...

      PROD(  OLIP     ) =                 RXRAT(    78 )      ! OLI+HO=OLIP
     &                  +                 RXRAT(    79 )      ! DIEN+HO=OLIP
      LOSS(  OLIP     ) =                 RXRAT(   179 )      ! OLIP+NO=0.8300D+00*HO2+...
     &                  +                 RXRAT(   219 )      ! OLIP+HO2=OP2
     &                  +                 RXRAT(   255 )      ! OLIP+MO2=HO2+0.7500D+...
     &                  +                 RXRAT(   291 )      ! OLIP+ACO3=0.5000D+00*HO2+...
     &                  +                 RXRAT(   329 )      ! OLIP+NO3=0.8600D+00*HO2+...

      PROD(  DIEN     ) =   0.0D0
      LOSS(  DIEN     ) =                 RXRAT(    79 )      ! DIEN+HO=OLIP
     &                  +                 RXRAT(   129 )      ! DIEN+O3=0.9000D-01*O3P+...
     &                  +                 RXRAT(   144 )      ! DIEN+NO3=0.9000D+00*OLNN+...

      PROD(  ACE      ) =   0.0D0
      LOSS(  ACE      ) =                 RXRAT(    80 )      ! ACE+HO=0.6500D+00*HO+...

      PROD(  ORA1     ) =    3.5000D-01 * RXRAT(    80 )      ! ACE+HO=0.3500D+00*ORA1+...
     &                  +    3.7000D-01 * RXRAT(   126 )      ! ETE+O3=0.3700D+00*ORA1+...
     &                  +    3.0000D-02 * RXRAT(   127 )      ! OLT+O3=0.3000D-01*ORA1+...
     &                  +    1.5000D-01 * RXRAT(   129 )      ! DIEN+O3=0.1500D+00*ORA1+...
     &                  +    2.8000D-01 * RXRAT(   130 )      ! ISO+O3=0.2800D+00*ORA1+...
     &                  +    1.0000D-02 * RXRAT(   132 )      ! LIM+O3=0.1000D-01*ORA1+...
     &                  +    4.5000D-01 * RXRAT(   133 )      ! MACR+O3=0.4500D+00*ORA1+...
     &                  +    7.0000D-02 * RXRAT(   134 )      ! MVK+O3=0.7000D-01*ORA1+...
     &                  +    4.4000D-02 * RXRAT(   135 )      ! UALD+O3=0.4400D-01*ORA1+...
     &                  +    2.5000D-01 * RXRAT(   138 )      ! DCB3+O3=0.2500D+00*ORA1+...
     &                  +    7.0000D-02 * RXRAT(   189 )      ! APIP+NO=0.7000D-01*ORA1+...
     &                  +    7.0000D-02 * RXRAT(   190 )      ! LIMP+NO=0.7000D-01*ORA1+...
      LOSS(  ORA1     ) =                 RXRAT(   117 )      ! ORA1+HO=HO2

      PROD(  BENZENE  ) =    3.2000D-02 * RXRAT(   127 )      ! OLT+O3=0.3200D-01*BENZENE+...
      LOSS(  BENZENE  ) =                 RXRAT(    81 )      ! BENZENE+HO=0.6480D+00*HO2+...

      PROD(  BENP     ) =    3.5200D-01 * RXRAT(    81 )      ! BENZENE+HO=0.3520D+00*BENP+...
      LOSS(  BENP     ) =                 RXRAT(   180 )      ! BENP+NO=0.9180D+00*HO2+...
     &                  +                 RXRAT(   220 )      ! BENP+HO2=OP2
     &                  +                 RXRAT(   256 )      ! BENP+MO2=0.1600D+01*HO2+...
     &                  +                 RXRAT(   292 )      ! BENP+ACO3=0.6000D+00*HO2+...
     &                  +                 RXRAT(   330 )      ! BENP+NO3=HO2+NO2+0.5000D+...

      PROD(  EPX      ) =    1.1800D-01 * RXRAT(    81 )      ! BENZENE+HO=0.1180D+00*EPX+...
     &                  +    2.8000D-01 * RXRAT(   160 )      ! TR2=0.2800D+00*EPX+0.2900D+...
     &                  +    8.4000D-01 * RXRAT(   162 )      ! XY2=0.8400D+00*EPX+0.3080D+...
     &                  +    8.4000D-01 * RXRAT(   164 )      ! XYO2=0.8400D+00*EPX+...
      LOSS(  EPX      ) =                 RXRAT(   107 )      ! EPX+HO=HO2+XO2+CO+ALD
     &                  +                 RXRAT(   139 )      ! EPX+O3=0.5000D-01*HO+...
     &                  +                 RXRAT(   157 )      ! EPX+NO3=0.5000D+00*HO+...

      PROD(  PHEN     ) =    5.3000D-01 * RXRAT(    81 )      ! BENZENE+HO=0.5300D+00*PHEN+...
      LOSS(  PHEN     ) =                 RXRAT(   105 )      ! PHEN+HO=0.7300D+00*HO2+...
     &                  +                 RXRAT(   155 )      ! PHEN+NO3=0.4000D+00*CHO+...

      PROD(  BENZRO2  ) =                 RXRAT(    81 )      ! BENZENE+HO=BENZRO2+0.3520D+...
      LOSS(  BENZRO2  ) =                 RXRAT(   368 )      ! BENZRO2+NO=NO+BNZNRXN
     &                  +                 RXRAT(   369 )      ! BENZRO2+HO2=HO2+BNZHRXN

      PROD(  TOL      ) =   0.0D0
      LOSS(  TOL      ) =                 RXRAT(    82 )      ! TOL+HO=0.1770D+00*HO2+...

      PROD(  TR2      ) =    7.6300D-01 * RXRAT(    82 )      ! TOL+HO=0.7630D+00*TR2+...
      LOSS(  TR2      ) =                 RXRAT(   160 )      ! TR2=0.2800D+00*HO+0.2900D+...

      PROD(  TLP1     ) =    6.0000D-02 * RXRAT(    82 )      ! TOL+HO=0.6000D-01*TLP1+...
      LOSS(  TLP1     ) =                 RXRAT(   181 )      ! TLP1+NO=NO2+BALD
     &                  +                 RXRAT(   221 )      ! TLP1+HO2=OP2
     &                  +                 RXRAT(   257 )      ! TLP1+MO2=HO2+HCHO+BALD
     &                  +                 RXRAT(   293 )      ! TLP1+ACO3=MO2+BALD
     &                  +                 RXRAT(   331 )      ! TLP1+NO3=NO2+BALD

      PROD(  CSL      ) =    1.7700D-01 * RXRAT(    82 )      ! TOL+HO=0.1770D+00*CSL+...
     &                  +    1.7700D-01 * RXRAT(    83 )      ! XYM+HO=0.1770D+00*CSL+...
     &                  +    1.7700D-01 * RXRAT(    84 )      ! XYP+HO=0.1770D+00*CSL+...
     &                  +    1.7700D-01 * RXRAT(    85 )      ! XYO+HO=0.1770D+00*CSL+...
     &                  +    1.0000D-02 * RXRAT(   160 )      ! TR2=0.1000D-01*CSL+0.2900D+...
     &                  +    1.0000D-02 * RXRAT(   161 )      ! TOLP=0.1000D-01*CSL+...
     &                  +    1.0000D-02 * RXRAT(   162 )      ! XY2=0.1000D-01*CSL+0.3080D+...
     &                  +    1.0000D-02 * RXRAT(   163 )      ! XYLP=0.1000D-01*CSL+...
     &                  +    1.0000D-02 * RXRAT(   164 )      ! XYO2=0.1000D-01*CSL+...
     &                  +    1.0000D-02 * RXRAT(   165 )      ! XYOP=0.1000D-01*CSL+...
     &                  +                 RXRAT(   241 )      ! CHO+HO2=CSL
      LOSS(  CSL      ) =                 RXRAT(   106 )      ! CSL+HO=0.7300D+00*HO2+...
     &                  +                 RXRAT(   156 )      ! CSL+NO3=0.4000D+00*CHO+...

      PROD(  TOLRO2   ) =                 RXRAT(    82 )      ! TOL+HO=TOLRO2+0.7630D+...
      LOSS(  TOLRO2   ) =                 RXRAT(   364 )      ! TOLRO2+NO=NO+TOLNRXN
     &                  +                 RXRAT(   365 )      ! TOLRO2+HO2=HO2+TOLHRXN

      PROD(  XYM      ) =   0.0D0
      LOSS(  XYM      ) =                 RXRAT(    83 )      ! XYM+HO=0.1770D+00*HO2+...

      PROD(  XY2      ) =    7.6300D-01 * RXRAT(    83 )      ! XYM+HO=0.7630D+00*XY2+...
     &                  +    7.6300D-01 * RXRAT(    84 )      ! XYP+HO=0.7630D+00*XY2+...
      LOSS(  XY2      ) =                 RXRAT(   162 )      ! XY2=0.1580D+00*HO+0.3080D+...

      PROD(  XYL1     ) =    6.0000D-02 * RXRAT(    83 )      ! XYM+HO=0.6000D-01*XYL1+...
     &                  +    6.0000D-02 * RXRAT(    84 )      ! XYP+HO=0.6000D-01*XYL1+...
     &                  +    6.0000D-02 * RXRAT(    85 )      ! XYO+HO=0.6000D-01*XYL1+...
      LOSS(  XYL1     ) =                 RXRAT(   184 )      ! XYL1+NO=NO2+BALD
     &                  +                 RXRAT(   224 )      ! XYL1+HO2=OP2
     &                  +                 RXRAT(   260 )      ! XYL1+MO2=HO2+HCHO+BALD
     &                  +                 RXRAT(   296 )      ! XYL1+ACO3=MO2+BALD
     &                  +                 RXRAT(   334 )      ! XYL1+NO3=NO2+BALD

      PROD(  XYLRO2   ) =    9.8000D-01 * RXRAT(    83 )      ! XYM+HO=0.9800D+00*XYLRO2+...
     &                  +                 RXRAT(    84 )      ! XYP+HO=XYLRO2+0.7630D+...
     &                  +                 RXRAT(    85 )      ! XYO+HO=XYLRO2+0.7630D+...
      LOSS(  XYLRO2   ) =                 RXRAT(   366 )      ! XYLRO2+NO=NO+XYLNRXN
     &                  +                 RXRAT(   367 )      ! XYLRO2+HO2=HO2+XYLHRXN

      PROD(  XYP      ) =   0.0D0
      LOSS(  XYP      ) =                 RXRAT(    84 )      ! XYP+HO=0.1770D+00*HO2+...

      PROD(  XYO      ) =   0.0D0
      LOSS(  XYO      ) =                 RXRAT(    85 )      ! XYO+HO=0.1770D+00*HO2+...

      PROD(  XYO2     ) =    7.6300D-01 * RXRAT(    85 )      ! XYO+HO=0.7630D+00*XYO2+...
      LOSS(  XYO2     ) =                 RXRAT(   164 )      ! XYO2=0.1580D+00*HO+0.3080D+...

      PROD(  ISO      ) =   0.0D0
      LOSS(  ISO      ) =                 RXRAT(    86 )      ! ISO+HO=ISOP+ISOPRXN
     &                  +                 RXRAT(   130 )      ! ISO+O3=0.2500D+00*HO+...
     &                  +                 RXRAT(   145 )      ! ISO+NO3=ISON+ISOPRXN

      PROD(  ISOP     ) =                 RXRAT(    86 )      ! ISO+HO=ISOP+ISOPRXN
      LOSS(  ISOP     ) =                 RXRAT(   188 )      ! ISOP+NO=0.8800D+00*HO2+...
     &                  +                 RXRAT(   228 )      ! ISOP+HO2=ISHP
     &                  +                 RXRAT(   264 )      ! ISOP+MO2=HO2+0.1310D+...
     &                  +                 RXRAT(   300 )      ! ISOP+ACO3=0.5000D+00*HO2+...
     &                  +                 RXRAT(   338 )      ! ISOP+NO3=HO2+NO2+0.7500D+...

      PROD(  ISOPRXN  ) =                 RXRAT(    86 )      ! ISO+HO=ISOPRXN+ISOP
     &                  +                 RXRAT(   145 )      ! ISO+NO3=ISOPRXN+ISON
      LOSS(  ISOPRXN  ) =   0.0D0

      PROD(  API      ) =   0.0D0
      LOSS(  API      ) =                 RXRAT(    87 )      ! API+HO=APIP+TRPRXN
     &                  +                 RXRAT(   131 )      ! API+O3=0.8500D+00*HO+...
     &                  +                 RXRAT(   146 )      ! API+NO3=0.1000D+00*OLNN+...

      PROD(  APIP     ) =                 RXRAT(    87 )      ! API+HO=APIP+TRPRXN
      LOSS(  APIP     ) =                 RXRAT(   189 )      ! APIP+NO=0.8200D+00*HO2+...
     &                  +                 RXRAT(   229 )      ! APIP+HO2=OP2
     &                  +                 RXRAT(   265 )      ! APIP+MO2=HO2+0.7500D+...
     &                  +                 RXRAT(   301 )      ! APIP+ACO3=0.5000D+00*HO2+...
     &                  +                 RXRAT(   339 )      ! APIP+NO3=HO2+NO2+ALD+KET

      PROD(  TRPRXN   ) =                 RXRAT(    87 )      ! API+HO=TRPRXN+APIP
     &                  +                 RXRAT(    88 )      ! LIM+HO=TRPRXN+LIMP
     &                  +                 RXRAT(   131 )      ! API+O3=TRPRXN+0.1000D+...
     &                  +                 RXRAT(   132 )      ! LIM+O3=TRPRXN+0.1000D+...
     &                  +                 RXRAT(   146 )      ! API+NO3=TRPRXN+0.9000D+...
     &                  +                 RXRAT(   147 )      ! LIM+NO3=TRPRXN+0.2900D+...
      LOSS(  TRPRXN   ) =   0.0D0

      PROD(  LIM      ) =   0.0D0
      LOSS(  LIM      ) =                 RXRAT(    88 )      ! LIM+HO=LIMP+TRPRXN
     &                  +                 RXRAT(   132 )      ! LIM+O3=0.8500D+00*HO+...
     &                  +                 RXRAT(   147 )      ! LIM+NO3=0.7100D+00*OLNN+...

      PROD(  LIMP     ) =                 RXRAT(    88 )      ! LIM+HO=LIMP+TRPRXN
      LOSS(  LIMP     ) =                 RXRAT(   190 )      ! LIMP+NO=HO2+0.6800D+...
     &                  +                 RXRAT(   230 )      ! LIMP+HO2=OP2
     &                  +                 RXRAT(   266 )      ! LIMP+MO2=HO2+0.1040D+...
     &                  +                 RXRAT(   302 )      ! LIMP+ACO3=0.5000D+00*HO2+...
     &                  +                 RXRAT(   340 )      ! LIMP+NO3=HO2+NO2+0.3850D+...

      PROD(  RCO3     ) =                 RXRAT(    91 )      ! ALD+HO=RCO3
     &                  +    6.0000D-01 * RXRAT(   136 )      ! DCB1+O3=0.6000D+00*RCO3+...
     &                  +    6.0000D-01 * RXRAT(   137 )      ! DCB2+O3=0.6000D+00*RCO3+...
     &                  +                 RXRAT(   150 )      ! ALD+NO3=RCO3+HNO3
     &                  +    2.5000D-01 * RXRAT(   162 )      ! XY2=0.2500D+00*RCO3+...
     &                  +    2.5000D-01 * RXRAT(   164 )      ! XYO2=0.2500D+00*RCO3+...
     &                  +                 RXRAT(   169 )      ! PPN=RCO3+NO2
      LOSS(  RCO3     ) =                 RXRAT(   168 )      ! RCO3+NO2=PPN
     &                  +                 RXRAT(   192 )      ! RCO3+NO=ETHP+NO2
     &                  +                 RXRAT(   232 )      ! RCO3+HO2=0.4400D+00*HO+...
     &                  +                 RXRAT(   268 )      ! RCO3+MO2=0.9000D+00*HO2+...
     &                  +                 RXRAT(   304 )      ! RCO3+ACO3=MO2+ETHP
     &                  +    2.0000D+00 * RXRAT(   321 )      ! RCO3+RCO3=0.2000D+01*ETHP
     &                  +                 RXRAT(   342 )      ! RCO3+NO3=ETHP+NO2
     &                  +                 RXRAT(   362 )      ! RCO3+XO2=ETHP

      PROD(  ACTP     ) =                 RXRAT(    92 )      ! ACT+HO=ACTP
      LOSS(  ACTP     ) =                 RXRAT(   193 )      ! ACTP+NO=ACO3+NO2+HCHO
     &                  +                 RXRAT(   233 )      ! ACTP+HO2=0.1500D+00*HO+...
     &                  +                 RXRAT(   269 )      ! ACTP+MO2=0.5000D+00*HO2+...
     &                  +                 RXRAT(   305 )      ! ACTP+ACO3=0.5000D+00*MO2+...
     &                  +                 RXRAT(   343 )      ! ACTP+NO3=ACO3+NO2+HCHO

      PROD(  MEKP     ) =                 RXRAT(    93 )      ! MEK+HO=MEKP
      LOSS(  MEKP     ) =                 RXRAT(   194 )      ! MEKP+NO=0.6700D+00*HO2+NO2+...
     &                  +                 RXRAT(   234 )      ! MEKP+HO2=OP2
     &                  +                 RXRAT(   270 )      ! MEKP+MO2=0.8340D+00*HO2+...
     &                  +                 RXRAT(   306 )      ! MEKP+ACO3=0.3300D+00*HO2+...
     &                  +                 RXRAT(   344 )      ! MEKP+NO3=0.6700D+00*HO2+...

      PROD(  KETP     ) =                 RXRAT(    94 )      ! KET+HO=KETP
     &                  +    2.0000D-02 * RXRAT(   129 )      ! DIEN+O3=0.2000D-01*KETP+...
     &                  +    4.2000D-01 * RXRAT(   131 )      ! API+O3=0.4200D+00*KETP+...
     &                  +    4.2000D-01 * RXRAT(   132 )      ! LIM+O3=0.4200D+00*KETP+...
      LOSS(  KETP     ) =                 RXRAT(   195 )      ! KETP+NO=0.7700D+00*HO2+...
     &                  +                 RXRAT(   235 )      ! KETP+HO2=OP2
     &                  +                 RXRAT(   271 )      ! KETP+MO2=HO2+0.7500D+...
     &                  +                 RXRAT(   307 )      ! KETP+ACO3=0.5000D+00*HO2+...
     &                  +                 RXRAT(   345 )      ! KETP+NO3=HO2+NO2+DCB1

      PROD(  MCP      ) =    4.3000D-01 * RXRAT(    96 )      ! MACR+HO=0.4300D+00*MCP+...
      LOSS(  MCP      ) =                 RXRAT(   197 )      ! MCP+NO=NO2+0.5000D+00*HO2+...
     &                  +                 RXRAT(   237 )      ! MCP+HO2=MAHP
     &                  +                 RXRAT(   273 )      ! MCP+MO2=NO2+HO2+0.1500D+...
     &                  +                 RXRAT(   309 )      ! MCP+ACO3=NO2+0.5000D+...
     &                  +                 RXRAT(   347 )      ! MCP+NO3=NO2+HO2+HCHO+HKET

      PROD(  MVKP     ) =                 RXRAT(    97 )      ! MVK+HO=MVKP
      LOSS(  MVKP     ) =                 RXRAT(   198 )      ! MVKP+NO=0.3000D+00*HO2+...
     &                  +                 RXRAT(   238 )      ! MVKP+HO2=OP2
     &                  +                 RXRAT(   274 )      ! MVKP+MO2=HO2+0.1160D+...
     &                  +                 RXRAT(   310 )      ! MVKP+ACO3=0.5000D+00*HO2+...
     &                  +                 RXRAT(   348 )      ! MVKP+NO3=0.3000D+00*HO2+...

      PROD(  UALP     ) =    6.8700D-01 * RXRAT(    98 )      ! UALD+HO=0.6870D+00*UALP+...
      LOSS(  UALP     ) =                 RXRAT(   199 )      ! UALP+NO=HO2+NO2+0.6100D+...
     &                  +                 RXRAT(   239 )      ! UALP+HO2=OP2
     &                  +                 RXRAT(   275 )      ! UALP+MO2=HO2+0.3050D+00*CO+...
     &                  +                 RXRAT(   311 )      ! UALP+ACO3=0.5000D+00*HO2+...
     &                  +                 RXRAT(   349 )      ! UALP+NO3=HO2+NO2+0.6100D+...

      PROD(  DCB3     ) =    4.5900D-01 * RXRAT(   180 )      ! BENP+NO=0.4590D+00*DCB3+...
     &                  +    9.5000D-01 * RXRAT(   185 )      ! XYLP+NO=0.9500D+00*DCB3+...
     &                  +    1.0500D+00 * RXRAT(   186 )      ! PER2+NO=0.1050D+01*DCB3+...
     &                  +    1.7700D-01 * RXRAT(   187 )      ! XYOP+NO=0.1770D+00*DCB3+...
     &                  +    4.5900D-01 * RXRAT(   256 )      ! BENP+MO2=0.4590D+00*DCB3+...
     &                  +    1.0500D+00 * RXRAT(   262 )      ! PER2+MO2=0.1050D+01*DCB3+...
     &                  +    1.8600D-01 * RXRAT(   263 )      ! XYOP+MO2=0.1860D+00*DCB3+...
     &                  +    4.5800D-01 * RXRAT(   292 )      ! BENP+ACO3=0.4580D+00*DCB3+...
     &                  +    1.0500D+00 * RXRAT(   298 )      ! PER2+ACO3=0.1050D+01*DCB3+...
     &                  +    1.8600D-01 * RXRAT(   299 )      ! XYOP+ACO3=0.1860D+00*DCB3+...
     &                  +    5.0000D-01 * RXRAT(   330 )      ! BENP+NO3=0.5000D+00*DCB3+...
     &                  +                 RXRAT(   335 )      ! XYLP+NO3=DCB3+NO2+HO2
     &                  +    1.0500D+00 * RXRAT(   336 )      ! PER2+NO3=0.1050D+01*DCB3+...
     &                  +    1.8600D-01 * RXRAT(   337 )      ! XYOP+NO3=0.1860D+00*DCB3+...
      LOSS(  DCB3     ) =                 RXRAT(   103 )      ! DCB3+HO=0.5600D+00*HO2+...
     &                  +                 RXRAT(   138 )      ! DCB3+O3=0.5000D-01*HO+HO2+...

      PROD(  BALP     ) =                 RXRAT(   104 )      ! BALD+HO=BALP
      LOSS(  BALP     ) =                 RXRAT(   200 )      ! BALP+NO=BAL1+NO2
     &                  +                 RXRAT(   276 )      ! BALP+MO2=HO2+BAL1+HCHO
     &                  +                 RXRAT(   312 )      ! BALP+ACO3=MO2+BAL1
     &                  +                 RXRAT(   350 )      ! BALP+NO3=BAL1+NO2

      PROD(  ADDC     ) =    2.0000D-01 * RXRAT(   105 )      ! PHEN+HO=0.2000D+00*ADDC+...
     &                  +    2.0000D-01 * RXRAT(   106 )      ! CSL+HO=0.2000D+00*ADDC+...
     &                  +    1.0000D-01 * RXRAT(   155 )      ! PHEN+NO3=0.1000D+00*ADDC+...
     &                  +    1.0000D-01 * RXRAT(   156 )      ! CSL+NO3=0.1000D+00*ADDC+...
      LOSS(  ADDC     ) =                 RXRAT(   202 )      ! ADDC+NO=HO2+NO2+0.3200D+...
     &                  +                 RXRAT(   240 )      ! ADDC+HO2=OP2
     &                  +                 RXRAT(   278 )      ! ADDC+MO2=0.2000D+01*HO2+...
     &                  +                 RXRAT(   314 )      ! ADDC+ACO3=0.2000D+01*HO2+...
     &                  +                 RXRAT(   352 )      ! ADDC+NO3=HO2+NO2+0.3200D+...

      PROD(  MCT      ) =    7.3000D-01 * RXRAT(   105 )      ! PHEN+HO=0.7300D+00*MCT+...
     &                  +    7.3000D-01 * RXRAT(   106 )      ! CSL+HO=0.7300D+00*MCT+...
      LOSS(  MCT      ) =                 RXRAT(   108 )      ! MCT+HO=MCTO
     &                  +                 RXRAT(   158 )      ! MCT+NO3=MCTO+HNO3

      PROD(  MCTO     ) =                 RXRAT(   108 )      ! MCT+HO=MCTO
     &                  +                 RXRAT(   158 )      ! MCT+NO3=MCTO+HNO3
     &                  +                 RXRAT(   203 )      ! MCTP+NO=MCTO+NO2
     &                  +                 RXRAT(   279 )      ! MCTP+MO2=MCTO+HO2+HCHO
     &                  +                 RXRAT(   315 )      ! MCTP+ACO3=MCTO+MO2+HO2
     &                  +                 RXRAT(   353 )      ! MCTP+NO3=MCTO+NO2
      LOSS(  MCTO     ) =                 RXRAT(   140 )      ! MCTO+O3=MCTP
     &                  +                 RXRAT(   211 )      ! MCTO+NO2=ONIT

      PROD(  MOH      ) =    6.3000D-01 * RXRAT(   248 )      ! MO2+MO2=0.6300D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   249 )      ! ETHP+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   250 )      ! HC3P+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   251 )      ! HC5P+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   252 )      ! HC8P+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   253 )      ! ETEP+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   254 )      ! OLTP+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   255 )      ! OLIP+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   264 )      ! ISOP+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   265 )      ! APIP+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   266 )      ! LIMP+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   269 )      ! ACTP+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   270 )      ! MEKP+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   271 )      ! KETP+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   272 )      ! MACP+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   273 )      ! MCP+MO2=0.2500D+00*MOH+HO2+...
     &                  +    2.5000D-01 * RXRAT(   274 )      ! MVKP+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   275 )      ! UALP+MO2=0.2500D+00*MOH+...
     &                  +    2.5000D-01 * RXRAT(   282 )      ! OLND+MO2=0.2500D+00*MOH+...
      LOSS(  MOH      ) =                 RXRAT(   109 )      ! MOH+HO=HO2+HCHO

      PROD(  EOH      ) =    2.5000D-01 * RXRAT(   249 )      ! ETHP+MO2=0.2500D+00*EOH+...
      LOSS(  EOH      ) =                 RXRAT(   110 )      ! EOH+HO=HO2+ACD

      PROD(  ROH      ) =    2.5000D-01 * RXRAT(   250 )      ! HC3P+MO2=0.2500D+00*ROH+...
     &                  +    2.5000D-01 * RXRAT(   251 )      ! HC5P+MO2=0.2500D+00*ROH+...
     &                  +    2.5000D-01 * RXRAT(   252 )      ! HC8P+MO2=0.2500D+00*ROH+...
     &                  +    2.5000D-01 * RXRAT(   254 )      ! OLTP+MO2=0.2500D+00*ROH+...
     &                  +    2.5000D-01 * RXRAT(   255 )      ! OLIP+MO2=0.2500D+00*ROH+...
     &                  +    2.5000D-01 * RXRAT(   264 )      ! ISOP+MO2=0.2500D+00*ROH+...
     &                  +    2.5000D-01 * RXRAT(   265 )      ! APIP+MO2=0.2500D+00*ROH+...
     &                  +    2.5000D-01 * RXRAT(   266 )      ! LIMP+MO2=0.2500D+00*ROH+...
     &                  +    2.5000D-01 * RXRAT(   269 )      ! ACTP+MO2=0.2500D+00*ROH+...
     &                  +    2.5000D-01 * RXRAT(   270 )      ! MEKP+MO2=0.2500D+00*ROH+...
     &                  +    2.5000D-01 * RXRAT(   271 )      ! KETP+MO2=0.2500D+00*ROH+...
     &                  +    2.5000D-01 * RXRAT(   272 )      ! MACP+MO2=0.2500D+00*ROH+...
     &                  +    2.5000D-01 * RXRAT(   273 )      ! MCP+MO2=0.2500D+00*ROH+HO2+...
     &                  +    2.5000D-01 * RXRAT(   274 )      ! MVKP+MO2=0.2500D+00*ROH+...
     &                  +    2.5000D-01 * RXRAT(   275 )      ! UALP+MO2=0.2500D+00*ROH+...
     &                  +    2.5000D-01 * RXRAT(   282 )      ! OLND+MO2=0.2500D+00*ROH+...
      LOSS(  ROH      ) =                 RXRAT(   111 )      ! ROH+HO=HO2+0.7190D+00*ALD+...

      PROD(  ETEG     ) =    2.5000D-01 * RXRAT(   253 )      ! ETEP+MO2=0.2500D+00*ETEG+...
      LOSS(  ETEG     ) =                 RXRAT(   112 )      ! ETEG+HO=HO2+ALD

      PROD(  ISHP     ) =                 RXRAT(   228 )      ! ISOP+HO2=ISHP
      LOSS(  ISHP     ) =                 RXRAT(   115 )      ! ISHP+HO=HO+MACR+0.9040D+...

      PROD(  IEPOX    ) =    9.0400D-01 * RXRAT(   115 )      ! ISHP+HO=0.9040D+00*IEPOX+...
      LOSS(  IEPOX    ) =                 RXRAT(   377 )      ! IEPOX+HO=HO
     &                  +                 RXRAT(   381 )      ! IEPOX=AISO3J

      PROD(  MAHP     ) =                 RXRAT(   236 )      ! MACP+HO2=MAHP
     &                  +                 RXRAT(   237 )      ! MCP+HO2=MAHP
      LOSS(  MAHP     ) =                 RXRAT(   116 )      ! MAHP+HO=MACP

      PROD(  ORA2     ) =    6.0000D-02 * RXRAT(   127 )      ! OLT+O3=0.6000D-01*ORA2+...
     &                  +    1.7000D-02 * RXRAT(   128 )      ! OLI+O3=0.1700D-01*ORA2+...
     &                  +    7.0000D-02 * RXRAT(   132 )      ! LIM+O3=0.7000D-01*ORA2+...
     &                  +    7.0000D-02 * RXRAT(   134 )      ! MVK+O3=0.7000D-01*ORA2+...
     &                  +    2.5000D-01 * RXRAT(   138 )      ! DCB3+O3=0.2500D+00*ORA2+...
     &                  +    1.5000D-01 * RXRAT(   231 )      ! ACO3+HO2=0.1500D+00*ORA2+...
     &                  +    1.5000D-01 * RXRAT(   232 )      ! RCO3+HO2=0.1500D+00*ORA2+...
     &                  +    1.0000D-01 * RXRAT(   267 )      ! ACO3+MO2=0.1000D+00*ORA2+...
     &                  +    1.0000D-01 * RXRAT(   268 )      ! RCO3+MO2=0.1000D+00*ORA2+...
     &                  +    1.2500D-01 * RXRAT(   269 )      ! ACTP+MO2=0.1250D+00*ORA2+...
     &                  +    6.7000D-02 * RXRAT(   272 )      ! MACP+MO2=0.6700D-01*ORA2+...
     &                  +    2.9200D-01 * RXRAT(   274 )      ! MVKP+MO2=0.2920D+00*ORA2+...
     &                  +    5.0000D-01 * RXRAT(   285 )      ! ETHP+ACO3=0.5000D+00*ORA2+...
     &                  +    5.0000D-01 * RXRAT(   286 )      ! HC3P+ACO3=0.5000D+00*ORA2+...
     &                  +    5.0000D-01 * RXRAT(   287 )      ! HC5P+ACO3=0.5000D+00*ORA2+...
     &                  +    4.9500D-01 * RXRAT(   288 )      ! HC8P+ACO3=0.4950D+00*ORA2+...
     &                  +    5.0000D-01 * RXRAT(   289 )      ! ETEP+ACO3=0.5000D+00*ORA2+...
     &                  +    5.0000D-01 * RXRAT(   290 )      ! OLTP+ACO3=0.5000D+00*ORA2+...
     &                  +    5.0000D-01 * RXRAT(   291 )      ! OLIP+ACO3=0.5000D+00*ORA2+...
     &                  +    5.0000D-01 * RXRAT(   300 )      ! ISOP+ACO3=0.5000D+00*ORA2+...
     &                  +                 RXRAT(   301 )      ! APIP+ACO3=ORA2+0.5000D+...
     &                  +    5.0000D-01 * RXRAT(   302 )      ! LIMP+ACO3=0.5000D+00*ORA2+...
     &                  +    7.5000D-01 * RXRAT(   305 )      ! ACTP+ACO3=0.7500D+00*ORA2+...
     &                  +    5.0000D-01 * RXRAT(   306 )      ! MEKP+ACO3=0.5000D+00*ORA2+...
     &                  +    5.0000D-01 * RXRAT(   307 )      ! KETP+ACO3=0.5000D+00*ORA2+...
     &                  +    6.3500D-01 * RXRAT(   308 )      ! MACP+ACO3=0.6350D+00*ORA2+...
     &                  +    5.0000D-01 * RXRAT(   309 )      ! MCP+ACO3=0.5000D+00*ORA2+...
     &                  +    1.0830D+00 * RXRAT(   310 )      ! MVKP+ACO3=0.1083D+01*ORA2+...
     &                  +    5.0000D-01 * RXRAT(   311 )      ! UALP+ACO3=0.5000D+00*ORA2+...
     &                  +    5.0000D-01 * RXRAT(   318 )      ! OLND+ACO3=0.5000D+00*ORA2+...
      LOSS(  ORA2     ) =                 RXRAT(   118 )      ! ORA2+HO=0.6400D+00*MO2+...

      PROD(  ORAP     ) =    3.6000D-01 * RXRAT(   118 )      ! ORA2+HO=0.3600D+00*ORAP+...
      LOSS(  ORAP     ) =                 RXRAT(   204 )      ! ORAP+NO=NO2+GLY+HO2
     &                  +                 RXRAT(   243 )      ! ORAP+HO2=OP2
     &                  +                 RXRAT(   280 )      ! ORAP+MO2=HCHO+HO2+GLY
     &                  +                 RXRAT(   316 )      ! ORAP+ACO3=MO2+GLY
     &                  +                 RXRAT(   354 )      ! ORAP+NO3=NO2+GLY+HO2

      PROD(  PPN      ) =                 RXRAT(   168 )      ! RCO3+NO2=PPN
      LOSS(  PPN      ) =                 RXRAT(   121 )      ! PPN+HO=XO2+NO3+HCHO
     &                  +                 RXRAT(   169 )      ! PPN=RCO3+NO2

      PROD(  MPAN     ) =                 RXRAT(   170 )      ! MACP+NO2=MPAN
      LOSS(  MPAN     ) =                 RXRAT(   122 )      ! MPAN+HO=NO2+HKET
     &                  +                 RXRAT(   159 )      ! MPAN+NO3=MACP+NO2
     &                  +                 RXRAT(   171 )      ! MPAN=MACP+NO2

      PROD(  NALD     ) =                 RXRAT(   125 )      ! ISON+HO=NALD+0.7000D-...
      LOSS(  NALD     ) =                 RXRAT(   124 )      ! NALD+HO=NO2+XO2+HKET

      PROD(  ISON     ) =                 RXRAT(   145 )      ! ISO+NO3=ISON+ISOPRXN
     &                  +    1.2000D-01 * RXRAT(   188 )      ! ISOP+NO=0.1200D+00*ISON+...
      LOSS(  ISON     ) =                 RXRAT(   125 )      ! ISON+HO=NALD+0.7000D-...

      PROD(  MCTP     ) =                 RXRAT(   140 )      ! MCTO+O3=MCTP
      LOSS(  MCTP     ) =                 RXRAT(   203 )      ! MCTP+NO=MCTO+NO2
     &                  +                 RXRAT(   242 )      ! MCTP+HO2=OP2
     &                  +                 RXRAT(   279 )      ! MCTP+MO2=HO2+MCTO+HCHO
     &                  +                 RXRAT(   315 )      ! MCTP+ACO3=HO2+MO2+MCTO
     &                  +                 RXRAT(   353 )      ! MCTP+NO3=NO2+MCTO

      PROD(  OLNN     ) =    8.0000D-01 * RXRAT(   141 )      ! ETE+NO3=0.8000D+00*OLNN+...
     &                  +    4.3000D-01 * RXRAT(   142 )      ! OLT+NO3=0.4300D+00*OLNN+...
     &                  +    1.1000D-01 * RXRAT(   143 )      ! OLI+NO3=0.1100D+00*OLNN+...
     &                  +    9.0000D-01 * RXRAT(   144 )      ! DIEN+NO3=0.9000D+00*OLNN+...
     &                  +    1.0000D-01 * RXRAT(   146 )      ! API+NO3=0.1000D+00*OLNN+...
     &                  +    7.1000D-01 * RXRAT(   147 )      ! LIM+NO3=0.7100D+00*OLNN+...
      LOSS(  OLNN     ) =                 RXRAT(   205 )      ! OLNN+NO=NO2+HO2+ONIT
     &                  +                 RXRAT(   244 )      ! OLNN+HO2=ONIT
     &                  +                 RXRAT(   281 )      ! OLNN+MO2=0.2000D+01*HO2+...
     &                  +                 RXRAT(   317 )      ! OLNN+ACO3=HO2+MO2+ONIT
     &                  +                 RXRAT(   355 )      ! OLNN+NO3=HO2+NO2+ONIT
     &                  +    2.0000D+00 * RXRAT(   358 )      ! OLNN+OLNN=HO2+0.2000D+01*ONIT
     &                  +                 RXRAT(   359 )      ! OLNN+OLND=0.5000D+00*HO2+...

      PROD(  OLND     ) =    2.0000D-01 * RXRAT(   141 )      ! ETE+NO3=0.2000D+00*OLND+...
     &                  +    5.7000D-01 * RXRAT(   142 )      ! OLT+NO3=0.5700D+00*OLND+...
     &                  +    8.9000D-01 * RXRAT(   143 )      ! OLI+NO3=0.8900D+00*OLND+...
     &                  +    1.0000D-01 * RXRAT(   144 )      ! DIEN+NO3=0.1000D+00*OLND+...
     &                  +    9.0000D-01 * RXRAT(   146 )      ! API+NO3=0.9000D+00*OLND+...
     &                  +    2.9000D-01 * RXRAT(   147 )      ! LIM+NO3=0.2900D+00*OLND+...
      LOSS(  OLND     ) =                 RXRAT(   206 )      ! OLND+NO=0.2000D+01*NO2+...
     &                  +                 RXRAT(   245 )      ! OLND+HO2=ONIT
     &                  +                 RXRAT(   282 )      ! OLND+MO2=0.5000D+00*HO2+...
     &                  +                 RXRAT(   318 )      ! OLND+ACO3=0.5000D+00*MO2+...
     &                  +                 RXRAT(   356 )      ! OLND+NO3=0.2000D+01*NO2+...
     &                  +                 RXRAT(   359 )      ! OLND+OLNN=0.5000D+00*HO2+...
     &                  +    2.0000D+00 * RXRAT(   360 )      ! OLND+OLND=NO2+0.5040D+...

      PROD(  ADCN     ) =    5.0000D-01 * RXRAT(   155 )      ! PHEN+NO3=0.5000D+00*ADCN+...
     &                  +    5.0000D-01 * RXRAT(   156 )      ! CSL+NO3=0.5000D+00*ADCN+...
      LOSS(  ADCN     ) =                 RXRAT(   207 )      ! ADCN+NO=0.2000D+01*NO2+GLY+OP2
     &                  +                 RXRAT(   246 )      ! ADCN+HO2=OP2
     &                  +                 RXRAT(   283 )      ! ADCN+MO2=HO2+0.7000D+...
     &                  +                 RXRAT(   319 )      ! ADCN+ACO3=HO2+MO2+0.7000D+...
     &                  +                 RXRAT(   357 )      ! ADCN+NO3=0.2000D+01*NO2+...

      PROD(  TOLP     ) =    2.8000D-01 * RXRAT(   160 )      ! TR2=0.2800D+00*TOLP+...
      LOSS(  TOLP     ) =                 RXRAT(   161 )      ! TOLP=0.4900D+00*HO+0.1000D-...
     &                  +                 RXRAT(   182 )      ! TOLP+NO=0.9500D+00*HO2+...
     &                  +                 RXRAT(   222 )      ! TOLP+HO2=OP2
     &                  +                 RXRAT(   258 )      ! TOLP+MO2=0.2000D+01*HO2+...
     &                  +                 RXRAT(   294 )      ! TOLP+ACO3=HO2+MO2+DCB2
     &                  +                 RXRAT(   332 )      ! TOLP+NO3=HO2+NO2+DCB2

      PROD(  PER1     ) =    1.5000D-01 * RXRAT(   160 )      ! TR2=0.1500D+00*PER1+...
     &                  +    5.0000D-01 * RXRAT(   161 )      ! TOLP=0.5000D+00*PER1+...
      LOSS(  PER1     ) =                 RXRAT(   183 )      ! PER1+NO=0.5000D+00*HO2+...
     &                  +                 RXRAT(   223 )      ! PER1+HO2=OP2
     &                  +                 RXRAT(   259 )      ! PER1+MO2=0.2000D+01*HO2+...
     &                  +                 RXRAT(   295 )      ! PER1+ACO3=HO2+MO2+MGLY+DCB1
     &                  +                 RXRAT(   333 )      ! PER1+NO3=0.5000D+00*HO2+...

      PROD(  XYLP     ) =    3.0800D-01 * RXRAT(   162 )      ! XY2=0.3080D+00*XYLP+...
      LOSS(  XYLP     ) =                 RXRAT(   163 )      ! XYLP=0.3900D+00*HO+0.1000D-...
     &                  +                 RXRAT(   185 )      ! XYLP+NO=0.9500D+00*HO2+...
     &                  +                 RXRAT(   225 )      ! XYLP+HO2=OP2
     &                  +                 RXRAT(   261 )      ! XYLP+MO2=0.2000D+01*HO2+...
     &                  +                 RXRAT(   297 )      ! XYLP+ACO3=HO2+MO2+DCB2
     &                  +                 RXRAT(   335 )      ! XYLP+NO3=HO2+NO2+DCB3

      PROD(  PER2     ) =    1.5000D-01 * RXRAT(   162 )      ! XY2=0.1500D+00*PER2+...
     &                  +    3.0000D-01 * RXRAT(   163 )      ! XYLP=0.3000D+00*PER2+...
     &                  +    1.5000D-01 * RXRAT(   164 )      ! XYO2=0.1500D+00*PER2+...
     &                  +    5.0000D-01 * RXRAT(   165 )      ! XYOP=0.5000D+00*PER2+...
      LOSS(  PER2     ) =                 RXRAT(   186 )      ! PER2+NO=0.9500D+00*HO2+...
     &                  +                 RXRAT(   226 )      ! PER2+HO2=OP2
     &                  +                 RXRAT(   262 )      ! PER2+MO2=0.2000D+01*HO2+...
     &                  +                 RXRAT(   298 )      ! PER2+ACO3=HO2+MO2+MGLY+...
     &                  +                 RXRAT(   336 )      ! PER2+NO3=HO2+NO2+MGLY+DCB1+...

      PROD(  XYOP     ) =    3.0800D-01 * RXRAT(   164 )      ! XYO2=0.3080D+00*XYOP+...
      LOSS(  XYOP     ) =                 RXRAT(   165 )      ! XYOP=0.3900D+00*HO+0.1000D-...
     &                  +                 RXRAT(   187 )      ! XYOP+NO=0.9500D+00*HO2+...
     &                  +                 RXRAT(   227 )      ! XYOP+HO2=OP2
     &                  +                 RXRAT(   263 )      ! XYOP+MO2=0.2000D+01*HO2+...
     &                  +                 RXRAT(   299 )      ! XYOP+ACO3=HO2+MO2+0.3680D+...
     &                  +                 RXRAT(   337 )      ! XYOP+NO3=HO2+NO2+0.3680D+...

      PROD(  BAL1     ) =                 RXRAT(   200 )      ! BALP+NO=BAL1+NO2
     &                  +                 RXRAT(   276 )      ! BALP+MO2=BAL1+HO2+HCHO
     &                  +                 RXRAT(   312 )      ! BALP+ACO3=BAL1+MO2
     &                  +                 RXRAT(   350 )      ! BALP+NO3=BAL1+NO2
      LOSS(  BAL1     ) =                 RXRAT(   201 )      ! BAL1+NO=BAL2+NO2
     &                  +                 RXRAT(   277 )      ! BAL1+MO2=HO2+BAL2+HCHO
     &                  +                 RXRAT(   313 )      ! BAL1+ACO3=MO2+BAL2
     &                  +                 RXRAT(   351 )      ! BAL1+NO3=BAL2+NO2

      PROD(  BAL2     ) =                 RXRAT(   201 )      ! BAL1+NO=BAL2+NO2
     &                  +                 RXRAT(   277 )      ! BAL1+MO2=BAL2+HO2+HCHO
     &                  +                 RXRAT(   313 )      ! BAL1+ACO3=BAL2+MO2
     &                  +                 RXRAT(   351 )      ! BAL1+NO3=BAL2+NO2
      LOSS(  BAL2     ) =                 RXRAT(   209 )      ! BAL2+NO2=ONIT

      PROD(  TOLNRXN  ) =                 RXRAT(   364 )      ! TOLRO2+NO=TOLNRXN+NO
      LOSS(  TOLNRXN  ) =   0.0D0

      PROD(  TOLHRXN  ) =                 RXRAT(   365 )      ! TOLRO2+HO2=TOLHRXN+HO2
      LOSS(  TOLHRXN  ) =   0.0D0

      PROD(  XYLNRXN  ) =                 RXRAT(   366 )      ! XYLRO2+NO=XYLNRXN+NO
      LOSS(  XYLNRXN  ) =   0.0D0

      PROD(  XYLHRXN  ) =                 RXRAT(   367 )      ! XYLRO2+HO2=XYLHRXN+HO2
      LOSS(  XYLHRXN  ) =   0.0D0

      PROD(  BNZNRXN  ) =                 RXRAT(   368 )      ! BENZRO2+NO=BNZNRXN+NO
      LOSS(  BNZNRXN  ) =   0.0D0

      PROD(  BNZHRXN  ) =                 RXRAT(   369 )      ! BENZRO2+HO2=BNZHRXN+HO2
      LOSS(  BNZHRXN  ) =   0.0D0

      PROD(  SESQ     ) =   0.0D0
      LOSS(  SESQ     ) =                 RXRAT(   370 )      ! SESQ+O3=O3+SESQRXN
     &                  +                 RXRAT(   371 )      ! SESQ+HO=HO+SESQRXN
     &                  +                 RXRAT(   372 )      ! SESQ+NO3=NO3+SESQRXN

      PROD(  SESQRXN  ) =                 RXRAT(   370 )      ! SESQ+O3=SESQRXN+O3
     &                  +                 RXRAT(   371 )      ! SESQ+HO=SESQRXN+HO
     &                  +                 RXRAT(   372 )      ! SESQ+NO3=SESQRXN+NO3
      LOSS(  SESQRXN  ) =   0.0D0

      PROD(  NAPH     ) =   0.0D0
      LOSS(  NAPH     ) =                 RXRAT(   373 )      ! NAPH+HO=HO+PAHRO2

      PROD(  PAHRO2   ) =                 RXRAT(   373 )      ! NAPH+HO=PAHRO2+HO
      LOSS(  PAHRO2   ) =                 RXRAT(   374 )      ! PAHRO2+NO=NO+PAHNRXN
     &                  +                 RXRAT(   375 )      ! PAHRO2+HO2=HO2+PAHHRXN

      PROD(  PAHNRXN  ) =                 RXRAT(   374 )      ! PAHRO2+NO=PAHNRXN+NO
      LOSS(  PAHNRXN  ) =   0.0D0

      PROD(  PAHHRXN  ) =                 RXRAT(   375 )      ! PAHRO2+HO2=PAHHRXN+HO2
      LOSS(  PAHHRXN  ) =   0.0D0

      PROD(  SOAALK   ) =   0.0D0
      LOSS(  SOAALK   ) =                 RXRAT(   376 )      ! SOAALK+HO=HO+0.4700D+00*ALKRXN

      PROD(  ALKRXN   ) =    4.7000D-01 * RXRAT(   376 )      ! SOAALK+HO=0.4700D+00*ALKRXN+HO
      LOSS(  ALKRXN   ) =   0.0D0

      PROD(  AISO3J   ) =                 RXRAT(   381 )      ! IEPOX=AISO3J
      LOSS(  AISO3J   ) =   0.0D0

      PROD(  AXYL1J   ) =   0.0D0
      LOSS(  AXYL1J   ) =                 RXRAT(   382 )      ! AXYL1J=0.8571D+00*AOLGAJ

      PROD(  AOLGAJ   ) =    8.5710D-01 * RXRAT(   382 )      ! AXYL1J=0.8571D+00*AOLGAJ
     &                  +    1.1429D+00 * RXRAT(   383 )      ! AXYL2J=0.1143D+01*AOLGAJ
     &                  +    8.5710D-01 * RXRAT(   384 )      ! ATOL1J=0.8571D+00*AOLGAJ
     &                  +    1.1429D+00 * RXRAT(   385 )      ! ATOL2J=0.1143D+01*AOLGAJ
     &                  +    7.1430D-01 * RXRAT(   386 )      ! ABNZ1J=0.7143D+00*AOLGAJ
     &                  +    7.1430D-01 * RXRAT(   387 )      ! ABNZ2J=0.7143D+00*AOLGAJ
     &                  +    1.4286D+00 * RXRAT(   393 )      ! APAH1J=0.1429D+01*AOLGAJ
     &                  +    1.4286D+00 * RXRAT(   394 )      ! APAH2J=0.1429D+01*AOLGAJ
     &                  +    1.7143D+00 * RXRAT(   395 )      ! AALK1J=0.1714D+01*AOLGAJ
     &                  +    1.7143D+00 * RXRAT(   396 )      ! AALK2J=0.1714D+01*AOLGAJ
      LOSS(  AOLGAJ   ) =   0.0D0

      PROD(  AXYL2J   ) =   0.0D0
      LOSS(  AXYL2J   ) =                 RXRAT(   383 )      ! AXYL2J=0.1143D+01*AOLGAJ

      PROD(  ATOL1J   ) =   0.0D0
      LOSS(  ATOL1J   ) =                 RXRAT(   384 )      ! ATOL1J=0.8571D+00*AOLGAJ

      PROD(  ATOL2J   ) =   0.0D0
      LOSS(  ATOL2J   ) =                 RXRAT(   385 )      ! ATOL2J=0.1143D+01*AOLGAJ

      PROD(  ABNZ1J   ) =   0.0D0
      LOSS(  ABNZ1J   ) =                 RXRAT(   386 )      ! ABNZ1J=0.7143D+00*AOLGAJ

      PROD(  ABNZ2J   ) =   0.0D0
      LOSS(  ABNZ2J   ) =                 RXRAT(   387 )      ! ABNZ2J=0.7143D+00*AOLGAJ

      PROD(  ATRP1J   ) =   0.0D0
      LOSS(  ATRP1J   ) =                 RXRAT(   388 )      ! ATRP1J=0.8000D+00*AOLGBJ

      PROD(  AOLGBJ   ) =    8.0000D-01 * RXRAT(   388 )      ! ATRP1J=0.8000D+00*AOLGBJ
     &                  +    9.0000D-01 * RXRAT(   389 )      ! ATRP2J=0.9000D+00*AOLGBJ
     &                  +    5.0000D-01 * RXRAT(   390 )      ! AISO1J=0.5000D+00*AOLGBJ
     &                  +    5.0000D-01 * RXRAT(   391 )      ! AISO2J=0.5000D+00*AOLGBJ
     &                  +    1.5000D+00 * RXRAT(   392 )      ! ASQTJ=0.1500D+01*AOLGBJ
      LOSS(  AOLGBJ   ) =   0.0D0

      PROD(  ATRP2J   ) =   0.0D0
      LOSS(  ATRP2J   ) =                 RXRAT(   389 )      ! ATRP2J=0.9000D+00*AOLGBJ

      PROD(  AISO1J   ) =   0.0D0
      LOSS(  AISO1J   ) =                 RXRAT(   390 )      ! AISO1J=0.5000D+00*AOLGBJ

      PROD(  AISO2J   ) =   0.0D0
      LOSS(  AISO2J   ) =                 RXRAT(   391 )      ! AISO2J=0.5000D+00*AOLGBJ

      PROD(  ASQTJ    ) =   0.0D0
      LOSS(  ASQTJ    ) =                 RXRAT(   392 )      ! ASQTJ=0.1500D+01*AOLGBJ

      PROD(  APAH1J   ) =   0.0D0
      LOSS(  APAH1J   ) =                 RXRAT(   393 )      ! APAH1J=0.1429D+01*AOLGAJ

      PROD(  APAH2J   ) =   0.0D0
      LOSS(  APAH2J   ) =                 RXRAT(   394 )      ! APAH2J=0.1429D+01*AOLGAJ

      PROD(  AALK1J   ) =   0.0D0
      LOSS(  AALK1J   ) =                 RXRAT(   395 )      ! AALK1J=0.1714D+01*AOLGAJ

      PROD(  AALK2J   ) =   0.0D0
      LOSS(  AALK2J   ) =                 RXRAT(   396 )      ! AALK2J=0.1714D+01*AOLGAJ

      PROD(  APOCI    ) =   0.0D0
      LOSS(  APOCI    ) =   0.0D0

      PROD(  APNCOMI  ) =    1.2500D+00 * RXRAT(   397 )      ! APOCI+HO=0.1250D+...
      LOSS(  APNCOMI  ) =                 RXRAT(   398 )      ! APNCOMI+HO=HO

      PROD(  APOCJ    ) =   0.0D0
      LOSS(  APOCJ    ) =   0.0D0

      PROD(  APNCOMJ  ) =    1.2500D+00 * RXRAT(   399 )      ! APOCJ+HO=0.1250D+...
      LOSS(  APNCOMJ  ) =                 RXRAT(   400 )      ! APNCOMJ+HO=HO

      PROD(  PCVOC    ) =   0.0D0
      LOSS(  PCVOC    ) =                 RXRAT(   401 )      ! PCVOC+HO=HO+PCSOARXN

      PROD(  PCSOARXN ) =                 RXRAT(   401 )      ! PCVOC+HO=PCSOARXN+HO
      LOSS(  PCSOARXN ) =   0.0D0

      PROD(  VLVPO1   ) =    3.0030D-01 * RXRAT(   403 )      ! VSVPO1+HO=0.3003D+...
     &                  +    3.8560D-01 * RXRAT(   404 )      ! VSVPO2+HO=0.3856D+...
     &                  +    2.1810D-01 * RXRAT(   405 )      ! VSVPO3+HO=0.2181D+...
     &                  +    2.4120D-01 * RXRAT(   406 )      ! VIVPO1+HO=0.2412D+...
      LOSS(  VLVPO1   ) =    5.1430D-01 * RXRAT(   402 )      ! VLVPO1+HO=0.4857D+...

      PROD(  VSVPO1   ) =    6.2000D-03 * RXRAT(   402 )      ! VLVPO1+HO=0.6200D-...
     &                  +    9.5000D-02 * RXRAT(   404 )      ! VSVPO2+HO=0.9500D-...
     &                  +    3.0630D-01 * RXRAT(   405 )      ! VSVPO3+HO=0.3063D+...
     &                  +    2.0890D-01 * RXRAT(   406 )      ! VIVPO1+HO=0.2089D+...
      LOSS(  VSVPO1   ) =    7.1380D-01 * RXRAT(   403 )      ! VSVPO1+HO=0.2862D+...

      PROD(  VSVPO2   ) =    2.5000D-03 * RXRAT(   402 )      ! VLVPO1+HO=0.2500D-...
     &                  +    4.1000D-03 * RXRAT(   403 )      ! VSVPO1+HO=0.4100D-...
     &                  +    1.5300D-02 * RXRAT(   405 )      ! VSVPO3+HO=0.1530D-...
     &                  +    3.0000D-01 * RXRAT(   406 )      ! VIVPO1+HO=0.3000D+...
      LOSS(  VSVPO2   ) =    8.6270D-01 * RXRAT(   404 )      ! VSVPO2+HO=0.1373D+...

      PROD(  VSVPO3   ) =    2.6000D-03 * RXRAT(   402 )      ! VLVPO1+HO=0.2600D-...
     &                  +    3.5000D-03 * RXRAT(   403 )      ! VSVPO1+HO=0.3500D-...
     &                  +    5.0000D-04 * RXRAT(   404 )      ! VSVPO2+HO=0.5000D-...
      LOSS(  VSVPO3   ) =    8.9570D-01 * RXRAT(   405 )      ! VSVPO3+HO=0.1043D+...

      PROD(  VIVPO1   ) =    2.3000D-03 * RXRAT(   402 )      ! VLVPO1+HO=0.2300D-...
      LOSS(  VIVPO1   ) =                 RXRAT(   406 )      ! VIVPO1+HO=HO+0.2412D+...

      PROD(  VLVOO1   ) =    2.9440D-01 * RXRAT(   402 )      ! VLVPO1+HO=0.2944D+...
     &                  +    2.2390D-01 * RXRAT(   403 )      ! VSVPO1+HO=0.2239D+...
     &                  +    2.0510D-01 * RXRAT(   404 )      ! VSVPO2+HO=0.2051D+...
     &                  +    1.8930D-01 * RXRAT(   405 )      ! VSVPO3+HO=0.1893D+...
     &                  +    2.0280D-01 * RXRAT(   406 )      ! VIVPO1+HO=0.2028D+...
     &                  +    2.8580D-01 * RXRAT(   408 )      ! VLVOO2+HO=0.2858D+...
     &                  +    3.3030D-01 * RXRAT(   409 )      ! VSVOO1+HO=0.3303D+...
     &                  +    3.4440D-01 * RXRAT(   410 )      ! VSVOO2+HO=0.3444D+...
     &                  +    3.8860D-01 * RXRAT(   411 )      ! VSVOO3+HO=0.3886D+...
      LOSS(  VLVOO1   ) =    3.3360D-01 * RXRAT(   407 )      ! VLVOO1+HO=0.6664D+...

      PROD(  VLVOO2   ) =    2.0210D-01 * RXRAT(   402 )      ! VLVPO1+HO=0.2021D+...
     &                  +    1.8200D-01 * RXRAT(   403 )      ! VSVPO1+HO=0.1820D+...
     &                  +    1.7640D-01 * RXRAT(   404 )      ! VSVPO2+HO=0.1764D+...
     &                  +    1.6680D-01 * RXRAT(   405 )      ! VSVPO3+HO=0.1668D+...
     &                  +    4.7100D-02 * RXRAT(   406 )      ! VIVPO1+HO=0.4710D-...
     &                  +    1.4300D-02 * RXRAT(   407 )      ! VLVOO1+HO=0.1430D-...
     &                  +    2.2720D-01 * RXRAT(   409 )      ! VSVOO1+HO=0.2272D+...
     &                  +    2.7490D-01 * RXRAT(   410 )      ! VSVOO2+HO=0.2749D+...
     &                  +    2.4210D-01 * RXRAT(   411 )      ! VSVOO3+HO=0.2421D+...
      LOSS(  VLVOO2   ) =    6.0690D-01 * RXRAT(   408 )      ! VLVOO2+HO=0.3931D+...

      PROD(  VSVOO2   ) =    1.9000D-03 * RXRAT(   402 )      ! VLVPO1+HO=0.1900D-...
     &                  +    1.2390D-01 * RXRAT(   407 )      ! VLVOO1+HO=0.1239D+...
     &                  +    1.0270D-01 * RXRAT(   408 )      ! VLVOO2+HO=0.1027D+...
     &                  +    7.0200D-02 * RXRAT(   409 )      ! VSVOO1+HO=0.7020D-...
     &                  +    3.8500D-02 * RXRAT(   411 )      ! VSVOO3+HO=0.3850D-...
      LOSS(  VSVOO2   ) =    7.4230D-01 * RXRAT(   410 )      ! VSVOO2+HO=0.2577D+...

      PROD(  VSVOO3   ) =    2.3000D-03 * RXRAT(   402 )      ! VLVPO1+HO=0.2300D-...
     &                  +    1.8310D-01 * RXRAT(   407 )      ! VLVOO1+HO=0.1831D+...
     &                  +    2.0450D-01 * RXRAT(   408 )      ! VLVOO2+HO=0.2045D+...
     &                  +    1.1160D-01 * RXRAT(   409 )      ! VSVOO1+HO=0.1116D+...
     &                  +    7.3900D-02 * RXRAT(   410 )      ! VSVOO2+HO=0.7390D-...
      LOSS(  VSVOO3   ) =    7.3330D-01 * RXRAT(   411 )      ! VSVOO3+HO=0.2667D+...

      PROD(  VSVOO1   ) =    1.2300D-02 * RXRAT(   407 )      ! VLVOO1+HO=0.1230D-...
     &                  +    1.3900D-02 * RXRAT(   408 )      ! VLVOO2+HO=0.1390D-...
     &                  +    4.9100D-02 * RXRAT(   410 )      ! VSVOO2+HO=0.4910D-...
     &                  +    6.4000D-02 * RXRAT(   411 )      ! VSVOO3+HO=0.6400D-...
      LOSS(  VSVOO1   ) =    7.3930D-01 * RXRAT(   409 )      ! VSVOO1+HO=0.2607D+...

      RETURN

      END
