
!------------------------------------------------------------------------!
!  The Community Multiscale Air Quality (CMAQ) system software is in     !
!  continuous development by various groups and is based on information  !
!  from these groups: Federal Government employees, contractors working  !
!  within a United States Government contract, and non-Federal sources   !
!  including research institutions.  These groups give the Government    !
!  permission to use, prepare derivative works of, and distribute copies !
!  of their work in the CMAQ system to the public and to permit others   !
!  to do so.  The United States Environmental Protection Agency          !
!  therefore grants similar permission to use the CMAQ system software,  !
!  but users are requested to provide copies of derivative works or      !
!  products designed to operate in the CMAQ system to the United States  !
!  Government without restrictions as to use by others.  Software        !
!  that is used with the CMAQ system but distributed under the GNU       !
!  General Public License or the GNU Lesser General Public License is    !
!  subject to their copyright restrictions.                              !
!------------------------------------------------------------------------!

      SUBROUTINE HRPRODLOSS

C***********************************************************************
C
C  FUNCTION: To compute the production and loss rates for EBI species 
C
R1  PRECONDITIONS: For SAPRC99 family of mechanisms only
C
C  RETURN VALUES: None
C
C  KEY SUBROUTINES/FUNCTIONS CALLED: None
C
R2  REVISION HISTORY: Prototype created by Jerry Gipson, September, 2003
C
C   18 Jul 14 B.Hutzell: revised to use real(8) variables                   

C***********************************************************************
      USE HRDATA

      IMPLICIT NONE


C.....INCLUDES: NONE


C.....ARGUMENTS: NONE 


C.....PARAMETERS: NONE


C.....EXTERNAL FUNCTIONS: NONE


C.....SAVED VARIABLES: NONE
!     CHARACTER( 16 ), SAVE  ::  PNAME = 'HRPRODLOSS'   ! Program name


C.....LOCAL VARIABLES: 


C***********************************************************************

S1

      PROD( NCELL, HNO3     ) =    2.000 * RXRAT(  13 )
     &                   +          RXRAT(  25 )
     &                   +  0.200 * RXRAT(  39 )
     &                   +          RXRAT( 129 )
     &                   +          RXRAT( 132 )
     &                   +          RXRAT( 135 )
     &                   +          RXRAT( 148 )
     &                   +          RXRAT( 151 )
     &                   +          RXRAT( 154 )
     &                   +          RXRAT( 156 )
     &                   +          RXRAT( 157 )
     &                   +          RXRAT( 160 )
     &                   +  0.500 * RXRAT( 163 )
     &                   +  0.150 * RXRAT( 172 )
      LOSS( NCELL, HNO3     ) =            RXRAT(  27 )
     &                   +          RXRAT(  28 )

      PROD( NCELL, CO       ) =            RXRAT( 123 )
     &                   +          RXRAT( 124 )
     &                   +          RXRAT( 125 )
     &                   +          RXRAT( 129 )
     &                   +          RXRAT( 131 )
     &                   +  0.034 * RXRAT( 133 )
     &                   +          RXRAT( 134 )
     &                   +  2.000 * RXRAT( 145 )
     &                   +          RXRAT( 146 )
     &                   +  1.260 * RXRAT( 147 )
     &                   +  1.260 * RXRAT( 148 )
     &                   +          RXRAT( 149 )
     &                   +          RXRAT( 150 )
     &                   +          RXRAT( 151 )
     &                   +  0.416 * RXRAT( 161 )
     &                   +  0.450 * RXRAT( 162 )
     &                   +  0.500 * RXRAT( 163 )
     &                   +  0.670 * RXRAT( 165 )
     &                   +  0.475 * RXRAT( 167 )
     &                   +  0.700 * RXRAT( 169 )
     &                   +  0.336 * RXRAT( 170 )
     &                   +  0.498 * RXRAT( 171 )
     &                   +  0.572 * RXRAT( 172 )
     &                   +  1.233 * RXRAT( 173 )
     &                   +          RXRAT( 178 )
     &                   +  1.500 * RXRAT( 179 )
     &                   +          RXRAT( 181 )
     &                   +          RXRAT( 183 )
     &                   +  0.500 * RXRAT( 186 )
     &                   +  0.491 * RXRAT( 188 )
     &                   +  0.275 * RXRAT( 190 )
     &                   +  0.157 * RXRAT( 194 )
     &                   +  0.160 * RXRAT( 198 )
     &                   +  0.002 * RXRAT( 200 )
     &                   +  0.345 * RXRAT( 205 )
     &                   +  0.265 * RXRAT( 209 )
     &                   +  0.012 * RXRAT( 211 )
      LOSS( NCELL, CO       ) =            RXRAT(  29 )

      PROD( NCELL, HO2H     ) =            RXRAT(  37 )
     &                   +          RXRAT(  38 )
      LOSS( NCELL, HO2H     ) =            RXRAT(  41 )
     &                   +          RXRAT(  42 )

      PROD( NCELL, SO2      ) =    0.0
      LOSS( NCELL, SO2      ) =            RXRAT(  44 )

      PROD( NCELL, SULF     ) =            RXRAT(  44 )
      LOSS( NCELL, SULF     ) =    0.0

      PROD( NCELL, C_O2     ) =            RXRAT(  71 )
     &                   +          RXRAT(  73 )
     &                   +  2.000 * RXRAT(  78 )
     &                   +          RXRAT(  88 )
     &                   +          RXRAT(  99 )
     &                   +          RXRAT( 111 )
     &                   +          RXRAT( 116 )
     &                   +          RXRAT( 131 )
     &                   +          RXRAT( 137 )
     &                   +  0.650 * RXRAT( 141 )
     &                   +  0.300 * RXRAT( 169 )
     &                   +          RXRAT( 184 )
     &                   +  0.300 * RXRAT( 188 )
     &                   +  0.250 * RXRAT( 192 )
     &                   +  0.011 * RXRAT( 200 )
     &                   +  0.076 * RXRAT( 205 )
     &                   +  0.197 * RXRAT( 209 )
     &                   +  0.030 * RXRAT( 210 )
     &                   +  0.870 * RXRAT( 213 )
      LOSS( NCELL, C_O2     ) =            RXRAT(  46 )
     &                   +          RXRAT(  47 )
     &                   +          RXRAT(  48 )
     &                   +  2.000 * RXRAT(  49 )
     &                   +  2.000 * RXRAT(  50 )
     &                   +          RXRAT(  54 )
     &                   +          RXRAT(  64 )
     &                   +          RXRAT(  74 )
     &                   +          RXRAT(  84 )
     &                   +          RXRAT(  95 )
     &                   +          RXRAT( 107 )

      PROD( NCELL, HCHO     ) =            RXRAT(  46 )
     &                   +          RXRAT(  48 )
     &                   +          RXRAT(  49 )
     &                   +  2.000 * RXRAT(  50 )
     &                   +  0.750 * RXRAT(  54 )
     &                   +  0.750 * RXRAT(  64 )
     &                   +          RXRAT(  74 )
     &                   +          RXRAT(  84 )
     &                   +          RXRAT(  95 )
     &                   +          RXRAT( 104 )
     &                   +          RXRAT( 106 )
     &                   +          RXRAT( 107 )
     &                   +          RXRAT( 111 )
     &                   +          RXRAT( 112 )
     &                   +          RXRAT( 113 )
     &                   +  2.000 * RXRAT( 114 )
     &                   +          RXRAT( 127 )
     &                   +          RXRAT( 136 )
     &                   +  0.115 * RXRAT( 138 )
     &                   +          RXRAT( 140 )
     &                   +  0.350 * RXRAT( 141 )
     &                   +          RXRAT( 142 )
     &                   +          RXRAT( 146 )
     &                   +  0.084 * RXRAT( 161 )
     &                   +  0.200 * RXRAT( 162 )
     &                   +  0.670 * RXRAT( 165 )
     &                   +  0.300 * RXRAT( 166 )
     &                   +  0.100 * RXRAT( 167 )
     &                   +  0.055 * RXRAT( 170 )
     &                   +  0.125 * RXRAT( 171 )
     &                   +  0.227 * RXRAT( 172 )
     &                   +  0.300 * RXRAT( 173 )
     &                   +  0.213 * RXRAT( 174 )
     &                   +  0.506 * RXRAT( 175 )
     &                   +  0.010 * RXRAT( 176 )
     &                   +  0.134 * RXRAT( 177 )
     &                   +  1.610 * RXRAT( 185 )
     &                   +          RXRAT( 186 )
     &                   +  0.191 * RXRAT( 188 )
     &                   +  0.624 * RXRAT( 189 )
     &                   +  0.592 * RXRAT( 190 )
     &                   +  0.240 * RXRAT( 192 )
     &                   +  0.276 * RXRAT( 193 )
     &                   +  0.235 * RXRAT( 194 )
     &                   +  0.039 * RXRAT( 198 )
     &                   +  0.026 * RXRAT( 199 )
     &                   +  0.024 * RXRAT( 200 )
     &                   +  0.026 * RXRAT( 201 )
     &                   +  0.732 * RXRAT( 204 )
     &                   +  0.500 * RXRAT( 205 )
     &                   +  0.244 * RXRAT( 208 )
     &                   +  0.269 * RXRAT( 209 )
     &                   +  0.079 * RXRAT( 210 )
      LOSS( NCELL, HCHO     ) =            RXRAT( 123 )
     &                   +          RXRAT( 124 )
     &                   +          RXRAT( 125 )
     &                   +          RXRAT( 126 )
     &                   +          RXRAT( 129 )

      PROD( NCELL, COOH     ) =            RXRAT(  47 )
      LOSS( NCELL, COOH     ) =            RXRAT( 141 )
     &                   +          RXRAT( 142 )

      PROD( NCELL, MEOH     ) =            RXRAT(  49 )
     &                   +  0.250 * RXRAT(  54 )
     &                   +  0.250 * RXRAT(  64 )
      LOSS( NCELL, MEOH     ) =            RXRAT( 140 )

      PROD( NCELL, RO2_R    ) =            RXRAT(  81 )
     &                   +          RXRAT(  83 )
     &                   +          RXRAT(  88 )
     &                   +  2.000 * RXRAT(  89 )
     &                   +          RXRAT( 100 )
     &                   +          RXRAT( 112 )
     &                   +  0.034 * RXRAT( 133 )
     &                   +          RXRAT( 134 )
     &                   +  0.370 * RXRAT( 138 )
     &                   +          RXRAT( 139 )
     &                   +  0.340 * RXRAT( 143 )
     &                   +  0.760 * RXRAT( 153 )
     &                   +  0.760 * RXRAT( 155 )
     &                   +  0.500 * RXRAT( 161 )
     &                   +  0.100 * RXRAT( 162 )
     &                   +  0.500 * RXRAT( 163 )
     &                   +  0.330 * RXRAT( 165 )
     &                   +  0.300 * RXRAT( 166 )
     &                   +  0.050 * RXRAT( 167 )
     &                   +  0.670 * RXRAT( 170 )
     &                   +  0.048 * RXRAT( 171 )
     &                   +  0.799 * RXRAT( 172 )
     &                   +  0.473 * RXRAT( 174 )
     &                   +  0.960 * RXRAT( 175 )
     &                   +  0.376 * RXRAT( 176 )
     &                   +  0.564 * RXRAT( 177 )
     &                   +          RXRAT( 178 )
     &                   +          RXRAT( 181 )
     &                   +          RXRAT( 183 )
     &                   +          RXRAT( 185 )
     &                   +          RXRAT( 187 )
     &                   +  0.200 * RXRAT( 188 )
     &                   +  0.907 * RXRAT( 189 )
     &                   +  0.066 * RXRAT( 190 )
     &                   +  0.749 * RXRAT( 191 )
     &                   +  0.750 * RXRAT( 193 )
     &                   +  0.031 * RXRAT( 194 )
     &                   +  0.276 * RXRAT( 195 )
     &                   +          RXRAT( 197 )
     &                   +  0.612 * RXRAT( 198 )
     &                   +  0.695 * RXRAT( 199 )
     &                   +  0.835 * RXRAT( 200 )
     &                   +  0.653 * RXRAT( 201 )
     &                   +  0.765 * RXRAT( 202 )
     &                   +  0.804 * RXRAT( 203 )
     &                   +  0.910 * RXRAT( 204 )
     &                   +  0.022 * RXRAT( 205 )
     &                   +  0.824 * RXRAT( 206 )
     &                   +  0.918 * RXRAT( 208 )
     &                   +  0.033 * RXRAT( 209 )
     &                   +  0.442 * RXRAT( 210 )
     &                   +  0.012 * RXRAT( 211 )
     &                   +  0.130 * RXRAT( 213 )
     &                   +          RXRAT( 214 )
      LOSS( NCELL, RO2_R    ) =            RXRAT(  51 )
     &                   +          RXRAT(  52 )
     &                   +          RXRAT(  53 )
     &                   +          RXRAT(  54 )
     &                   +  2.000 * RXRAT(  55 )
     &                   +          RXRAT(  66 )
     &                   +          RXRAT(  75 )
     &                   +          RXRAT(  85 )
     &                   +          RXRAT(  96 )
     &                   +          RXRAT( 108 )

      PROD( NCELL, ROOH     ) =            RXRAT(  52 )
     &                   +          RXRAT(  63 )
      LOSS( NCELL, ROOH     ) =            RXRAT( 143 )
     &                   +          RXRAT( 144 )

      PROD( NCELL, R2O2     ) =            RXRAT(  92 )
     &                   +          RXRAT(  94 )
     &                   +          RXRAT(  99 )
     &                   +          RXRAT( 100 )
     &                   +  2.000 * RXRAT( 101 )
     &                   +          RXRAT( 113 )
     &                   +          RXRAT( 136 )
     &                   +  0.616 * RXRAT( 138 )
     &                   +  0.675 * RXRAT( 166 )
     &                   +  0.515 * RXRAT( 175 )
     &                   +  0.596 * RXRAT( 176 )
     &                   +  0.152 * RXRAT( 177 )
     &                   +          RXRAT( 180 )
     &                   +          RXRAT( 181 )
     &                   +          RXRAT( 182 )
     &                   +          RXRAT( 183 )
     &                   +  0.079 * RXRAT( 189 )
     &                   +  0.126 * RXRAT( 190 )
     &                   +  0.187 * RXRAT( 191 )
     &                   +  0.240 * RXRAT( 192 )
     &                   +  0.500 * RXRAT( 193 )
     &                   +  0.729 * RXRAT( 194 )
     &                   +  0.750 * RXRAT( 195 )
     &                   +  0.559 * RXRAT( 199 )
     &                   +  0.936 * RXRAT( 200 )
     &                   +  0.948 * RXRAT( 201 )
     &                   +  0.205 * RXRAT( 204 )
     &                   +  0.488 * RXRAT( 206 )
     &                   +  0.001 * RXRAT( 208 )
     &                   +  0.137 * RXRAT( 209 )
     &                   +  0.711 * RXRAT( 210 )
      LOSS( NCELL, R2O2     ) =            RXRAT(  56 )
     &                   +          RXRAT(  57 )
     &                   +          RXRAT(  58 )
     &                   +          RXRAT(  59 )
     &                   +          RXRAT(  60 )
     &                   +  2.000 * RXRAT(  61 )
     &                   +          RXRAT(  67 )
     &                   +          RXRAT(  76 )
     &                   +          RXRAT(  86 )
     &                   +          RXRAT(  97 )
     &                   +          RXRAT( 109 )

      PROD( NCELL, RO2_N    ) =    0.001 * RXRAT( 133 )
     &                   +  0.042 * RXRAT( 138 )
     &                   +  0.025 * RXRAT( 166 )
     &                   +  0.041 * RXRAT( 170 )
     &                   +  0.051 * RXRAT( 172 )
     &                   +  0.070 * RXRAT( 174 )
     &                   +  0.040 * RXRAT( 175 )
     &                   +  0.173 * RXRAT( 176 )
     &                   +  0.095 * RXRAT( 177 )
     &                   +  0.093 * RXRAT( 189 )
     &                   +  0.008 * RXRAT( 190 )
     &                   +  0.064 * RXRAT( 191 )
     &                   +  0.010 * RXRAT( 192 )
     &                   +  0.250 * RXRAT( 193 )
     &                   +  0.180 * RXRAT( 194 )
     &                   +  0.250 * RXRAT( 195 )
     &                   +  0.021 * RXRAT( 198 )
     &                   +  0.070 * RXRAT( 199 )
     &                   +  0.143 * RXRAT( 200 )
     &                   +  0.347 * RXRAT( 201 )
     &                   +  0.011 * RXRAT( 202 )
     &                   +  0.009 * RXRAT( 203 )
     &                   +  0.090 * RXRAT( 204 )
     &                   +  0.001 * RXRAT( 205 )
     &                   +  0.176 * RXRAT( 206 )
     &                   +  0.082 * RXRAT( 208 )
     &                   +  0.002 * RXRAT( 209 )
     &                   +  0.136 * RXRAT( 210 )
     &                   +  0.001 * RXRAT( 211 )
      LOSS( NCELL, RO2_N    ) =            RXRAT(  62 )
     &                   +          RXRAT(  63 )
     &                   +          RXRAT(  64 )
     &                   +          RXRAT(  65 )
     &                   +          RXRAT(  66 )
     &                   +  2.000 * RXRAT(  68 )
     &                   +          RXRAT(  77 )
     &                   +          RXRAT(  87 )
     &                   +          RXRAT(  98 )
     &                   +          RXRAT( 110 )

      PROD( NCELL, RNO3     ) =            RXRAT(  62 )
     &                   +          RXRAT( 115 )
     &                   +  0.572 * RXRAT( 172 )
     &                   +  0.276 * RXRAT( 195 )
     &                   +  0.511 * RXRAT( 206 )
     &                   +  0.321 * RXRAT( 210 )
      LOSS( NCELL, RNO3     ) =    0.690 * RXRAT( 176 )
     &                   +          RXRAT( 177 )

      PROD( NCELL, MEK      ) =    0.500 * RXRAT(  64 )
     &                   +          RXRAT(  65 )
     &                   +  0.500 * RXRAT(  66 )
     &                   +          RXRAT(  68 )
     &                   +  0.416 * RXRAT( 161 )
     &                   +  0.550 * RXRAT( 168 )
     &                   +  0.150 * RXRAT( 170 )
     &                   +  0.210 * RXRAT( 171 )
     &                   +  0.233 * RXRAT( 173 )
     &                   +  0.115 * RXRAT( NCE LL, 174 )
     &                   +  0.177 * RXRAT( 176 )
     &                   +  0.243 * RXRAT( 177 )
     &                   +  0.332 * RXRAT( 199 )
     &                   +  0.110 * RXRAT( 200 )
     &                   +  0.089 * RXRAT( 201 )
     &                   +  0.437 * RXRAT( 207 )
     &                   +  0.072 * RXRAT( 208 )
     &                   +  0.026 * RXRAT( 209 )
     &                   +  0.001 * RXRAT( 210 )
     &                   +  0.659 * RXRAT( 211 )
      LOSS( NCELL, MEK      ) =            RXRAT( 138 )
     &                   +          RXRAT( 139 )

      PROD( NCELL, PROD2    ) =    0.500 * RXRAT(  64 )
     &                   +  0.500 * RXRAT(  66 )
     &                   +          RXRAT(  68 )
     &                   +          RXRAT(  77 )
     &                   +          RXRAT(  87 )
     &                   +          RXRAT(  98 )
     &                   +  0.700 * RXRAT( 169 )
     &                   +  0.332 * RXRAT( 170 )
     &                   +  0.048 * RXRAT( 176 )
     &                   +  0.435 * RXRAT( 177 )
     &                   +  0.100 * RXRAT( 190 )
     &                   +  0.750 * RXRAT( 192 )
     &                   +  0.276 * RXRAT( 193 )
     &                   +  0.276 * RXRAT( 194 )
     &                   +  0.853 * RXRAT( 196 )
     &                   +  0.125 * RXRAT( 200 )
     &                   +  0.417 * RXRAT( 201 )
     &                   +  0.055 * RXRAT( 202 )
     &                   +  0.119 * RXRAT( 204 )
     &                   +  0.215 * RXRAT( 205 )
     &                   +  0.113 * RXRAT( 207 )
     &                   +  0.006 * RXRAT( 209 )
     &                   +  0.259 * RXRAT( 211 )
      LOSS( NCELL, PROD2    ) =    0.671 * RXRAT( 174 )
     &                   +          RXRAT( 175 )

      PROD( NCELL, CCO_OOH  ) =    0.750 * RXRAT(  72 )
      LOSS( NCELL, CCO_OOH  ) =    0.0

      PROD( NCELL, CCO_OH   ) =    0.250 * RXRAT(  72 )
     &                   +          RXRAT(  74 )
     &                   +          RXRAT(  75 )
     &                   +          RXRAT(  77 )
     &                   +  0.050 * RXRAT( 205 )
     &                   +  0.129 * RXRAT( 209 )
      LOSS( NCELL, CCO_OH   ) =            RXRAT( 213 )

      PROD( NCELL, RCO_O2   ) =            RXRAT(  80 )
     &                   +  0.965 * RXRAT( 133 )
     &                   +          RXRAT( 135 )
     &                   +  0.096 * RXRAT( 138 )
     &                   +  0.370 * RXRAT( 147 )
     &                   +  0.370 * RXRAT( 148 )
     &                   +  0.100 * RXRAT( 162 )
     &                   +  0.050 * RXRAT( 167 )
     &                   +  0.048 * RXRAT( 171 )
     &                   +  0.300 * RXRAT( 173 )
     &                   +  0.049 * RXRAT( 174 )
     &                   +  0.333 * RXRAT( 175 )
     &                   +  0.201 * RXRAT( 194 )
     &                   +  0.006 * RXRAT( 209 )
      LOSS( NCELL, RCO_O2   ) =            RXRAT(  79 )
     &                   +          RXRAT(  81 )
     &                   +          RXRAT(  82 )
     &                   +          RXRAT(  83 )
     &                   +          RXRAT(  84 )
     &                   +          RXRAT(  85 )
     &                   +          RXRAT(  87 )
     &                   +          RXRAT(  88 )
     &                   +  2.000 * RXRAT(  89 )
     &                   +          RXRAT( 100 )
     &                   +          RXRAT( 112 )

      PROD( NCELL, PAN2     ) =            RXRAT(  79 )
      LOSS( NCELL, PAN2     ) =            RXRAT(  80 )

      PROD( NCELL, CCHO     ) =            RXRAT(  81 )
     &                   +          RXRAT(  83 )
     &                   +          RXRAT(  88 )
     &                   +  2.000 * RXRAT(  89 )
     &                   +          RXRAT( 100 )
     &                   +          RXRAT( 112 )
     &                   +  0.034 * RXRAT( 133 )
     &                   +          RXRAT( 134 )
     &                   +  0.482 * RXRAT( 138 )
     &                   +          RXRAT( 139 )
     &                   +  0.129 * RXRAT( 170 )
     &                   +  0.047 * RXRAT( 171 )
     &                   +  0.467 * RXRAT( 173 )
     &                   +  0.084 * RXRAT( 174 )
     &                   +  0.246 * RXRAT( 175 )
     &                   +  0.439 * RXRAT( 176 )
     &                   +  0.431 * RXRAT( 177 )
     &                   +  0.195 * RXRAT( 185 )
     &                   +  0.250 * RXRAT( 188 )
     &                   +          RXRAT( 197 )
     &                   +  0.445 * RXRAT( 199 )
     &                   +  0.455 * RXRAT( 200 )
     &                   +  0.099 * RXRAT( 201 )
     &                   +  0.294 * RXRAT( 204 )
     &                   +  0.154 * RXRAT( 205 )
     &                   +  0.009 * RXRAT( 206 )
     &                   +  0.732 * RXRAT( 208 )
     &                   +  0.456 * RXRAT( 209 )
     &                   +  0.507 * RXRAT( 210 )
     &                   +  0.605 * RXRAT( 214 )
      LOSS( NCELL, CCHO     ) =            RXRAT( 130 )
     &                   +          RXRAT( 131 )
     &                   +          RXRAT( 132 )

      PROD( NCELL, RCO_OOH  ) =    0.750 * RXRAT(  82 )
     &                   +  0.750 * RXRAT(  93 )
     &                   +  0.750 * RXRAT( 105 )
      LOSS( NCELL, RCO_OOH  ) =    0.0

      PROD( NCELL, RCO_OH   ) =    0.250 * RXRAT(  82 )
     &                   +          RXRAT(  84 )
     &                   +          RXRAT(  85 )
     &                   +          RXRAT(  87 )
     &                   +  0.250 * RXRAT(  93 )
     &                   +          RXRAT(  95 )
     &                   +          RXRAT(  96 )
     &                   +          RXRAT(  98 )
     &                   +  0.250 * RXRAT( 105 )
     &                   +          RXRAT( 107 )
     &                   +          RXRAT( 108 )
     &                   +  2.000 * RXRAT( 110 )
     &                   +  0.372 * RXRAT( 171 )
     &                   +  0.150 * RXRAT( 190 )
     &                   +  0.189 * RXRAT( 194 )
     &                   +  0.119 * RXRAT( 205 )
     &                   +  0.303 * RXRAT( 209 )
      LOSS( NCELL, RCO_OH   ) =            RXRAT( 214 )

      PROD( NCELL, BZCO_O2  ) =            RXRAT(  91 )
     &                   +          RXRAT( 158 )
     &                   +          RXRAT( 160 )
      LOSS( NCELL, BZCO_O2  ) =            RXRAT(  90 )
     &                   +          RXRAT(  92 )
     &                   +          RXRAT(  93 )
     &                   +          RXRAT(  94 )
     &                   +          RXRAT(  95 )
     &                   +          RXRAT(  96 )
     &                   +          RXRAT(  98 )
     &                   +          RXRAT(  99 )
     &                   +          RXRAT( 100 )
     &                   +  2.000 * RXRAT( 101 )
     &                   +          RXRAT( 113 )

      PROD( NCELL, PBZN     ) =            RXRAT(  90 )
      LOSS( NCELL, PBZN     ) =            RXRAT(  91 )

      PROD( NCELL, BZ_O     ) =            RXRAT(  92 )
     &                   +          RXRAT(  94 )
     &                   +          RXRAT(  99 )
     &                   +          RXRAT( 100 )
     &                   +  2.000 * RXRAT( 101 )
     &                   +          RXRAT( 113 )
     &                   +  0.240 * RXRAT( 153 )
     &                   +          RXRAT( 154 )
     &                   +  0.240 * RXRAT( 155 )
     &                   +          RXRAT( 156 )
      LOSS( NCELL, BZ_O     ) =            RXRAT( 117 )
     &                   +          RXRAT( 118 )
     &                   +          RXRAT( 119 )

      PROD( NCELL, MA_RCO3  ) =            RXRAT( 103 )
     &                   +  0.500 * RXRAT( 161 )
     &                   +  0.500 * RXRAT( 163 )
     &                   +  0.330 * RXRAT( 165 )
     &                   +  0.300 * RXRAT( 169 )
     &                   +  0.289 * RXRAT( 170 )
     &                   +  0.150 * RXRAT( 172 )
     &                   +  0.192 * RXRAT( 190 )
     &                   +  0.240 * RXRAT( 192 )
      LOSS( NCELL, MA_RCO3  ) =            RXRAT( 102 )
     &                   +          RXRAT( 104 )
     &                   +          RXRAT( 105 )
     &                   +          RXRAT( 106 )
     &                   +          RXRAT( 107 )
     &                   +          RXRAT( 108 )
     &                   +          RXRAT( 110 )
     &                   +          RXRAT( 111 )
     &                   +          RXRAT( 112 )
     &                   +          RXRAT( 113 )
     &                   +  2.000 * RXRAT( 114 )

      PROD( NCELL, MA_PAN   ) =            RXRAT( 102 )
      LOSS( NCELL, MA_PAN   ) =            RXRAT( 103 )

      PROD( NCELL, TBU_O    ) =    0.236 * RXRAT( 199 )
      LOSS( NCELL, TBU_O    ) =            RXRAT( 115 )
     &                   +          RXRAT( 116 )

      PROD( NCELL, ACET     ) =            RXRAT( 116 )
     &                   +  0.006 * RXRAT( 176 )
     &                   +  0.020 * RXRAT( 177 )
     &                   +  0.130 * RXRAT( 194 )
     &                   +  0.417 * RXRAT( 198 )
     &                   +  0.024 * RXRAT( 199 )
     &                   +  0.452 * RXRAT( 200 )
     &                   +  0.072 * RXRAT( 201 )
     &                   +  0.005 * RXRAT( 204 )
     &                   +  0.001 * RXRAT( 205 )
     &                   +  0.024 * RXRAT( 206 )
     &                   +  0.127 * RXRAT( 208 )
     &                   +  0.045 * RXRAT( 209 )
     &                   +  0.102 * RXRAT( 210 )
      LOSS( NCELL, ACET     ) =            RXRAT( 136 )
     &                   +          RXRAT( 137 )

      PROD( NCELL, NPHE     ) =            RXRAT( 117 )
     &                   +          RXRAT( 121 )
     &                   +          RXRAT( 122 )
      LOSS( NCELL, NPHE     ) =            RXRAT( 157 )

      PROD( NCELL, PHEN     ) =            RXRAT( 118 )
     &                   +          RXRAT( 119 )
     &                   +  0.017 * RXRAT( 202 )
      LOSS( NCELL, PHEN     ) =            RXRAT( 153 )
     &                   +          RXRAT( 154 )

      PROD( NCELL, BZNO2_O  ) =            RXRAT( 157 )
      LOSS( NCELL, BZNO2_O  ) =            RXRAT( 120 )
     &                   +          RXRAT( 121 )
     &                   +          RXRAT( 122 )

      PROD( NCELL, HOCOO    ) =            RXRAT( 126 )
      LOSS( NCELL, HOCOO    ) =            RXRAT( 127 )
     &                   +          RXRAT( 128 )

      PROD( NCELL, HCOOH    ) =            RXRAT( 128 )
     &                   +  0.333 * RXRAT( 162 )
     &                   +  0.351 * RXRAT( 167 )
     &                   +  0.100 * RXRAT( 171 )
     &                   +  0.370 * RXRAT( 186 )
     &                   +  0.204 * RXRAT( 190 )
     &                   +  0.103 * RXRAT( 194 )
     &                   +  0.121 * RXRAT( 198 )
     &                   +  0.185 * RXRAT( 205 )
     &                   +  0.073 * RXRAT( 209 )
      LOSS( NCELL, HCOOH    ) =            RXRAT( 212 )

      PROD( NCELL, RCHO     ) =    0.370 * RXRAT( 138 )
     &                   +          RXRAT( 143 )
     &                   +          RXRAT( 144 )
     &                   +          RXRAT( 164 )
     &                   +  0.675 * RXRAT( 166 )
     &                   +  0.450 * RXRAT( 168 )
     &                   +  0.013 * RXRAT( 170 )
     &                   +  0.218 * RXRAT( 172 )
     &                   +  0.558 * RXRAT( 174 )
     &                   +  0.710 * RXRAT( 175 )
     &                   +  0.213 * RXRAT( 176 )
     &                   +  0.147 * RXRAT( 177 )
     &                   +          RXRAT( 178 )
     &                   +          RXRAT( 180 )
     &                   +          RXRAT( 182 )
     &                   +          RXRAT( 187 )
     &                   +  0.474 * RXRAT( 193 )
     &                   +  0.205 * RXRAT( 194 )
     &                   +  0.474 * RXRAT( 195 )
     &                   +  0.147 * RXRAT( 196 )
     &                   +  0.155 * RXRAT( 198 )
     &                   +  0.122 * RXRAT( 199 )
     &                   +  0.244 * RXRAT( 200 )
     &                   +  0.204 * RXRAT( 201 )
     &                   +  0.497 * RXRAT( 204 )
     &                   +  0.363 * RXRAT( 205 )
     &                   +  0.037 * RXRAT( 206 )
     &                   +  0.450 * RXRAT( 207 )
     &                   +  0.511 * RXRAT( 208 )
     &                   +  0.305 * RXRAT( 209 )
     &                   +  0.151 * RXRAT( 210 )
     &                   +  0.069 * RXRAT( 211 )
     &                   +  0.210 * RXRAT( 214 )
      LOSS( NCELL, RCHO     ) =            RXRAT( 133 )
     &                   +          RXRAT( 134 )
     &                   +          RXRAT( 135 )

      PROD( NCELL, GLY      ) =    0.230 * RXRAT( 153 )
     &                   +  0.150 * RXRAT( 170 )
     &                   +  0.023 * RXRAT( 171 )
     &                   +          RXRAT( 179 )
     &                   +  0.500 * RXRAT( 181 )
     &                   +  0.500 * RXRAT( 183 )
     &                   +  0.009 * RXRAT( 188 )
     &                   +  0.001 * RXRAT( 194 )
     &                   +  0.248 * RXRAT( 198 )
     &                   +  0.118 * RXRAT( 202 )
     &                   +  0.097 * RXRAT( 203 )
      LOSS( NCELL, GLY      ) =            RXRAT( 145 )
     &                   +          RXRAT( 146 )
     &                   +          RXRAT( 147 )
     &                   +          RXRAT( 148 )

      PROD( NCELL, MGLY     ) =    0.230 * RXRAT( 155 )
     &                   +  0.084 * RXRAT( 161 )
     &                   +  0.900 * RXRAT( 162 )
     &                   +  0.300 * RXRAT( 166 )
     &                   +  0.950 * RXRAT( 167 )
     &                   +  0.174 * RXRAT( 170 )
     &                   +  0.742 * RXRAT( 171 )
     &                   +  0.008 * RXRAT( 172 )
     &                   +  0.500 * RXRAT( 181 )
     &                   +  0.500 * RXRAT( 183 )
     &                   +  0.119 * RXRAT( 202 )
     &                   +  0.287 * RXRAT( 203 )
     &                   +  0.130 * RXRAT( 213 )
      LOSS( NCELL, MGLY     ) =            RXRAT( 149 )
     &                   +          RXRAT( 150 )
     &                   +          RXRAT( 151 )

      PROD( NCELL, BACL     ) =    0.031 * RXRAT( 194 )
     &                   +  0.087 * RXRAT( 203 )
     &                   +  0.185 * RXRAT( 214 )
      LOSS( NCELL, BACL     ) =            RXRAT( 152 )

      PROD( NCELL, CRES     ) =    0.207 * RXRAT( 202 )
     &                   +  0.187 * RXRAT( 203 )
      LOSS( NCELL, CRES     ) =            RXRAT( 155 )
     &                   +          RXRAT( 156 )

      PROD( NCELL, BALD     ) =    0.059 * RXRAT( 202 )
     &                   +  0.050 * RXRAT( 203 )
     &                   +  0.061 * RXRAT( 208 )
     &                   +  0.042 * RXRAT( 209 )
     &                   +  0.015 * RXRAT( 210 )
      LOSS( NCELL, BALD     ) =            RXRAT( 158 )
     &                   +          RXRAT( 159 )
     &                   +          RXRAT( 160 )

      PROD( NCELL, METHACRO ) =    0.230 * RXRAT( 189 )
     &                   +  0.390 * RXRAT( 190 )
     &                   +  0.025 * RXRAT( 208 )
     &                   +  0.026 * RXRAT( 209 )
     &                   +  0.012 * RXRAT( 211 )
      LOSS( NCELL, METHACRO ) =            RXRAT( 161 )
     &                   +          RXRAT( 162 )
     &                   +          RXRAT( 163 )
     &                   +          RXRAT( 164 )
     &                   +          RXRAT( 165 )

      PROD( NCELL, MVK      ) =    0.320 * RXRAT( 189 )
     &                   +  0.160 * RXRAT( 190 )
     &                   +  0.048 * RXRAT( 210 )
      LOSS( NCELL, MVK      ) =            RXRAT( 166 )
     &                   +          RXRAT( 167 )
     &                   +          RXRAT( 168 )
     &                   +          RXRAT( 169 )

      PROD( NCELL, ISOPROD  ) =    0.357 * RXRAT( 189 )
     &                   +  0.936 * RXRAT( 191 )
     &                   +  0.025 * RXRAT( 208 )
      LOSS( NCELL, ISOPROD  ) =            RXRAT( 170 )
     &                   +          RXRAT( 171 )
     &                   +          RXRAT( 172 )
     &                   +          RXRAT( 173 )

      PROD( NCELL, DCB1     ) =    0.491 * RXRAT( 202 )
     &                   +  0.561 * RXRAT( 203 )
      LOSS( NCELL, DCB1     ) =            RXRAT( 178 )
     &                   +          RXRAT( 179 )

      PROD( NCELL, DCB2     ) =    0.108 * RXRAT( 202 )
     &                   +  0.099 * RXRAT( 203 )
      LOSS( NCELL, DCB2     ) =            RXRAT( 180 )
     &                   +          RXRAT( 181 )

      PROD( NCELL, DCB3     ) =    0.051 * RXRAT( 202 )
     &                   +  0.093 * RXRAT( 203 )
      LOSS( NCELL, DCB3     ) =            RXRAT( 182 )
     &                   +          RXRAT( 183 )

      PROD( NCELL, ETHENE   ) =    0.0
      LOSS( NCELL, ETHENE   ) =            RXRAT( 185 )
     &                   +          RXRAT( 186 )
     &                   +          RXRAT( 187 )
     &                   +          RXRAT( 188 )

      PROD( NCELL, ISOPRENE ) =    0.0
      LOSS( NCELL, ISOPRENE ) =            RXRAT( 189 )
     &                   +          RXRAT( 190 )
     &                   +          RXRAT( 191 )
     &                   +          RXRAT( 192 )

      PROD( NCELL, TRP1     ) =    0.0
      LOSS( NCELL, TRP1     ) =            RXRAT( 193 )
     &                   +          RXRAT( 194 )
     &                   +          RXRAT( 195 )
     &                   +          RXRAT( 196 )

      PROD( NCELL, ALK1     ) =    0.0
      LOSS( NCELL, ALK1     ) =            RXRAT( 197 )

      PROD( NCELL, ALK2     ) =    0.0
      LOSS( NCELL, ALK2     ) =            RXRAT( 198 )

      PROD( NCELL, ALK3     ) =    0.0
      LOSS( NCELL, ALK3     ) =            RXRAT( 199 )

      PROD( NCELL, ALK4     ) =    0.0
      LOSS( NCELL, ALK4     ) =            RXRAT( 200 )

      PROD( NCELL, ALK5     ) =    0.0
      LOSS( NCELL, ALK5     ) =            RXRAT( 201 )

      PROD( NCELL, ARO1     ) =    0.0
      LOSS( NCELL, ARO1     ) =            RXRAT( 202 )

      PROD( NCELL, ARO2     ) =    0.0
      LOSS( NCELL, ARO2     ) =            RXRAT( 203 )

      PROD( NCELL, OLE1     ) =    0.0
      LOSS( NCELL, OLE1     ) =            RXRAT( 204 )
     &                   +          RXRAT( 205 )
     &                   +          RXRAT( 206 )
     &                   +          RXRAT( 207 )

      PROD( NCELL, OLE2     ) =    0.0
      LOSS( NCELL, OLE2     ) =            RXRAT( 208 )
     &                   +          RXRAT( 209 )
     &                   +          RXRAT( 210 )
     &                   +          RXRAT( 211 )


      IF( L_AE_VRSN ) THEN

         PROD( NCELL, SULAER   ) =            RXRAT(  44 )
         LOSS( NCELL, SULAER   ) =    0.0

         PROD( NCELL, ALK5AER  ) =            RXRAT( 201 )
         LOSS( NCELL, ALK5AER  ) =    0.0

         PROD( NCELL, OLE2AER  ) =            RXRAT( 208 )
     &                      +          RXRAT( 209 )
     &                      +          RXRAT( 210 )
         LOSS( NCELL, OLE2AER  ) =    0.0
    
         PROD( NCELL, ARO1AER  ) =            RXRAT( 202 )
         LOSS( NCELL, ARO1AER  ) =    0.0

         PROD( NCELL, ARO2AER  ) =            RXRAT( 203 )
         LOSS( NCELL, ARO2AER  ) =    0.0

         PROD( NCELL, CRESAER  ) =            RXRAT( 155 )
     &                   +          RXRAT( 156 )
         LOSS( NCELL, CRESAER  ) =    0.0

         PROD( NCELL, TRP1AER  ) =            RXRAT( 193 )
     &                      +          RXRAT( 194 )
     &                      +          RXRAT( 195 )
     &                      +          RXRAT( 196 )
         LOSS( NCELL, TRP1AER  ) =    0.0

      END IF

      RETURN

      END

S1
